/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 55 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"

#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 59 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 372 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 62 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 65 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 86 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 89 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 92 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 97 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 103 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 106 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 109 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 112 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 115 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 118 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 121 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 124 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 127 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 130 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 133 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 136 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 139 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 142 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DSeries.cpp"


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_type, "type(self) -> QAbstract3DSeries.SeriesType");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_type(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DSeries::SeriesType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DSeries_SeriesType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_type, doc_QtDataVisualization_QAbstract3DSeries_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat, "setItemLabelFormat(self, format: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setItemLabelFormat(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setItemLabelFormat, doc_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_itemLabelFormat, "itemLabelFormat(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_itemLabelFormat(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_itemLabelFormat(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->itemLabelFormat());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_itemLabelFormat, doc_QtDataVisualization_QAbstract3DSeries_itemLabelFormat);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setVisible, doc_QtDataVisualization_QAbstract3DSeries_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_isVisible, doc_QtDataVisualization_QAbstract3DSeries_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMesh, "setMesh(self, mesh: QAbstract3DSeries.Mesh)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMesh(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMesh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DSeries::Mesh a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QtDataVisualization_QAbstract3DSeries_Mesh, &a0))
        {
            sipCpp->setMesh(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMesh, doc_QtDataVisualization_QAbstract3DSeries_setMesh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_mesh, "mesh(self) -> QAbstract3DSeries.Mesh");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_mesh(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_mesh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DSeries::Mesh sipRes;

            sipRes = sipCpp->mesh();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DSeries_Mesh);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_mesh, doc_QtDataVisualization_QAbstract3DSeries_mesh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMeshSmooth, "setMeshSmooth(self, enable: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshSmooth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshSmooth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, &a0))
        {
            sipCpp->setMeshSmooth(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMeshSmooth, doc_QtDataVisualization_QAbstract3DSeries_setMeshSmooth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_isMeshSmooth, "isMeshSmooth(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isMeshSmooth(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isMeshSmooth(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isMeshSmooth();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_isMeshSmooth, doc_QtDataVisualization_QAbstract3DSeries_isMeshSmooth);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMeshRotation, "setMeshRotation(self, rotation: QQuaternion)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setMeshRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMeshRotation, doc_QtDataVisualization_QAbstract3DSeries_setMeshRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_meshRotation, "meshRotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_meshRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_meshRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->meshRotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_meshRotation, doc_QtDataVisualization_QAbstract3DSeries_meshRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh, "setUserDefinedMesh(self, fileName: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setUserDefinedMesh(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setUserDefinedMesh, doc_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_userDefinedMesh, "userDefinedMesh(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_userDefinedMesh(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_userDefinedMesh(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->userDefinedMesh());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_userDefinedMesh, doc_QtDataVisualization_QAbstract3DSeries_userDefinedMesh);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setColorStyle, "setColorStyle(self, style: Q3DTheme.ColorStyle)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setColorStyle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setColorStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme::ColorStyle a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QtDataVisualization_Q3DTheme_ColorStyle, &a0))
        {
            sipCpp->setColorStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setColorStyle, doc_QtDataVisualization_QAbstract3DSeries_setColorStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_colorStyle, "colorStyle(self) -> Q3DTheme.ColorStyle");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_colorStyle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_colorStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QtDataVisualization::Q3DTheme::ColorStyle sipRes;

            sipRes = sipCpp->colorStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_Q3DTheme_ColorStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_colorStyle, doc_QtDataVisualization_QAbstract3DSeries_colorStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setBaseColor, "setBaseColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setBaseColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setBaseColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBaseColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setBaseColor, doc_QtDataVisualization_QAbstract3DSeries_setBaseColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_baseColor, "baseColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_baseColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_baseColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->baseColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_baseColor, doc_QtDataVisualization_QAbstract3DSeries_baseColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setBaseGradient, "setBaseGradient(self, gradient: QLinearGradient)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setBaseGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setBaseGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLinearGradient* a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QLinearGradient, &a0))
        {
            sipCpp->setBaseGradient(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setBaseGradient, doc_QtDataVisualization_QAbstract3DSeries_setBaseGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_baseGradient, "baseGradient(self) -> QLinearGradient");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_baseGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_baseGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QLinearGradient*sipRes;

            sipRes = new ::QLinearGradient(sipCpp->baseGradient());

            return sipConvertFromNewType(sipRes, sipType_QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_baseGradient, doc_QtDataVisualization_QAbstract3DSeries_baseGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor, "setSingleHighlightColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setSingleHighlightColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setSingleHighlightColor, doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_singleHighlightColor, "singleHighlightColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_singleHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_singleHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->singleHighlightColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_singleHighlightColor, doc_QtDataVisualization_QAbstract3DSeries_singleHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient, "setSingleHighlightGradient(self, gradient: QLinearGradient)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLinearGradient* a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QLinearGradient, &a0))
        {
            sipCpp->setSingleHighlightGradient(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setSingleHighlightGradient, doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient, "singleHighlightGradient(self) -> QLinearGradient");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QLinearGradient*sipRes;

            sipRes = new ::QLinearGradient(sipCpp->singleHighlightGradient());

            return sipConvertFromNewType(sipRes, sipType_QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_singleHighlightGradient, doc_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor, "setMultiHighlightColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setMultiHighlightColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMultiHighlightColor, doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_multiHighlightColor, "multiHighlightColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_multiHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_multiHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->multiHighlightColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_multiHighlightColor, doc_QtDataVisualization_QAbstract3DSeries_multiHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient, "setMultiHighlightGradient(self, gradient: QLinearGradient)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLinearGradient* a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QLinearGradient, &a0))
        {
            sipCpp->setMultiHighlightGradient(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMultiHighlightGradient, doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient, "multiHighlightGradient(self) -> QLinearGradient");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QLinearGradient*sipRes;

            sipRes = new ::QLinearGradient(sipCpp->multiHighlightGradient());

            return sipConvertFromNewType(sipRes, sipType_QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_multiHighlightGradient, doc_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setName, "setName(self, name: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setName(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setName(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setName(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setName, doc_QtDataVisualization_QAbstract3DSeries_setName);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_name, "name(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_name(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_name(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->name());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_name, doc_QtDataVisualization_QAbstract3DSeries_name);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle, "setMeshAxisAndAngle(self, axis: QVector3D, angle: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        float a1;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9f", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, sipType_QVector3D, &a0, &a1))
        {
            sipCpp->setMeshAxisAndAngle(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setMeshAxisAndAngle, doc_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_itemLabel, "itemLabel(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_itemLabel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_itemLabel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->itemLabel());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_itemLabel, doc_QtDataVisualization_QAbstract3DSeries_itemLabel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible, "setItemLabelVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp, &a0))
        {
            sipCpp->setItemLabelVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_setItemLabelVisible, doc_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible, "isItemLabelVisible(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isItemLabelVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DSeries, sipName_isItemLabelVisible, doc_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QAbstract3DSeries(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QAbstract3DSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QAbstract3DSeries *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DSeries *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QAbstract3DSeries)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QAbstract3DSeries(void *, int);}
static void release_QtDataVisualization_QAbstract3DSeries(void *sipCppV, int)
{
    ::QtDataVisualization::QAbstract3DSeries *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtDataVisualization_QAbstract3DSeries(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QAbstract3DSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QAbstract3DSeries(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QAbstract3DSeries[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_QAbstract3DSeries[] = {
    {sipName_baseColor, meth_QtDataVisualization_QAbstract3DSeries_baseColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_baseColor},
    {sipName_baseGradient, meth_QtDataVisualization_QAbstract3DSeries_baseGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_baseGradient},
    {sipName_colorStyle, meth_QtDataVisualization_QAbstract3DSeries_colorStyle, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_colorStyle},
    {sipName_isItemLabelVisible, meth_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_isItemLabelVisible},
    {sipName_isMeshSmooth, meth_QtDataVisualization_QAbstract3DSeries_isMeshSmooth, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_isMeshSmooth},
    {sipName_isVisible, meth_QtDataVisualization_QAbstract3DSeries_isVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_isVisible},
    {sipName_itemLabel, meth_QtDataVisualization_QAbstract3DSeries_itemLabel, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_itemLabel},
    {sipName_itemLabelFormat, meth_QtDataVisualization_QAbstract3DSeries_itemLabelFormat, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_itemLabelFormat},
    {sipName_mesh, meth_QtDataVisualization_QAbstract3DSeries_mesh, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_mesh},
    {sipName_meshRotation, meth_QtDataVisualization_QAbstract3DSeries_meshRotation, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_meshRotation},
    {sipName_multiHighlightColor, meth_QtDataVisualization_QAbstract3DSeries_multiHighlightColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_multiHighlightColor},
    {sipName_multiHighlightGradient, meth_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_multiHighlightGradient},
    {sipName_name, meth_QtDataVisualization_QAbstract3DSeries_name, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_name},
    {sipName_setBaseColor, meth_QtDataVisualization_QAbstract3DSeries_setBaseColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setBaseColor},
    {sipName_setBaseGradient, meth_QtDataVisualization_QAbstract3DSeries_setBaseGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setBaseGradient},
    {sipName_setColorStyle, meth_QtDataVisualization_QAbstract3DSeries_setColorStyle, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setColorStyle},
    {sipName_setItemLabelFormat, meth_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setItemLabelFormat},
    {sipName_setItemLabelVisible, meth_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setItemLabelVisible},
    {sipName_setMesh, meth_QtDataVisualization_QAbstract3DSeries_setMesh, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMesh},
    {sipName_setMeshAxisAndAngle, meth_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMeshAxisAndAngle},
    {sipName_setMeshRotation, meth_QtDataVisualization_QAbstract3DSeries_setMeshRotation, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMeshRotation},
    {sipName_setMeshSmooth, meth_QtDataVisualization_QAbstract3DSeries_setMeshSmooth, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMeshSmooth},
    {sipName_setMultiHighlightColor, meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightColor},
    {sipName_setMultiHighlightGradient, meth_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setMultiHighlightGradient},
    {sipName_setName, meth_QtDataVisualization_QAbstract3DSeries_setName, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setName},
    {sipName_setSingleHighlightColor, meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightColor},
    {sipName_setSingleHighlightGradient, meth_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setSingleHighlightGradient},
    {sipName_setUserDefinedMesh, meth_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setUserDefinedMesh},
    {sipName_setVisible, meth_QtDataVisualization_QAbstract3DSeries_setVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_setVisible},
    {sipName_singleHighlightColor, meth_QtDataVisualization_QAbstract3DSeries_singleHighlightColor, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_singleHighlightColor},
    {sipName_singleHighlightGradient, meth_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_singleHighlightGradient},
    {sipName_type, meth_QtDataVisualization_QAbstract3DSeries_type, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_type},
    {sipName_userDefinedMesh, meth_QtDataVisualization_QAbstract3DSeries_userDefinedMesh, METH_VARARGS, doc_QtDataVisualization_QAbstract3DSeries_userDefinedMesh}
};

static sipEnumMemberDef enummembers_QtDataVisualization_QAbstract3DSeries[] = {
    {sipName_MeshArrow, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshArrow), 42},
    {sipName_MeshBar, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshBar), 42},
    {sipName_MeshBevelBar, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshBevelBar), 42},
    {sipName_MeshBevelCube, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshBevelCube), 42},
    {sipName_MeshCone, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshCone), 42},
    {sipName_MeshCube, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshCube), 42},
    {sipName_MeshCylinder, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshCylinder), 42},
    {sipName_MeshMinimal, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshMinimal), 42},
    {sipName_MeshPoint, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshPoint), 42},
    {sipName_MeshPyramid, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshPyramid), 42},
    {sipName_MeshSphere, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshSphere), 42},
    {sipName_MeshUserDefined, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::MeshUserDefined), 42},
    {sipName_SeriesTypeBar, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::SeriesTypeBar), 43},
    {sipName_SeriesTypeNone, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::SeriesTypeNone), 43},
    {sipName_SeriesTypeScatter, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::SeriesTypeScatter), 43},
    {sipName_SeriesTypeSurface, static_cast<int>(::QtDataVisualization::QAbstract3DSeries::SeriesTypeSurface), 43},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QAbstract3DSeries[] = {
    {"itemLabelVisibilityChanged(bool)", "\1itemLabelVisibilityChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemLabelChanged(QString)", "\1itemLabelChanged(self, label: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"nameChanged(QString)", "\1nameChanged(self, name: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"multiHighlightGradientChanged(QLinearGradient)", "\1multiHighlightGradientChanged(self, gradient: QLinearGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"multiHighlightColorChanged(QColor)", "\1multiHighlightColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"singleHighlightGradientChanged(QLinearGradient)", "\1singleHighlightGradientChanged(self, gradient: QLinearGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"singleHighlightColorChanged(QColor)", "\1singleHighlightColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"baseGradientChanged(QLinearGradient)", "\1baseGradientChanged(self, gradient: QLinearGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"baseColorChanged(QColor)", "\1baseColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"colorStyleChanged(Q3DTheme::ColorStyle)|(QtDataVisualization::Q3DTheme::ColorStyle)", "\1colorStyleChanged(self, style: Q3DTheme.ColorStyle)", SIP_NULLPTR, SIP_NULLPTR},
    {"userDefinedMeshChanged(QString)", "\1userDefinedMeshChanged(self, fileName: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"meshRotationChanged(QQuaternion)", "\1meshRotationChanged(self, rotation: QQuaternion)", SIP_NULLPTR, SIP_NULLPTR},
    {"meshSmoothChanged(bool)", "\1meshSmoothChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"meshChanged(QAbstract3DSeries::Mesh)|(QtDataVisualization::QAbstract3DSeries::Mesh)", "\1meshChanged(self, mesh: QAbstract3DSeries.Mesh)", SIP_NULLPTR, SIP_NULLPTR},
    {"visibilityChanged(bool)", "\1visibilityChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemLabelFormatChanged(QString)", "\1itemLabelFormatChanged(self, format: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QAbstract3DSeries = {
    &::QtDataVisualization::QAbstract3DSeries::staticMetaObject,
    0,
    signals_QtDataVisualization_QAbstract3DSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QAbstract3DSeries,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QAbstract3DSeries,
    },
    {
        sipNameNr_QAbstract3DSeries,
        {0, 0, 1},
        33, methods_QtDataVisualization_QAbstract3DSeries,
        16, enummembers_QtDataVisualization_QAbstract3DSeries,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtDataVisualization_QAbstract3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QAbstract3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtDataVisualization_QAbstract3DSeries,
    cast_QtDataVisualization_QAbstract3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
