/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 89 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 153 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"


extern "C" {static long slot_QtDataVisualization_QSurface3DSeries_DrawFlags___hash__(PyObject *);}
static long slot_QtDataVisualization_QSurface3DSeries_DrawFlags___hash__(PyObject *sipSelf)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return 0L;


    {
        {
            long sipRes = 0;

#line 122 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int();
#line 171 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static int slot_QtDataVisualization_QSurface3DSeries_DrawFlags___bool__(PyObject *);}
static int slot_QtDataVisualization_QSurface3DSeries_DrawFlags___bool__(PyObject *sipSelf)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return -1;


    {
        {
            int sipRes = 0;

#line 117 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int() != 0);
#line 196 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

            return sipRes;
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ne__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ne__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 112 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int() != a0->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int());
#line 226 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"
            sipReleaseType(const_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(a0), sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtDataVisualization, ne_slot, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___eq__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___eq__(PyObject *sipSelf, PyObject *sipArg)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;

        if (sipParseArgs(&sipParseErr, sipArg, "1J1", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State))
        {
            bool sipRes = 0;

#line 107 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = (sipCpp->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int() == a0->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int());
#line 259 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"
            sipReleaseType(const_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(a0), sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return PyBool_FromLong(sipRes);
        }
    }

    Py_XDECREF(sipParseErr);

    return sipPySlotExtend(&sipModuleAPI_QtDataVisualization, eq_slot, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, sipSelf, sipArg);
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ixor__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ixor__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtDataVisualization_QSurface3DSeries_DrawFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 101 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = QtDataVisualization::QSurface3DSeries::DrawFlags(*sipCpp ^ a0);
#line 295 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___xor__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___xor__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State, &a1))
        {
            ::QtDataVisualization::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QtDataVisualization::QSurface3DSeries::DrawFlags((*a0 ^ a1));
            sipReleaseType(a0, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtDataVisualization, xor_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ior__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ior__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtDataVisualization_QSurface3DSeries_DrawFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
#line 95 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        *sipCpp = QtDataVisualization::QSurface3DSeries::DrawFlags(*sipCpp | a0);
#line 367 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___or__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State, &a1))
        {
            ::QtDataVisualization::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QtDataVisualization::QSurface3DSeries::DrawFlags((*a0 | a1));
            sipReleaseType(a0, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtDataVisualization, or_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___iand__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___iand__(PyObject *sipSelf, PyObject *sipArg)
{
    if (!PyObject_TypeCheck(sipSelf, sipTypeAsPyTypeObject(sipType_QtDataVisualization_QSurface3DSeries_DrawFlags)))
    {
        Py_INCREF(Py_NotImplemented);
        return Py_NotImplemented;
    }

    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;

    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;

        if (sipParseArgs(&sipParseErr, sipArg, "1i", &a0))
        {
            sipCpp->::QtDataVisualization::QSurface3DSeries::DrawFlags::operator&=(a0);

            Py_INCREF(sipSelf);
            return sipSelf;
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___and__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___and__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;
        int a1;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "J1i", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State, &a1))
        {
            ::QtDataVisualization::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QtDataVisualization::QSurface3DSeries::DrawFlags((*a0 & a1));
            sipReleaseType(a0, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    return sipPySlotExtend(&sipModuleAPI_QtDataVisualization, and_slot, SIP_NULLPTR, sipArg0, sipArg1);
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___invert__(PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___invert__(PyObject *sipSelf)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            ::QtDataVisualization::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QtDataVisualization::QSurface3DSeries::DrawFlags(~(*sipCpp));

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NULLPTR);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___index__(PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___index__(PyObject *sipSelf)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes = 0;

#line 84 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
        sipRes = sipCpp->operator QtDataVisualization::QSurface3DSeries::DrawFlags::Int();
#line 524 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


extern "C" {static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___int__(PyObject *);}
static PyObject *slot_QtDataVisualization_QSurface3DSeries_DrawFlags___int__(PyObject *sipSelf)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipGetCppPtr((sipSimpleWrapper *)sipSelf, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags));

    if (!sipCpp)
        return SIP_NULLPTR;


    {
        {
            int sipRes;

            sipRes = int(*sipCpp);

            return PyLong_FromLong(sipRes);
        }
    }

    return 0;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QSurface3DSeries_DrawFlags(void *, int);}
static void release_QtDataVisualization_QSurface3DSeries_DrawFlags(void *sipCppV, int)
{
    delete reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipCppV);
}


extern "C" {static void *array_QtDataVisualization_QSurface3DSeries_DrawFlags(Py_ssize_t);}
static void *array_QtDataVisualization_QSurface3DSeries_DrawFlags(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QSurface3DSeries::DrawFlags[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QSurface3DSeries_DrawFlags(void *);}
static void array_delete_QtDataVisualization_QSurface3DSeries_DrawFlags(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipCpp);
}


extern "C" {static void assign_QtDataVisualization_QSurface3DSeries_DrawFlags(void *, Py_ssize_t, void *);}
static void assign_QtDataVisualization_QSurface3DSeries_DrawFlags(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipSrc);
}


extern "C" {static void *copy_QtDataVisualization_QSurface3DSeries_DrawFlags(const void *, Py_ssize_t);}
static void *copy_QtDataVisualization_QSurface3DSeries_DrawFlags(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QtDataVisualization::QSurface3DSeries::DrawFlags(reinterpret_cast<const ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QtDataVisualization_QSurface3DSeries_DrawFlags(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QSurface3DSeries_DrawFlags(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QSurface3DSeries_DrawFlags(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QtDataVisualization_QSurface3DSeries_DrawFlags(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QSurface3DSeries_DrawFlags(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QtDataVisualization::QSurface3DSeries::DrawFlags();

            return sipCpp;
        }
    }

    {
        int a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "i", &a0))
        {
            sipCpp = new ::QtDataVisualization::QSurface3DSeries::DrawFlags(a0);

            return sipCpp;
        }
    }

    {
        const ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J1", sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State))
        {
            sipCpp = new ::QtDataVisualization::QSurface3DSeries::DrawFlags(*a0);
            sipReleaseType(const_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags *>(a0), sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


extern "C" {static int convertTo_QtDataVisualization_QSurface3DSeries_DrawFlags(PyObject *, void **, int *, PyObject *);}
static int convertTo_QtDataVisualization_QSurface3DSeries_DrawFlags(PyObject *sipPy, void **sipCppPtrV, int *sipIsErr, PyObject *sipTransferObj)
{
    ::QtDataVisualization::QSurface3DSeries::DrawFlags **sipCppPtr = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries::DrawFlags **>(sipCppPtrV);

#line 127 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qglobal.sip"
// Allow an instance of the base enum whenever a QtDataVisualization::QSurface3DSeries::DrawFlags is expected.

if (sipIsErr == NULL)
    return (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QtDataVisualization_QSurface3DSeries_DrawFlag)) ||
            sipCanConvertToType(sipPy, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NO_CONVERTORS));

if (PyObject_TypeCheck(sipPy, sipTypeAsPyTypeObject(sipType_QtDataVisualization_QSurface3DSeries_DrawFlag)))
{
    *sipCppPtr = new QtDataVisualization::QSurface3DSeries::DrawFlags(int(SIPLong_AsLong(sipPy)));

    return sipGetState(sipTransferObj);
}

*sipCppPtr = reinterpret_cast<QtDataVisualization::QSurface3DSeries::DrawFlags *>(sipConvertToType(sipPy, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, sipTransferObj, SIP_NO_CONVERTORS, 0, sipIsErr));

return 0;
#line 667 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeriesDrawFlags.cpp"
}


/* Define this type's Python slots. */
static sipPySlotDef slots_QtDataVisualization_QSurface3DSeries_DrawFlags[] = {
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___hash__, hash_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___bool__, bool_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ne__, ne_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___eq__, eq_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ixor__, ixor_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___xor__, xor_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___ior__, ior_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___or__, or_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___iand__, iand_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___and__, and_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___invert__, invert_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___index__, index_slot},
    {(void *)slot_QtDataVisualization_QSurface3DSeries_DrawFlags___int__, int_slot},
    {0, (sipPySlotType)0}
};

PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_DrawFlags, "\1QSurface3DSeries.DrawFlags()\n"
"QSurface3DSeries.DrawFlags(f: QSurface3DSeries.DrawFlags|QSurface3DSeries.DrawFlag)\n"
"QSurface3DSeries.DrawFlags(a0: QSurface3DSeries.DrawFlags)");


static pyqt5ClassPluginDef plugin_QtDataVisualization_QSurface3DSeries_DrawFlags = {
    SIP_NULLPTR,
    1,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlags = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QSurface3DSeries__DrawFlags,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QSurface3DSeries_DrawFlags,
    },
    {
        sipNameNr_DrawFlags,
        {63, 255, 0},
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QSurface3DSeries_DrawFlags,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    slots_QtDataVisualization_QSurface3DSeries_DrawFlags,
    init_type_QtDataVisualization_QSurface3DSeries_DrawFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QSurface3DSeries_DrawFlags,
    assign_QtDataVisualization_QSurface3DSeries_DrawFlags,
    array_QtDataVisualization_QSurface3DSeries_DrawFlags,
    copy_QtDataVisualization_QSurface3DSeries_DrawFlags,
    release_QtDataVisualization_QSurface3DSeries_DrawFlags,
    SIP_NULLPTR,
    convertTo_QtDataVisualization_QSurface3DSeries_DrawFlags,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QSurface3DSeries_DrawFlags,
    sizeof (::QtDataVisualization::QSurface3DSeries::DrawFlags),
};
