/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 95 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 99 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 726 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 102 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 105 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 111 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 128 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 155 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 160 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 163 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 166 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 169 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 172 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 175 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 178 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 181 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 184 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 187 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 190 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 193 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 196 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 199 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 205 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQTouch3DInputHandler.cpp"


class sipQtDataVisualization_QTouch3DInputHandler : public ::QtDataVisualization::QTouch3DInputHandler
{
public:
    sipQtDataVisualization_QTouch3DInputHandler(::QObject*);
    virtual ~sipQtDataVisualization_QTouch3DInputHandler();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void wheelEvent(::QWheelEvent*) SIP_OVERRIDE;
    void mouseMoveEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void mouseReleaseEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void mousePressEvent(::QMouseEvent*, const ::QPoint&) SIP_OVERRIDE;
    void touchEvent(::QTouchEvent*) SIP_OVERRIDE;
    void mouseDoubleClickEvent(::QMouseEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QTouch3DInputHandler(const sipQtDataVisualization_QTouch3DInputHandler &);
    sipQtDataVisualization_QTouch3DInputHandler &operator = (const sipQtDataVisualization_QTouch3DInputHandler &);

    char sipPyMethods[13];
};

sipQtDataVisualization_QTouch3DInputHandler::sipQtDataVisualization_QTouch3DInputHandler(::QObject*a0): ::QtDataVisualization::QTouch3DInputHandler(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QTouch3DInputHandler::~sipQtDataVisualization_QTouch3DInputHandler()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QTouch3DInputHandler::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QTouch3DInputHandler);

    return ::QtDataVisualization::QTouch3DInputHandler::metaObject();
}

int sipQtDataVisualization_QTouch3DInputHandler::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QTouch3DInputHandler::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QTouch3DInputHandler, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QTouch3DInputHandler::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QTouch3DInputHandler, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QTouch3DInputHandler::qt_metacast(_clname));
}

void sipQtDataVisualization_QTouch3DInputHandler::wheelEvent(::QWheelEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_wheelEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::wheelEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_2(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QWheelEvent*);

    sipVH_QtDataVisualization_2(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::mouseMoveEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_mouseMoveEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::mouseMoveEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QTouch3DInputHandler::mouseReleaseEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_mouseReleaseEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::mouseReleaseEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QTouch3DInputHandler::mousePressEvent(::QMouseEvent*a0, const ::QPoint& a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_mousePressEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::mousePressEvent(a0, a1);
        return;
    }

    extern void sipVH_QtDataVisualization_23(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*, const ::QPoint&);

    sipVH_QtDataVisualization_23(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QTouch3DInputHandler::touchEvent(::QTouchEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_touchEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::touchEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_1(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTouchEvent*);

    sipVH_QtDataVisualization_1(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::mouseDoubleClickEvent(::QMouseEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_mouseDoubleClickEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::mouseDoubleClickEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_3(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QMouseEvent*);

    sipVH_QtDataVisualization_3(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QTouch3DInputHandler::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QTouch3DInputHandler::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QTouch3DInputHandler::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QTouch3DInputHandler::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QTouch3DInputHandler::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QTouch3DInputHandler::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QTouch3DInputHandler::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QTouch3DInputHandler_touchEvent, "touchEvent(self, event: QTouchEvent|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QTouch3DInputHandler_touchEvent(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QTouch3DInputHandler_touchEvent(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QTouchEvent* a0;
        ::QtDataVisualization::QTouch3DInputHandler *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ8", &sipSelf, sipType_QtDataVisualization_QTouch3DInputHandler, &sipCpp, sipType_QTouchEvent, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QTouch3DInputHandler::touchEvent(a0) : sipCpp->touchEvent(a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QTouch3DInputHandler, sipName_touchEvent, doc_QtDataVisualization_QTouch3DInputHandler_touchEvent);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QTouch3DInputHandler(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QTouch3DInputHandler(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QTouch3DInputHandler *sipCpp = reinterpret_cast< ::QtDataVisualization::QTouch3DInputHandler *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QTouch3DInputHandler)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_Q3DInputHandler)->ctd_cast(static_cast< ::QtDataVisualization::Q3DInputHandler *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QTouch3DInputHandler(void *, int);}
static void release_QtDataVisualization_QTouch3DInputHandler(void *sipCppV, int)
{
    ::QtDataVisualization::QTouch3DInputHandler *sipCpp = reinterpret_cast< ::QtDataVisualization::QTouch3DInputHandler *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QTouch3DInputHandler(Py_ssize_t);}
static void *array_QtDataVisualization_QTouch3DInputHandler(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QTouch3DInputHandler[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QTouch3DInputHandler(void *);}
static void array_delete_QtDataVisualization_QTouch3DInputHandler(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QTouch3DInputHandler *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QTouch3DInputHandler(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QTouch3DInputHandler(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QTouch3DInputHandler *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QTouch3DInputHandler(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QTouch3DInputHandler(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QTouch3DInputHandler(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QTouch3DInputHandler *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QTouch3DInputHandler(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QTouch3DInputHandler[] = {{20, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QTouch3DInputHandler[] = {
    {sipName_touchEvent, meth_QtDataVisualization_QTouch3DInputHandler_touchEvent, METH_VARARGS, doc_QtDataVisualization_QTouch3DInputHandler_touchEvent}
};

PyDoc_STRVAR(doc_QtDataVisualization_QTouch3DInputHandler, "\1QTouch3DInputHandler(parent: QObject|None = None)");


static pyqt5ClassPluginDef plugin_QtDataVisualization_QTouch3DInputHandler = {
    &::QtDataVisualization::QTouch3DInputHandler::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QTouch3DInputHandler = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QTouch3DInputHandler,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QTouch3DInputHandler,
    },
    {
        sipNameNr_QTouch3DInputHandler,
        {0, 0, 1},
        1, methods_QtDataVisualization_QTouch3DInputHandler,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QTouch3DInputHandler,
    -1,
    -1,
    supers_QtDataVisualization_QTouch3DInputHandler,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QTouch3DInputHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QTouch3DInputHandler,
    SIP_NULLPTR,
    array_QtDataVisualization_QTouch3DInputHandler,
    SIP_NULLPTR,
    release_QtDataVisualization_QTouch3DInputHandler,
    cast_QtDataVisualization_QTouch3DInputHandler,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QTouch3DInputHandler,
    sizeof (::QtDataVisualization::QTouch3DInputHandler),
};
