/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 33 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 37 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 40 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 53 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 70 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 75 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 78 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 81 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 84 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 87 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 90 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 93 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 96 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 99 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 102 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 105 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 111 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 114 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 117 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 120 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DCamera.cpp"


class sipQtDataVisualization_Q3DCamera : public ::QtDataVisualization::Q3DCamera
{
public:
    sipQtDataVisualization_Q3DCamera(::QObject*);
    virtual ~sipQtDataVisualization_Q3DCamera();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    void copyValuesFrom(const ::QtDataVisualization::Q3DObject&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_Q3DCamera(const sipQtDataVisualization_Q3DCamera &);
    sipQtDataVisualization_Q3DCamera &operator = (const sipQtDataVisualization_Q3DCamera &);

    char sipPyMethods[8];
};

sipQtDataVisualization_Q3DCamera::sipQtDataVisualization_Q3DCamera(::QObject*a0): ::QtDataVisualization::Q3DCamera(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_Q3DCamera::~sipQtDataVisualization_Q3DCamera()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_Q3DCamera::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_Q3DCamera);

    return ::QtDataVisualization::Q3DCamera::metaObject();
}

int sipQtDataVisualization_Q3DCamera::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::Q3DCamera::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_Q3DCamera, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_Q3DCamera::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_Q3DCamera, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::Q3DCamera::qt_metacast(_clname));
}

void sipQtDataVisualization_Q3DCamera::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DCamera::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DCamera::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DCamera::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DCamera::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_Q3DCamera::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DCamera::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtDataVisualization_Q3DCamera::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DCamera::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DCamera::copyValuesFrom(const ::QtDataVisualization::Q3DObject& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_copyValuesFrom);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DCamera::copyValuesFrom(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_22(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QtDataVisualization::Q3DObject&);

    sipVH_QtDataVisualization_22(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_xRotation, "xRotation(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_xRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_xRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->xRotation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_xRotation, doc_QtDataVisualization_Q3DCamera_xRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setXRotation, "setXRotation(self, rotation: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setXRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setXRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setXRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setXRotation, doc_QtDataVisualization_Q3DCamera_setXRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_yRotation, "yRotation(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_yRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_yRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->yRotation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_yRotation, doc_QtDataVisualization_Q3DCamera_yRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setYRotation, "setYRotation(self, rotation: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setYRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setYRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setYRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setYRotation, doc_QtDataVisualization_Q3DCamera_setYRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_wrapXRotation, "wrapXRotation(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_wrapXRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_wrapXRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->wrapXRotation();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_wrapXRotation, doc_QtDataVisualization_Q3DCamera_wrapXRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setWrapXRotation, "setWrapXRotation(self, isEnabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setWrapXRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setWrapXRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setWrapXRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setWrapXRotation, doc_QtDataVisualization_Q3DCamera_setWrapXRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_wrapYRotation, "wrapYRotation(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_wrapYRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_wrapYRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->wrapYRotation();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_wrapYRotation, doc_QtDataVisualization_Q3DCamera_wrapYRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setWrapYRotation, "setWrapYRotation(self, isEnabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setWrapYRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setWrapYRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setWrapYRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setWrapYRotation, doc_QtDataVisualization_Q3DCamera_setWrapYRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_copyValuesFrom, "copyValuesFrom(self, source: Q3DObject)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_copyValuesFrom(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_copyValuesFrom(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtDataVisualization::Q3DObject* a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, sipType_QtDataVisualization_Q3DObject, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::Q3DCamera::copyValuesFrom(*a0) : sipCpp->copyValuesFrom(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_copyValuesFrom, doc_QtDataVisualization_Q3DCamera_copyValuesFrom);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_cameraPreset, "cameraPreset(self) -> Q3DCamera.CameraPreset");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_cameraPreset(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_cameraPreset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            ::QtDataVisualization::Q3DCamera::CameraPreset sipRes;

            sipRes = sipCpp->cameraPreset();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_Q3DCamera_CameraPreset);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_cameraPreset, doc_QtDataVisualization_Q3DCamera_cameraPreset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setCameraPreset, "setCameraPreset(self, preset: Q3DCamera.CameraPreset)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setCameraPreset(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setCameraPreset(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DCamera::CameraPreset a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, sipType_QtDataVisualization_Q3DCamera_CameraPreset, &a0))
        {
            sipCpp->setCameraPreset(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setCameraPreset, doc_QtDataVisualization_Q3DCamera_setCameraPreset);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setCameraPosition, "setCameraPosition(self, horizontal: float, vertical: float, zoom: float = 100)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setCameraPosition(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setCameraPosition(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        float a2 = 100;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_zoom,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bff|f", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->setCameraPosition(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setCameraPosition, doc_QtDataVisualization_Q3DCamera_setCameraPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_zoomLevel, "zoomLevel(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_zoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_zoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->zoomLevel();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_zoomLevel, doc_QtDataVisualization_Q3DCamera_zoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setZoomLevel, "setZoomLevel(self, zoomLevel: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setZoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setZoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setZoomLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setZoomLevel, doc_QtDataVisualization_Q3DCamera_setZoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_minZoomLevel, "minZoomLevel(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_minZoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_minZoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->minZoomLevel();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_minZoomLevel, doc_QtDataVisualization_Q3DCamera_minZoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setMinZoomLevel, "setMinZoomLevel(self, zoomLevel: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setMinZoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setMinZoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setMinZoomLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setMinZoomLevel, doc_QtDataVisualization_Q3DCamera_setMinZoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_maxZoomLevel, "maxZoomLevel(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_maxZoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_maxZoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->maxZoomLevel();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_maxZoomLevel, doc_QtDataVisualization_Q3DCamera_maxZoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setMaxZoomLevel, "setMaxZoomLevel(self, zoomLevel: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setMaxZoomLevel(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setMaxZoomLevel(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, &a0))
        {
            sipCpp->setMaxZoomLevel(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setMaxZoomLevel, doc_QtDataVisualization_Q3DCamera_setMaxZoomLevel);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_target, "target(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_target(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_target(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->target());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_target, doc_QtDataVisualization_Q3DCamera_target);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera_setTarget, "setTarget(self, target: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DCamera_setTarget(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DCamera_setTarget(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::Q3DCamera *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DCamera, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setTarget(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DCamera, sipName_setTarget, doc_QtDataVisualization_Q3DCamera_setTarget);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_Q3DCamera(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_Q3DCamera(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::Q3DCamera *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DCamera *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_Q3DCamera)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_Q3DObject)->ctd_cast(static_cast< ::QtDataVisualization::Q3DObject *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_Q3DCamera(void *, int);}
static void release_QtDataVisualization_Q3DCamera(void *sipCppV, int)
{
    ::QtDataVisualization::Q3DCamera *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DCamera *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_Q3DCamera(Py_ssize_t);}
static void *array_QtDataVisualization_Q3DCamera(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::Q3DCamera[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_Q3DCamera(void *);}
static void array_delete_QtDataVisualization_Q3DCamera(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::Q3DCamera *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_Q3DCamera(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_Q3DCamera(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_Q3DCamera *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_Q3DCamera(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_Q3DCamera(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_Q3DCamera(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_Q3DCamera *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_Q3DCamera(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_Q3DCamera[] = {{22, 255, 1}};


static PyMethodDef methods_QtDataVisualization_Q3DCamera[] = {
    {sipName_cameraPreset, meth_QtDataVisualization_Q3DCamera_cameraPreset, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_cameraPreset},
    {sipName_copyValuesFrom, meth_QtDataVisualization_Q3DCamera_copyValuesFrom, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_copyValuesFrom},
    {sipName_maxZoomLevel, meth_QtDataVisualization_Q3DCamera_maxZoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_maxZoomLevel},
    {sipName_minZoomLevel, meth_QtDataVisualization_Q3DCamera_minZoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_minZoomLevel},
    {sipName_setCameraPosition, SIP_MLMETH_CAST(meth_QtDataVisualization_Q3DCamera_setCameraPosition), METH_VARARGS|METH_KEYWORDS, doc_QtDataVisualization_Q3DCamera_setCameraPosition},
    {sipName_setCameraPreset, meth_QtDataVisualization_Q3DCamera_setCameraPreset, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setCameraPreset},
    {sipName_setMaxZoomLevel, meth_QtDataVisualization_Q3DCamera_setMaxZoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setMaxZoomLevel},
    {sipName_setMinZoomLevel, meth_QtDataVisualization_Q3DCamera_setMinZoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setMinZoomLevel},
    {sipName_setTarget, meth_QtDataVisualization_Q3DCamera_setTarget, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setTarget},
    {sipName_setWrapXRotation, meth_QtDataVisualization_Q3DCamera_setWrapXRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setWrapXRotation},
    {sipName_setWrapYRotation, meth_QtDataVisualization_Q3DCamera_setWrapYRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setWrapYRotation},
    {sipName_setXRotation, meth_QtDataVisualization_Q3DCamera_setXRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setXRotation},
    {sipName_setYRotation, meth_QtDataVisualization_Q3DCamera_setYRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setYRotation},
    {sipName_setZoomLevel, meth_QtDataVisualization_Q3DCamera_setZoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_setZoomLevel},
    {sipName_target, meth_QtDataVisualization_Q3DCamera_target, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_target},
    {sipName_wrapXRotation, meth_QtDataVisualization_Q3DCamera_wrapXRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_wrapXRotation},
    {sipName_wrapYRotation, meth_QtDataVisualization_Q3DCamera_wrapYRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_wrapYRotation},
    {sipName_xRotation, meth_QtDataVisualization_Q3DCamera_xRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_xRotation},
    {sipName_yRotation, meth_QtDataVisualization_Q3DCamera_yRotation, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_yRotation},
    {sipName_zoomLevel, meth_QtDataVisualization_Q3DCamera_zoomLevel, METH_VARARGS, doc_QtDataVisualization_Q3DCamera_zoomLevel}
};

static sipEnumMemberDef enummembers_QtDataVisualization_Q3DCamera[] = {
    {sipName_CameraPresetBehind, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetBehind), 19},
    {sipName_CameraPresetBehindBelow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetBehindBelow), 19},
    {sipName_CameraPresetBehindHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetBehindHigh), 19},
    {sipName_CameraPresetBehindLow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetBehindLow), 19},
    {sipName_CameraPresetDirectlyAbove, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetDirectlyAbove), 19},
    {sipName_CameraPresetDirectlyAboveCCW45, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetDirectlyAboveCCW45), 19},
    {sipName_CameraPresetDirectlyAboveCW45, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetDirectlyAboveCW45), 19},
    {sipName_CameraPresetDirectlyBelow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetDirectlyBelow), 19},
    {sipName_CameraPresetFront, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetFront), 19},
    {sipName_CameraPresetFrontBelow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetFrontBelow), 19},
    {sipName_CameraPresetFrontHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetFrontHigh), 19},
    {sipName_CameraPresetFrontLow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetFrontLow), 19},
    {sipName_CameraPresetIsometricLeft, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetIsometricLeft), 19},
    {sipName_CameraPresetIsometricLeftHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetIsometricLeftHigh), 19},
    {sipName_CameraPresetIsometricRight, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetIsometricRight), 19},
    {sipName_CameraPresetIsometricRightHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetIsometricRightHigh), 19},
    {sipName_CameraPresetLeft, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetLeft), 19},
    {sipName_CameraPresetLeftBelow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetLeftBelow), 19},
    {sipName_CameraPresetLeftHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetLeftHigh), 19},
    {sipName_CameraPresetLeftLow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetLeftLow), 19},
    {sipName_CameraPresetNone, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetNone), 19},
    {sipName_CameraPresetRight, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetRight), 19},
    {sipName_CameraPresetRightBelow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetRightBelow), 19},
    {sipName_CameraPresetRightHigh, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetRightHigh), 19},
    {sipName_CameraPresetRightLow, static_cast<int>(::QtDataVisualization::Q3DCamera::CameraPresetRightLow), 19},
};

PyDoc_STRVAR(doc_QtDataVisualization_Q3DCamera, "\1Q3DCamera(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_Q3DCamera[] = {
    {"targetChanged(QVector3D)", "\1targetChanged(self, target: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxZoomLevelChanged(float)", "\1maxZoomLevelChanged(self, zoomLevel: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minZoomLevelChanged(float)", "\1minZoomLevelChanged(self, zoomLevel: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"wrapYRotationChanged(bool)", "\1wrapYRotationChanged(self, isEnabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"wrapXRotationChanged(bool)", "\1wrapXRotationChanged(self, isEnabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"cameraPresetChanged(Q3DCamera::CameraPreset)|(QtDataVisualization::Q3DCamera::CameraPreset)", "\1cameraPresetChanged(self, preset: Q3DCamera.CameraPreset)", SIP_NULLPTR, SIP_NULLPTR},
    {"zoomLevelChanged(float)", "\1zoomLevelChanged(self, zoomLevel: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"yRotationChanged(float)", "\1yRotationChanged(self, rotation: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"xRotationChanged(float)", "\1xRotationChanged(self, rotation: float)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_Q3DCamera = {
    &::QtDataVisualization::Q3DCamera::staticMetaObject,
    0,
    signals_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DCamera = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__Q3DCamera,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_Q3DCamera,
    },
    {
        sipNameNr_Q3DCamera,
        {0, 0, 1},
        20, methods_QtDataVisualization_Q3DCamera,
        25, enummembers_QtDataVisualization_Q3DCamera,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_Q3DCamera,
    -1,
    -1,
    supers_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR,
    init_type_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR,
    array_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR,
    release_QtDataVisualization_Q3DCamera,
    cast_QtDataVisualization_Q3DCamera,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_Q3DCamera,
    sizeof (::QtDataVisualization::Q3DCamera),
};
