/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 89 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 35 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 157 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 160 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 163 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 166 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 229 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 232 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 372 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 235 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 238 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 259 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 262 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 291 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 294 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 299 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 302 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 305 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 308 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 311 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 314 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 317 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 320 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 323 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 326 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 329 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 332 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 335 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 338 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 341 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQSurface3DSeries.cpp"


class sipQtDataVisualization_QSurface3DSeries : public ::QtDataVisualization::QSurface3DSeries
{
public:
    sipQtDataVisualization_QSurface3DSeries(::QtDataVisualization::QSurfaceDataProxy*, ::QObject*);
    sipQtDataVisualization_QSurface3DSeries(::QObject*);
    virtual ~sipQtDataVisualization_QSurface3DSeries();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QSurface3DSeries(const sipQtDataVisualization_QSurface3DSeries &);
    sipQtDataVisualization_QSurface3DSeries &operator = (const sipQtDataVisualization_QSurface3DSeries &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QSurface3DSeries::sipQtDataVisualization_QSurface3DSeries(::QtDataVisualization::QSurfaceDataProxy*a0, ::QObject*a1): ::QtDataVisualization::QSurface3DSeries(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QSurface3DSeries::sipQtDataVisualization_QSurface3DSeries(::QObject*a0): ::QtDataVisualization::QSurface3DSeries(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QSurface3DSeries::~sipQtDataVisualization_QSurface3DSeries()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QSurface3DSeries::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QSurface3DSeries);

    return ::QtDataVisualization::QSurface3DSeries::metaObject();
}

int sipQtDataVisualization_QSurface3DSeries::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QSurface3DSeries::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QSurface3DSeries, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QSurface3DSeries::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QSurface3DSeries, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QSurface3DSeries::qt_metacast(_clname));
}

void sipQtDataVisualization_QSurface3DSeries::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QSurface3DSeries::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QSurface3DSeries::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QSurface3DSeries::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QSurface3DSeries::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QSurface3DSeries::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QSurface3DSeries::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QSurface3DSeries::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QSurface3DSeries::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QSurface3DSeries::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QSurface3DSeries::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QSurface3DSeries::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtDataVisualization_QSurface3DSeries::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QSurface3DSeries::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setDataProxy, "setDataProxy(self, proxy: QSurfaceDataProxy|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setDataProxy(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setDataProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurfaceDataProxy* a0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, sipType_QtDataVisualization_QSurfaceDataProxy, &a0))
        {
            sipCpp->setDataProxy(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setDataProxy, doc_QtDataVisualization_QSurface3DSeries_setDataProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_dataProxy, "dataProxy(self) -> QSurfaceDataProxy|None");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_dataProxy(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_dataProxy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            ::QtDataVisualization::QSurfaceDataProxy*sipRes;

            sipRes = sipCpp->dataProxy();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QSurfaceDataProxy, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_dataProxy, doc_QtDataVisualization_QSurface3DSeries_dataProxy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setSelectedPoint, "setSelectedPoint(self, position: QPoint)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setSelectedPoint(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setSelectedPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setSelectedPoint(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setSelectedPoint, doc_QtDataVisualization_QSurface3DSeries_setSelectedPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_selectedPoint, "selectedPoint(self) -> QPoint");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_selectedPoint(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_selectedPoint(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->selectedPoint());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_selectedPoint, doc_QtDataVisualization_QSurface3DSeries_selectedPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition, "invalidSelectionPosition() -> QPoint");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(::QtDataVisualization::QSurface3DSeries::invalidSelectionPosition());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_invalidSelectionPosition, doc_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled, "setFlatShadingEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, &a0))
        {
            sipCpp->setFlatShadingEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setFlatShadingEnabled, doc_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled, "isFlatShadingEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFlatShadingEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_isFlatShadingEnabled, doc_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setDrawMode, "setDrawMode(self, mode: QSurface3DSeries.DrawFlags|QSurface3DSeries.DrawFlag)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setDrawMode(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setDrawMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurface3DSeries::DrawFlags* a0;
        int a0State = 0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, &a0, &a0State))
        {
            sipCpp->setDrawMode(*a0);
            sipReleaseType(a0, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setDrawMode, doc_QtDataVisualization_QSurface3DSeries_setDrawMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_drawMode, "drawMode(self) -> QSurface3DSeries.DrawFlags");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_drawMode(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_drawMode(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            ::QtDataVisualization::QSurface3DSeries::DrawFlags*sipRes;

            sipRes = new ::QtDataVisualization::QSurface3DSeries::DrawFlags(sipCpp->drawMode());

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QSurface3DSeries_DrawFlags, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_drawMode, doc_QtDataVisualization_QSurface3DSeries_drawMode);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported, "isFlatShadingSupported(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFlatShadingSupported();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_isFlatShadingSupported, doc_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setTexture, "setTexture(self, texture: QImage)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setTexture(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setTexture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, sipType_QImage, &a0))
        {
            sipCpp->setTexture(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setTexture, doc_QtDataVisualization_QSurface3DSeries_setTexture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_texture, "texture(self) -> QImage");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_texture(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_texture(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            ::QImage*sipRes;

            sipRes = new ::QImage(sipCpp->texture());

            return sipConvertFromNewType(sipRes, sipType_QImage, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_texture, doc_QtDataVisualization_QSurface3DSeries_texture);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_setTextureFile, "setTextureFile(self, filename: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_setTextureFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_setTextureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTextureFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_setTextureFile, doc_QtDataVisualization_QSurface3DSeries_setTextureFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries_textureFile, "textureFile(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QSurface3DSeries_textureFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QSurface3DSeries_textureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QSurface3DSeries *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QSurface3DSeries, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->textureFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QSurface3DSeries, sipName_textureFile, doc_QtDataVisualization_QSurface3DSeries_textureFile);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QSurface3DSeries(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QSurface3DSeries(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QSurface3DSeries *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QSurface3DSeries)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QAbstract3DSeries)->ctd_cast(static_cast< ::QtDataVisualization::QAbstract3DSeries *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QSurface3DSeries(void *, int);}
static void release_QtDataVisualization_QSurface3DSeries(void *sipCppV, int)
{
    ::QtDataVisualization::QSurface3DSeries *sipCpp = reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QSurface3DSeries(Py_ssize_t);}
static void *array_QtDataVisualization_QSurface3DSeries(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QSurface3DSeries[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QSurface3DSeries(void *);}
static void array_delete_QtDataVisualization_QSurface3DSeries(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QSurface3DSeries *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QSurface3DSeries(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QSurface3DSeries(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QSurface3DSeries *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QSurface3DSeries(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QSurface3DSeries(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QSurface3DSeries(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QSurface3DSeries *sipCpp = SIP_NULLPTR;

    {
        ::QtDataVisualization::QSurfaceDataProxy* a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "#J:|JH", sipSelf, sipType_QtDataVisualization_QSurfaceDataProxy, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QSurface3DSeries(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QSurface3DSeries(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QSurface3DSeries[] = {{41, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QSurface3DSeries[] = {
    {sipName_dataProxy, meth_QtDataVisualization_QSurface3DSeries_dataProxy, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_dataProxy},
    {sipName_drawMode, meth_QtDataVisualization_QSurface3DSeries_drawMode, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_drawMode},
    {sipName_invalidSelectionPosition, meth_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_invalidSelectionPosition},
    {sipName_isFlatShadingEnabled, meth_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_isFlatShadingEnabled},
    {sipName_isFlatShadingSupported, meth_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_isFlatShadingSupported},
    {sipName_selectedPoint, meth_QtDataVisualization_QSurface3DSeries_selectedPoint, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_selectedPoint},
    {sipName_setDataProxy, meth_QtDataVisualization_QSurface3DSeries_setDataProxy, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setDataProxy},
    {sipName_setDrawMode, meth_QtDataVisualization_QSurface3DSeries_setDrawMode, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setDrawMode},
    {sipName_setFlatShadingEnabled, meth_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setFlatShadingEnabled},
    {sipName_setSelectedPoint, meth_QtDataVisualization_QSurface3DSeries_setSelectedPoint, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setSelectedPoint},
    {sipName_setTexture, meth_QtDataVisualization_QSurface3DSeries_setTexture, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setTexture},
    {sipName_setTextureFile, meth_QtDataVisualization_QSurface3DSeries_setTextureFile, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_setTextureFile},
    {sipName_texture, meth_QtDataVisualization_QSurface3DSeries_texture, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_texture},
    {sipName_textureFile, meth_QtDataVisualization_QSurface3DSeries_textureFile, METH_VARARGS, doc_QtDataVisualization_QSurface3DSeries_textureFile}
};

static sipEnumMemberDef enummembers_QtDataVisualization_QSurface3DSeries[] = {
    {sipName_DrawSurface, static_cast<int>(::QtDataVisualization::QSurface3DSeries::DrawSurface), 64},
    {sipName_DrawSurfaceAndWireframe, static_cast<int>(::QtDataVisualization::QSurface3DSeries::DrawSurfaceAndWireframe), 64},
    {sipName_DrawWireframe, static_cast<int>(::QtDataVisualization::QSurface3DSeries::DrawWireframe), 64},
};

PyDoc_STRVAR(doc_QtDataVisualization_QSurface3DSeries, "\1QSurface3DSeries(dataProxy: QSurfaceDataProxy|None, parent: QObject|None = None)\n"
"QSurface3DSeries(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QSurface3DSeries[] = {
    {"textureFileChanged(QString)", "\1textureFileChanged(self, filename: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureChanged(QImage)", "\1textureChanged(self, image: QImage)", SIP_NULLPTR, SIP_NULLPTR},
    {"drawModeChanged(QSurface3DSeries::DrawFlags)|(QtDataVisualization::QSurface3DSeries::DrawFlags)", "\1drawModeChanged(self, mode: QSurface3DSeries.DrawFlags|QSurface3DSeries.DrawFlag)", SIP_NULLPTR, SIP_NULLPTR},
    {"flatShadingSupportedChanged(bool)", "\1flatShadingSupportedChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"flatShadingEnabledChanged(bool)", "\1flatShadingEnabledChanged(self, enable: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectedPointChanged(QPoint)", "\1selectedPointChanged(self, position: QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"dataProxyChanged(QSurfaceDataProxy*)|(QtDataVisualization::QSurfaceDataProxy*)", "\1dataProxyChanged(self, proxy: QSurfaceDataProxy|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QSurface3DSeries = {
    &::QtDataVisualization::QSurface3DSeries::staticMetaObject,
    0,
    signals_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QSurface3DSeries,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QSurface3DSeries,
    },
    {
        sipNameNr_QSurface3DSeries,
        {0, 0, 1},
        14, methods_QtDataVisualization_QSurface3DSeries,
        3, enummembers_QtDataVisualization_QSurface3DSeries,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QSurface3DSeries,
    -1,
    -1,
    supers_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR,
    array_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR,
    release_QtDataVisualization_QSurface3DSeries,
    cast_QtDataVisualization_QSurface3DSeries,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QSurface3DSeries,
    sizeof (::QtDataVisualization::QSurface3DSeries),
};
