/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 49 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"

#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 53 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 56 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 61 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 64 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 67 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 70 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 73 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 76 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 79 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 82 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 85 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 88 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 91 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 94 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 97 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 103 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 106 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQAbstract3DAxis.cpp"


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_title, "title(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_title(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_title(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->title());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_title, doc_QtDataVisualization_QAbstract3DAxis_title);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setLabels, "setLabels(self, labels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setLabels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setLabels(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setLabels, doc_QtDataVisualization_QAbstract3DAxis_setLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_labels, "labels(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_labels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_labels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->labels());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_labels, doc_QtDataVisualization_QAbstract3DAxis_labels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_orientation, "orientation(self) -> QAbstract3DAxis.AxisOrientation");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_orientation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_orientation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DAxis::AxisOrientation sipRes;

            sipRes = sipCpp->orientation();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DAxis_AxisOrientation);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_orientation, doc_QtDataVisualization_QAbstract3DAxis_orientation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_type, "type(self) -> QAbstract3DAxis.AxisType");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_type(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            ::QtDataVisualization::QAbstract3DAxis::AxisType sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_QAbstract3DAxis_AxisType);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_type, doc_QtDataVisualization_QAbstract3DAxis_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setMin, "setMin(self, min: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setMin(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setMin(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setMin(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setMin, doc_QtDataVisualization_QAbstract3DAxis_setMin);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_min, "min(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_min(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_min(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->min();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_min, doc_QtDataVisualization_QAbstract3DAxis_min);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setMax, "setMax(self, max: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setMax(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setMax(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setMax(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setMax, doc_QtDataVisualization_QAbstract3DAxis_setMax);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_max, "max(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_max(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_max(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->max();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_max, doc_QtDataVisualization_QAbstract3DAxis_max);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange, "setAutoAdjustRange(self, autoAdjust: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setAutoAdjustRange(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setAutoAdjustRange, doc_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange, "isAutoAdjustRange(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isAutoAdjustRange();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_isAutoAdjustRange, doc_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setRange, "setRange(self, min: float, max: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setRange(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setRange(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        float a1;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bff", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0, &a1))
        {
            sipCpp->setRange(a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setRange, doc_QtDataVisualization_QAbstract3DAxis_setRange);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setTitle, "setTitle(self, title: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTitle(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setTitle, doc_QtDataVisualization_QAbstract3DAxis_setTitle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation, "setLabelAutoRotation(self, angle: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setLabelAutoRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setLabelAutoRotation, doc_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_labelAutoRotation, "labelAutoRotation(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_labelAutoRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_labelAutoRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->labelAutoRotation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_labelAutoRotation, doc_QtDataVisualization_QAbstract3DAxis_labelAutoRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setTitleVisible, "setTitleVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitleVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitleVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setTitleVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setTitleVisible, doc_QtDataVisualization_QAbstract3DAxis_setTitleVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_isTitleVisible, "isTitleVisible(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isTitleVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isTitleVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isTitleVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_isTitleVisible, doc_QtDataVisualization_QAbstract3DAxis_isTitleVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_setTitleFixed, "setTitleFixed(self, fixed: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitleFixed(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_setTitleFixed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp, &a0))
        {
            sipCpp->setTitleFixed(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_setTitleFixed, doc_QtDataVisualization_QAbstract3DAxis_setTitleFixed);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QAbstract3DAxis_isTitleFixed, "isTitleFixed(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isTitleFixed(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QAbstract3DAxis_isTitleFixed(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QAbstract3DAxis *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QAbstract3DAxis, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isTitleFixed();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QAbstract3DAxis, sipName_isTitleFixed, doc_QtDataVisualization_QAbstract3DAxis_isTitleFixed);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QAbstract3DAxis(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QAbstract3DAxis(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QAbstract3DAxis *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DAxis *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QAbstract3DAxis)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QAbstract3DAxis(void *, int);}
static void release_QtDataVisualization_QAbstract3DAxis(void *sipCppV, int)
{
    ::QtDataVisualization::QAbstract3DAxis *sipCpp = reinterpret_cast< ::QtDataVisualization::QAbstract3DAxis *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void dealloc_QtDataVisualization_QAbstract3DAxis(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QAbstract3DAxis(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QAbstract3DAxis(sipGetAddress(sipSelf), 0);
    }
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QAbstract3DAxis[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_QAbstract3DAxis[] = {
    {sipName_isAutoAdjustRange, meth_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_isAutoAdjustRange},
    {sipName_isTitleFixed, meth_QtDataVisualization_QAbstract3DAxis_isTitleFixed, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_isTitleFixed},
    {sipName_isTitleVisible, meth_QtDataVisualization_QAbstract3DAxis_isTitleVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_isTitleVisible},
    {sipName_labelAutoRotation, meth_QtDataVisualization_QAbstract3DAxis_labelAutoRotation, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_labelAutoRotation},
    {sipName_labels, meth_QtDataVisualization_QAbstract3DAxis_labels, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_labels},
    {sipName_max, meth_QtDataVisualization_QAbstract3DAxis_max, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_max},
    {sipName_min, meth_QtDataVisualization_QAbstract3DAxis_min, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_min},
    {sipName_orientation, meth_QtDataVisualization_QAbstract3DAxis_orientation, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_orientation},
    {sipName_setAutoAdjustRange, meth_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setAutoAdjustRange},
    {sipName_setLabelAutoRotation, meth_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setLabelAutoRotation},
    {sipName_setLabels, meth_QtDataVisualization_QAbstract3DAxis_setLabels, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setLabels},
    {sipName_setMax, meth_QtDataVisualization_QAbstract3DAxis_setMax, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setMax},
    {sipName_setMin, meth_QtDataVisualization_QAbstract3DAxis_setMin, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setMin},
    {sipName_setRange, meth_QtDataVisualization_QAbstract3DAxis_setRange, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setRange},
    {sipName_setTitle, meth_QtDataVisualization_QAbstract3DAxis_setTitle, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setTitle},
    {sipName_setTitleFixed, meth_QtDataVisualization_QAbstract3DAxis_setTitleFixed, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setTitleFixed},
    {sipName_setTitleVisible, meth_QtDataVisualization_QAbstract3DAxis_setTitleVisible, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_setTitleVisible},
    {sipName_title, meth_QtDataVisualization_QAbstract3DAxis_title, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_title},
    {sipName_type, meth_QtDataVisualization_QAbstract3DAxis_type, METH_VARARGS, doc_QtDataVisualization_QAbstract3DAxis_type}
};

static sipEnumMemberDef enummembers_QtDataVisualization_QAbstract3DAxis[] = {
    {sipName_AxisOrientationNone, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisOrientationNone), 30},
    {sipName_AxisOrientationX, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisOrientationX), 30},
    {sipName_AxisOrientationY, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisOrientationY), 30},
    {sipName_AxisOrientationZ, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisOrientationZ), 30},
    {sipName_AxisTypeCategory, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisTypeCategory), 31},
    {sipName_AxisTypeNone, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisTypeNone), 31},
    {sipName_AxisTypeValue, static_cast<int>(::QtDataVisualization::QAbstract3DAxis::AxisTypeValue), 31},
};


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QAbstract3DAxis[] = {
    {"titleFixedChanged(bool)", "\1titleFixedChanged(self, fixed: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleVisibilityChanged(bool)", "\1titleVisibilityChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelAutoRotationChanged(float)", "\1labelAutoRotationChanged(self, angle: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"autoAdjustRangeChanged(bool)", "\1autoAdjustRangeChanged(self, autoAdjust: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"rangeChanged(float,float)", "\1rangeChanged(self, min: float, max: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"maxChanged(float)", "\1maxChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"minChanged(float)", "\1minChanged(self, value: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"orientationChanged(QAbstract3DAxis::AxisOrientation)|(QtDataVisualization::QAbstract3DAxis::AxisOrientation)", "\1orientationChanged(self, orientation: QAbstract3DAxis.AxisOrientation)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelsChanged()", "\1labelsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"titleChanged(QString)", "\1titleChanged(self, newTitle: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QAbstract3DAxis = {
    &::QtDataVisualization::QAbstract3DAxis::staticMetaObject,
    0,
    signals_QtDataVisualization_QAbstract3DAxis,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DAxis = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QAbstract3DAxis,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QAbstract3DAxis,
    },
    {
        sipNameNr_QAbstract3DAxis,
        {0, 0, 1},
        19, methods_QtDataVisualization_QAbstract3DAxis,
        7, enummembers_QtDataVisualization_QAbstract3DAxis,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    SIP_NULLPTR,
    -1,
    -1,
    supers_QtDataVisualization_QAbstract3DAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QAbstract3DAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    release_QtDataVisualization_QAbstract3DAxis,
    cast_QtDataVisualization_QAbstract3DAxis,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    0,
};
