/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qutils.sip"
#include <qutils.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxisformatter.sip"
#include <qvalue3daxisformatter.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxisformatter.sip"
#include <qvalue3daxisformatter.h>
#line 101 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 105 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qlocale.sip"
#include <qlocale.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 111 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 134 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qpygui_qvector.sip"
#include <qvector.h>
#line 114 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qutils.sip"
#include <qutils.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 187 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 190 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 195 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 198 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 201 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 204 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 207 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 210 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 213 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 216 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 219 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 222 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 225 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 228 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 231 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 234 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 237 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQValue3DAxisFormatter.cpp"


class sipQtDataVisualization_QValue3DAxisFormatter : public ::QtDataVisualization::QValue3DAxisFormatter
{
public:
    sipQtDataVisualization_QValue3DAxisFormatter(::QObject*);
    virtual ~sipQtDataVisualization_QValue3DAxisFormatter();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void populateCopy(::QtDataVisualization::QValue3DAxisFormatter&) const SIP_OVERRIDE;
    float valueAt(float) const SIP_OVERRIDE;
    float positionAt(float) const SIP_OVERRIDE;
    ::QString stringForValue(::qreal, const ::QString&) const SIP_OVERRIDE;
    void recalculate() SIP_OVERRIDE;
    ::QtDataVisualization::QValue3DAxisFormatter* createNewInstance() const SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QValue3DAxisFormatter(const sipQtDataVisualization_QValue3DAxisFormatter &);
    sipQtDataVisualization_QValue3DAxisFormatter &operator = (const sipQtDataVisualization_QValue3DAxisFormatter &);

    char sipPyMethods[13];
};

sipQtDataVisualization_QValue3DAxisFormatter::sipQtDataVisualization_QValue3DAxisFormatter(::QObject*a0): ::QtDataVisualization::QValue3DAxisFormatter(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QValue3DAxisFormatter::~sipQtDataVisualization_QValue3DAxisFormatter()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QValue3DAxisFormatter::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QValue3DAxisFormatter);

    return ::QtDataVisualization::QValue3DAxisFormatter::metaObject();
}

int sipQtDataVisualization_QValue3DAxisFormatter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QValue3DAxisFormatter::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QValue3DAxisFormatter, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QValue3DAxisFormatter::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QValue3DAxisFormatter, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QValue3DAxisFormatter::qt_metacast(_clname));
}

void sipQtDataVisualization_QValue3DAxisFormatter::populateCopy(::QtDataVisualization::QValue3DAxisFormatter& a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[0]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_populateCopy);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::populateCopy(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_28(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QtDataVisualization::QValue3DAxisFormatter&);

    sipVH_QtDataVisualization_28(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

float sipQtDataVisualization_QValue3DAxisFormatter::valueAt(float a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[1]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_valueAt);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::valueAt(a0);

    extern float sipVH_QtDataVisualization_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, float);

    return sipVH_QtDataVisualization_27(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

float sipQtDataVisualization_QValue3DAxisFormatter::positionAt(float a0) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[2]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_positionAt);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::positionAt(a0);

    extern float sipVH_QtDataVisualization_27(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, float);

    return sipVH_QtDataVisualization_27(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

::QString sipQtDataVisualization_QValue3DAxisFormatter::stringForValue(::qreal a0, const ::QString& a1) const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[3]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_stringForValue);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::stringForValue(a0, a1);

    extern ::QString sipVH_QtDataVisualization_26(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::qreal, const ::QString&);

    return sipVH_QtDataVisualization_26(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QValue3DAxisFormatter::recalculate()
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_recalculate);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::recalculate();
        return;
    }

    extern void sipVH_QtDataVisualization_25(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    sipVH_QtDataVisualization_25(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

::QtDataVisualization::QValue3DAxisFormatter* sipQtDataVisualization_QValue3DAxisFormatter::createNewInstance() const
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, const_cast<char *>(&sipPyMethods[5]), const_cast<sipSimpleWrapper **>(&sipPySelf), SIP_NULLPTR, sipName_createNewInstance);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::createNewInstance();

    extern ::QtDataVisualization::QValue3DAxisFormatter* sipVH_QtDataVisualization_24(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *);

    return sipVH_QtDataVisualization_24(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth);
}

bool sipQtDataVisualization_QValue3DAxisFormatter::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QValue3DAxisFormatter::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[7], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QValue3DAxisFormatter::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QValue3DAxisFormatter::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[8], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QValue3DAxisFormatter::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[9], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QValue3DAxisFormatter::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[10], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QValue3DAxisFormatter::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[11], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QValue3DAxisFormatter::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[12], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QValue3DAxisFormatter::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives, "setAllowNegatives(self, allow: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->setAllowNegatives(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_setAllowNegatives, doc_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_allowNegatives, "allowNegatives(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_allowNegatives(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_allowNegatives(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->allowNegatives();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_allowNegatives, doc_QtDataVisualization_QValue3DAxisFormatter_allowNegatives);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_setAllowZero, "setAllowZero(self, allow: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setAllowZero(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setAllowZero(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pb", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->setAllowZero(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_setAllowZero, doc_QtDataVisualization_QValue3DAxisFormatter_setAllowZero);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_allowZero, "allowZero(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_allowZero(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_allowZero(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->allowZero();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_allowZero, doc_QtDataVisualization_QValue3DAxisFormatter_allowZero);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_createNewInstance, "createNewInstance(self) -> QValue3DAxisFormatter|None");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_createNewInstance(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_createNewInstance(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QtDataVisualization::QValue3DAxisFormatter*sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::createNewInstance() : sipCpp->createNewInstance());

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QValue3DAxisFormatter, Py_None);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_createNewInstance, doc_QtDataVisualization_QValue3DAxisFormatter_createNewInstance);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_recalculate, "recalculate(self)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_recalculate(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_recalculate(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::recalculate() : sipCpp->recalculate());

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_recalculate, doc_QtDataVisualization_QValue3DAxisFormatter_recalculate);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_stringForValue, "stringForValue(self, value: float, format: str|None) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_stringForValue(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_stringForValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::qreal a0;
        const ::QString* a1;
        int a1State = 0;
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pdJ1", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0, sipType_QString, &a1, &a1State))
        {
            ::QString*sipRes;

            sipRes = new ::QString((sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::stringForValue(a0, *a1) : sipCpp->stringForValue(a0, *a1)));
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_stringForValue, doc_QtDataVisualization_QValue3DAxisFormatter_stringForValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_positionAt, "positionAt(self, value: float) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_positionAt(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_positionAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        float a0;
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pf", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0))
        {
            float sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::positionAt(a0) : sipCpp->positionAt(a0));

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_positionAt, doc_QtDataVisualization_QValue3DAxisFormatter_positionAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_valueAt, "valueAt(self, position: float) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_valueAt(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_valueAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        float a0;
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pf", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0))
        {
            float sipRes;

            sipRes = (sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::valueAt(a0) : sipCpp->valueAt(a0));

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_valueAt, doc_QtDataVisualization_QValue3DAxisFormatter_valueAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_populateCopy, "populateCopy(self, copy: QValue3DAxisFormatter)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_populateCopy(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_populateCopy(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;
    bool sipSelfWasArg = (!sipSelf || sipIsDerivedClass((sipSimpleWrapper *)sipSelf));

    {
        ::QtDataVisualization::QValue3DAxisFormatter* a0;
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, sipType_QtDataVisualization_QValue3DAxisFormatter, &a0))
        {
            (sipSelfWasArg ? sipCpp->::QtDataVisualization::QValue3DAxisFormatter::populateCopy(*a0) : sipCpp->populateCopy(*a0));

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_populateCopy, doc_QtDataVisualization_QValue3DAxisFormatter_populateCopy);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_markDirty, "markDirty(self, labelsChange: bool = False)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_markDirty(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_markDirty(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 0;
        ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        static const char *sipKwdList[] = {
            sipName_labelsChange,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "p|b", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, &a0))
        {
            sipCpp->markDirty(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_markDirty, doc_QtDataVisualization_QValue3DAxisFormatter_markDirty);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_axis, "axis(self) -> QValue3DAxis|None");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_axis(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_axis(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QtDataVisualization::QValue3DAxis*sipRes;

            sipRes = sipCpp->axis();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QValue3DAxis, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_axis, doc_QtDataVisualization_QValue3DAxisFormatter_axis);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_gridPositions, "gridPositions(self) -> list[float]");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_gridPositions(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_gridPositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QVector<float>*sipRes;

            sipRes = &sipCpp->gridPositions();

            return sipConvertFromType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_gridPositions, doc_QtDataVisualization_QValue3DAxisFormatter_gridPositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_subGridPositions, "subGridPositions(self) -> list[float]");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_subGridPositions(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_subGridPositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QVector<float>*sipRes;

            sipRes = &sipCpp->subGridPositions();

            return sipConvertFromType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_subGridPositions, doc_QtDataVisualization_QValue3DAxisFormatter_subGridPositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_labelPositions, "labelPositions(self) -> list[float]");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_labelPositions(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_labelPositions(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QVector<float>*sipRes;

            sipRes = &sipCpp->labelPositions();

            return sipConvertFromType(sipRes, sipType_QVector_2200, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_labelPositions, doc_QtDataVisualization_QValue3DAxisFormatter_labelPositions);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_labelStrings, "labelStrings(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_labelStrings(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_labelStrings(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = &sipCpp->labelStrings();

            return sipConvertFromType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_labelStrings, doc_QtDataVisualization_QValue3DAxisFormatter_labelStrings);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_setLocale, "setLocale(self, locale: QLocale)");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setLocale(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_setLocale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLocale* a0;
        ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "pJ9", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp, sipType_QLocale, &a0))
        {
            sipCpp->setLocale(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_setLocale, doc_QtDataVisualization_QValue3DAxisFormatter_setLocale);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter_locale, "locale(self) -> QLocale");

extern "C" {static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_locale(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QValue3DAxisFormatter_locale(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QValue3DAxisFormatter *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "p", &sipSelf, sipType_QtDataVisualization_QValue3DAxisFormatter, &sipCpp))
        {
            ::QLocale*sipRes;

            sipRes = new ::QLocale(sipCpp->locale());

            return sipConvertFromNewType(sipRes, sipType_QLocale, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QValue3DAxisFormatter, sipName_locale, doc_QtDataVisualization_QValue3DAxisFormatter_locale);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QValue3DAxisFormatter(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QValue3DAxisFormatter(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QValue3DAxisFormatter *sipCpp = reinterpret_cast< ::QtDataVisualization::QValue3DAxisFormatter *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QValue3DAxisFormatter)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QValue3DAxisFormatter(void *, int);}
static void release_QtDataVisualization_QValue3DAxisFormatter(void *sipCppV, int)
{
    ::QtDataVisualization::QValue3DAxisFormatter *sipCpp = reinterpret_cast< ::QtDataVisualization::QValue3DAxisFormatter *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QValue3DAxisFormatter(Py_ssize_t);}
static void *array_QtDataVisualization_QValue3DAxisFormatter(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QValue3DAxisFormatter[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QValue3DAxisFormatter(void *);}
static void array_delete_QtDataVisualization_QValue3DAxisFormatter(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QValue3DAxisFormatter *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QValue3DAxisFormatter(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QValue3DAxisFormatter(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QValue3DAxisFormatter *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QValue3DAxisFormatter(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QValue3DAxisFormatter(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QValue3DAxisFormatter(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QValue3DAxisFormatter *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QValue3DAxisFormatter(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QValue3DAxisFormatter[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_QValue3DAxisFormatter[] = {
    {sipName_allowNegatives, meth_QtDataVisualization_QValue3DAxisFormatter_allowNegatives, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_allowNegatives},
    {sipName_allowZero, meth_QtDataVisualization_QValue3DAxisFormatter_allowZero, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_allowZero},
    {sipName_axis, meth_QtDataVisualization_QValue3DAxisFormatter_axis, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_axis},
    {sipName_createNewInstance, meth_QtDataVisualization_QValue3DAxisFormatter_createNewInstance, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_createNewInstance},
    {sipName_gridPositions, meth_QtDataVisualization_QValue3DAxisFormatter_gridPositions, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_gridPositions},
    {sipName_labelPositions, meth_QtDataVisualization_QValue3DAxisFormatter_labelPositions, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_labelPositions},
    {sipName_labelStrings, meth_QtDataVisualization_QValue3DAxisFormatter_labelStrings, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_labelStrings},
    {sipName_locale, meth_QtDataVisualization_QValue3DAxisFormatter_locale, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_locale},
    {sipName_markDirty, SIP_MLMETH_CAST(meth_QtDataVisualization_QValue3DAxisFormatter_markDirty), METH_VARARGS|METH_KEYWORDS, doc_QtDataVisualization_QValue3DAxisFormatter_markDirty},
    {sipName_populateCopy, meth_QtDataVisualization_QValue3DAxisFormatter_populateCopy, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_populateCopy},
    {sipName_positionAt, meth_QtDataVisualization_QValue3DAxisFormatter_positionAt, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_positionAt},
    {sipName_recalculate, meth_QtDataVisualization_QValue3DAxisFormatter_recalculate, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_recalculate},
    {sipName_setAllowNegatives, meth_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_setAllowNegatives},
    {sipName_setAllowZero, meth_QtDataVisualization_QValue3DAxisFormatter_setAllowZero, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_setAllowZero},
    {sipName_setLocale, meth_QtDataVisualization_QValue3DAxisFormatter_setLocale, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_setLocale},
    {sipName_stringForValue, meth_QtDataVisualization_QValue3DAxisFormatter_stringForValue, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_stringForValue},
    {sipName_subGridPositions, meth_QtDataVisualization_QValue3DAxisFormatter_subGridPositions, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_subGridPositions},
    {sipName_valueAt, meth_QtDataVisualization_QValue3DAxisFormatter_valueAt, METH_VARARGS, doc_QtDataVisualization_QValue3DAxisFormatter_valueAt}
};

PyDoc_STRVAR(doc_QtDataVisualization_QValue3DAxisFormatter, "\1QValue3DAxisFormatter(parent: QObject|None = None)");


static pyqt5ClassPluginDef plugin_QtDataVisualization_QValue3DAxisFormatter = {
    &::QtDataVisualization::QValue3DAxisFormatter::staticMetaObject,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QValue3DAxisFormatter = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QValue3DAxisFormatter,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QValue3DAxisFormatter,
    },
    {
        sipNameNr_QValue3DAxisFormatter,
        {0, 0, 1},
        18, methods_QtDataVisualization_QValue3DAxisFormatter,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QValue3DAxisFormatter,
    -1,
    -1,
    supers_QtDataVisualization_QValue3DAxisFormatter,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QValue3DAxisFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QValue3DAxisFormatter,
    SIP_NULLPTR,
    array_QtDataVisualization_QValue3DAxisFormatter,
    SIP_NULLPTR,
    release_QtDataVisualization_QValue3DAxisFormatter,
    cast_QtDataVisualization_QValue3DAxisFormatter,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QValue3DAxisFormatter,
    sizeof (::QtDataVisualization::QValue3DAxisFormatter),
};
