/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 61 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataItem.cpp"



PyDoc_STRVAR(doc_QtDataVisualization_QBarDataItem_setValue, "setValue(self, value: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataItem_setValue(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataItem_setValue(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QBarDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QBarDataItem, &sipCpp, &a0))
        {
            sipCpp->setValue(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataItem, sipName_setValue, doc_QtDataVisualization_QBarDataItem_setValue);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataItem_value, "value(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataItem_value(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataItem_value(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->value();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataItem, sipName_value, doc_QtDataVisualization_QBarDataItem_value);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataItem_setRotation, "setRotation(self, angle: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataItem_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataItem_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QBarDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QBarDataItem, &sipCpp, &a0))
        {
            sipCpp->setRotation(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataItem, sipName_setRotation, doc_QtDataVisualization_QBarDataItem_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataItem_rotation, "rotation(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataItem_rotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataItem_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->rotation();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataItem, sipName_rotation, doc_QtDataVisualization_QBarDataItem_rotation);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QBarDataItem(void *, int);}
static void release_QtDataVisualization_QBarDataItem(void *sipCppV, int)
{
    delete reinterpret_cast< ::QtDataVisualization::QBarDataItem *>(sipCppV);
}


extern "C" {static void *array_QtDataVisualization_QBarDataItem(Py_ssize_t);}
static void *array_QtDataVisualization_QBarDataItem(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QBarDataItem[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QBarDataItem(void *);}
static void array_delete_QtDataVisualization_QBarDataItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QBarDataItem *>(sipCpp);
}


extern "C" {static void assign_QtDataVisualization_QBarDataItem(void *, Py_ssize_t, void *);}
static void assign_QtDataVisualization_QBarDataItem(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QtDataVisualization::QBarDataItem *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QtDataVisualization::QBarDataItem *>(sipSrc);
}


extern "C" {static void *copy_QtDataVisualization_QBarDataItem(const void *, Py_ssize_t);}
static void *copy_QtDataVisualization_QBarDataItem(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QtDataVisualization::QBarDataItem(reinterpret_cast<const ::QtDataVisualization::QBarDataItem *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QtDataVisualization_QBarDataItem(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QBarDataItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QBarDataItem(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QtDataVisualization_QBarDataItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QBarDataItem(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QtDataVisualization::QBarDataItem *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QtDataVisualization::QBarDataItem();

            return sipCpp;
        }
    }

    {
        float a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "f", &a0))
        {
            sipCpp = new ::QtDataVisualization::QBarDataItem(a0);

            return sipCpp;
        }
    }

    {
        float a0;
        float a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "ff", &a0, &a1))
        {
            sipCpp = new ::QtDataVisualization::QBarDataItem(a0, a1);

            return sipCpp;
        }
    }

    {
        const ::QtDataVisualization::QBarDataItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QtDataVisualization_QBarDataItem, &a0))
        {
            sipCpp = new ::QtDataVisualization::QBarDataItem(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QtDataVisualization_QBarDataItem[] = {
    {sipName_rotation, meth_QtDataVisualization_QBarDataItem_rotation, METH_VARARGS, doc_QtDataVisualization_QBarDataItem_rotation},
    {sipName_setRotation, meth_QtDataVisualization_QBarDataItem_setRotation, METH_VARARGS, doc_QtDataVisualization_QBarDataItem_setRotation},
    {sipName_setValue, meth_QtDataVisualization_QBarDataItem_setValue, METH_VARARGS, doc_QtDataVisualization_QBarDataItem_setValue},
    {sipName_value, meth_QtDataVisualization_QBarDataItem_value, METH_VARARGS, doc_QtDataVisualization_QBarDataItem_value}
};

PyDoc_STRVAR(doc_QtDataVisualization_QBarDataItem, "\1QBarDataItem()\n"
"QBarDataItem(value: float)\n"
"QBarDataItem(value: float, angle: float)\n"
"QBarDataItem(other: QBarDataItem)");


static pyqt5ClassPluginDef plugin_QtDataVisualization_QBarDataItem = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QBarDataItem,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QBarDataItem,
    },
    {
        sipNameNr_QBarDataItem,
        {0, 0, 1},
        4, methods_QtDataVisualization_QBarDataItem,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QBarDataItem,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QBarDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QBarDataItem,
    assign_QtDataVisualization_QBarDataItem,
    array_QtDataVisualization_QBarDataItem,
    copy_QtDataVisualization_QBarDataItem,
    release_QtDataVisualization_QBarDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QBarDataItem,
    sizeof (::QtDataVisualization::QBarDataItem),
};
