/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 35 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 63 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 67 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 37 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlist.sip"
#include <qlist.h>
#include <qvector.h>
#line 104 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 139 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 36 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstringlist.sip"
#include <qstringlist.h>
#line 142 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qvector.sip"
#include <qvector.h>
#line 145 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 148 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 151 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 182 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 187 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 190 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 193 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 196 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 199 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 205 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 208 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 211 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 214 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 217 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 220 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 223 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 226 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 229 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQBarDataProxy.cpp"


class sipQtDataVisualization_QBarDataProxy : public ::QtDataVisualization::QBarDataProxy
{
public:
    sipQtDataVisualization_QBarDataProxy(::QObject*);
    virtual ~sipQtDataVisualization_QBarDataProxy();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QBarDataProxy(const sipQtDataVisualization_QBarDataProxy &);
    sipQtDataVisualization_QBarDataProxy &operator = (const sipQtDataVisualization_QBarDataProxy &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QBarDataProxy::sipQtDataVisualization_QBarDataProxy(::QObject*a0): ::QtDataVisualization::QBarDataProxy(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QBarDataProxy::~sipQtDataVisualization_QBarDataProxy()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QBarDataProxy::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QBarDataProxy);

    return ::QtDataVisualization::QBarDataProxy::metaObject();
}

int sipQtDataVisualization_QBarDataProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QBarDataProxy::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QBarDataProxy, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QBarDataProxy::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QBarDataProxy, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QBarDataProxy::qt_metacast(_clname));
}

void sipQtDataVisualization_QBarDataProxy::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QBarDataProxy::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QBarDataProxy::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QBarDataProxy::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QBarDataProxy::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QBarDataProxy::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QBarDataProxy::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QBarDataProxy::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QBarDataProxy::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QBarDataProxy::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QBarDataProxy::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QBarDataProxy::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtDataVisualization_QBarDataProxy::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QBarDataProxy::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_rowCount, "rowCount(self) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_rowCount(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_rowCount(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            int sipRes;

            sipRes = sipCpp->rowCount();

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_rowCount, doc_QtDataVisualization_QBarDataProxy_rowCount);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_rowLabels, "rowLabels(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_rowLabels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_rowLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->rowLabels());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_rowLabels, doc_QtDataVisualization_QBarDataProxy_rowLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_setRowLabels, "setRowLabels(self, labels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_setRowLabels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_setRowLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setRowLabels(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_setRowLabels, doc_QtDataVisualization_QBarDataProxy_setRowLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_columnLabels, "columnLabels(self) -> list[str]");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_columnLabels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_columnLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            ::QStringList*sipRes;

            sipRes = new ::QStringList(sipCpp->columnLabels());

            return sipConvertFromNewType(sipRes, sipType_QStringList, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_columnLabels, doc_QtDataVisualization_QBarDataProxy_columnLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_setColumnLabels, "setColumnLabels(self, labels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_setColumnLabels(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_setColumnLabels(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QStringList* a0;
        int a0State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QStringList, &a0, &a0State))
        {
            sipCpp->setColumnLabels(*a0);
            sipReleaseType(const_cast< ::QStringList *>(a0), sipType_QStringList, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_setColumnLabels, doc_QtDataVisualization_QBarDataProxy_setColumnLabels);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_array, "array(self) -> list[list[QBarDataItem]]");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_array(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_array(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            const ::QtDataVisualization::QBarDataArray*sipRes;

            sipRes = sipCpp->array();

            return sipConvertFromType(const_cast< ::QtDataVisualization::QBarDataArray *>(sipRes), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_array, doc_QtDataVisualization_QBarDataProxy_array);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_rowAt, "rowAt(self, rowIndex: int) -> list[QBarDataItem]");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_rowAt(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_rowAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bi", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0))
        {
            const ::QtDataVisualization::QBarDataRow*sipRes;

            sipRes = sipCpp->rowAt(a0);

            return sipConvertFromType(const_cast< ::QtDataVisualization::QBarDataRow *>(sipRes), sipType_QVector_0100QtDataVisualization_QBarDataItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_rowAt, doc_QtDataVisualization_QBarDataProxy_rowAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_itemAt, "itemAt(self, rowIndex: int, columnIndex: int) -> QBarDataItem|None\n"
"itemAt(self, position: QPoint) -> QBarDataItem|None");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_itemAt(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_itemAt(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bii", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, &a1))
        {
            const ::QtDataVisualization::QBarDataItem*sipRes;

            sipRes = sipCpp->itemAt(a0, a1);

            return sipConvertFromType(const_cast< ::QtDataVisualization::QBarDataItem *>(sipRes), sipType_QtDataVisualization_QBarDataItem, SIP_NULLPTR);
        }
    }

    {
        const ::QPoint* a0;
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QPoint, &a0))
        {
            const ::QtDataVisualization::QBarDataItem*sipRes;

            sipRes = sipCpp->itemAt(*a0);

            return sipConvertFromType(const_cast< ::QtDataVisualization::QBarDataItem *>(sipRes), sipType_QtDataVisualization_QBarDataItem, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_itemAt, doc_QtDataVisualization_QBarDataProxy_itemAt);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_resetArray, "resetArray(self)\n"
"resetArray(self, newArray: Iterable[Iterable[QBarDataItem]])\n"
"resetArray(self, newArray: Iterable[Iterable[QBarDataItem]], rowLabels: Iterable[str|None], columnLabels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_resetArray(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_resetArray(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            sipCpp->resetArray();

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QtDataVisualization::QBarDataArray* a0;
        int a0State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State))
        {
            sipCpp->resetArray(a0);
            sipReleaseType(a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        ::QtDataVisualization::QBarDataArray* a0;
        int a0State = 0;
        const ::QStringList* a1;
        int a1State = 0;
        const ::QStringList* a2;
        int a2State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2J1J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State, sipType_QStringList, &a1, &a1State, sipType_QStringList, &a2, &a2State))
        {
            sipCpp->resetArray(a0, *a1, *a2);
            sipReleaseType(a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);
            sipReleaseType(const_cast< ::QStringList *>(a2), sipType_QStringList, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_resetArray, doc_QtDataVisualization_QBarDataProxy_resetArray);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_setRow, "setRow(self, rowIndex: int, row: Iterable[QBarDataItem])\n"
"setRow(self, rowIndex: int, row: Iterable[QBarDataItem], label: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_setRow(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_setRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QBarDataRow* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State))
        {
            sipCpp->setRow(a0, a1);
            sipReleaseType(a1, sipType_QVector_0100QtDataVisualization_QBarDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QtDataVisualization::QBarDataRow* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp->setRow(a0, a1, *a2);
            sipReleaseType(a1, sipType_QVector_0100QtDataVisualization_QBarDataItem, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_setRow, doc_QtDataVisualization_QBarDataProxy_setRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_setRows, "setRows(self, rowIndex: int, rows: Iterable[Iterable[QBarDataItem]])\n"
"setRows(self, rowIndex: int, rows: Iterable[Iterable[QBarDataItem]], labels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_setRows(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_setRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtDataVisualization::QBarDataArray* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State))
        {
            sipCpp->setRows(a0, *a1);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a1), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QtDataVisualization::QBarDataArray* a1;
        int a1State = 0;
        const ::QStringList* a2;
        int a2State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State, sipType_QStringList, &a2, &a2State))
        {
            sipCpp->setRows(a0, *a1, *a2);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a1), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a1State);
            sipReleaseType(const_cast< ::QStringList *>(a2), sipType_QStringList, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_setRows, doc_QtDataVisualization_QBarDataProxy_setRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_setItem, "setItem(self, rowIndex: int, columnIndex: int, item: QBarDataItem)\n"
"setItem(self, position: QPoint, item: QBarDataItem)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_setItem(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_setItem(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        const ::QtDataVisualization::QBarDataItem* a2;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiiJ9", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, &a1, sipType_QtDataVisualization_QBarDataItem, &a2))
        {
            sipCpp->setItem(a0, a1, *a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        const ::QPoint* a0;
        const ::QtDataVisualization::QBarDataItem* a1;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9J9", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QPoint, &a0, sipType_QtDataVisualization_QBarDataItem, &a1))
        {
            sipCpp->setItem(*a0, *a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_setItem, doc_QtDataVisualization_QBarDataProxy_setItem);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_addRow, "addRow(self, row: Iterable[QBarDataItem]) -> int\n"
"addRow(self, row: Iterable[QBarDataItem], label: str|None) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_addRow(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_addRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QBarDataRow* a0;
        int a0State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->addRow(a0);
            sipReleaseType(a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        ::QtDataVisualization::QBarDataRow* a0;
        int a0State = 0;
        const ::QString* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ2J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State, sipType_QString, &a1, &a1State))
        {
            int sipRes;

            sipRes = sipCpp->addRow(a0, *a1);
            sipReleaseType(a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, a0State);
            sipReleaseType(const_cast< ::QString *>(a1), sipType_QString, a1State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_addRow, doc_QtDataVisualization_QBarDataProxy_addRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_addRows, "addRows(self, rows: Iterable[Iterable[QBarDataItem]]) -> int\n"
"addRows(self, rows: Iterable[Iterable[QBarDataItem]], labels: Iterable[str|None]) -> int");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_addRows(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_addRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataArray* a0;
        int a0State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State))
        {
            int sipRes;

            sipRes = sipCpp->addRows(*a0);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a0), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a0State);

            return PyLong_FromLong(sipRes);
        }
    }

    {
        const ::QtDataVisualization::QBarDataArray* a0;
        int a0State = 0;
        const ::QStringList* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a0, &a0State, sipType_QStringList, &a1, &a1State))
        {
            int sipRes;

            sipRes = sipCpp->addRows(*a0, *a1);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a0), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a0State);
            sipReleaseType(const_cast< ::QStringList *>(a1), sipType_QStringList, a1State);

            return PyLong_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_addRows, doc_QtDataVisualization_QBarDataProxy_addRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_insertRow, "insertRow(self, rowIndex: int, row: Iterable[QBarDataItem])\n"
"insertRow(self, rowIndex: int, row: Iterable[QBarDataItem], label: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_insertRow(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_insertRow(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        ::QtDataVisualization::QBarDataRow* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State))
        {
            sipCpp->insertRow(a0, a1);
            sipReleaseType(a1, sipType_QVector_0100QtDataVisualization_QBarDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        ::QtDataVisualization::QBarDataRow* a1;
        int a1State = 0;
        const ::QString* a2;
        int a2State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ2J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State, sipType_QString, &a2, &a2State))
        {
            sipCpp->insertRow(a0, a1, *a2);
            sipReleaseType(a1, sipType_QVector_0100QtDataVisualization_QBarDataItem, a1State);
            sipReleaseType(const_cast< ::QString *>(a2), sipType_QString, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_insertRow, doc_QtDataVisualization_QBarDataProxy_insertRow);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_insertRows, "insertRows(self, rowIndex: int, rows: Iterable[Iterable[QBarDataItem]])\n"
"insertRows(self, rowIndex: int, rows: Iterable[Iterable[QBarDataItem]], labels: Iterable[str|None])");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_insertRows(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_insertRows(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        const ::QtDataVisualization::QBarDataArray* a1;
        int a1State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State))
        {
            sipCpp->insertRows(a0, *a1);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a1), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a1State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    {
        int a0;
        const ::QtDataVisualization::QBarDataArray* a1;
        int a1State = 0;
        const ::QStringList* a2;
        int a2State = 0;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BiJ1J1", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, &a1, &a1State, sipType_QStringList, &a2, &a2State))
        {
            sipCpp->insertRows(a0, *a1, *a2);
            sipReleaseType(const_cast< ::QtDataVisualization::QBarDataArray *>(a1), sipType_QList_0601QVector_0100QtDataVisualization_QBarDataItem, a1State);
            sipReleaseType(const_cast< ::QStringList *>(a2), sipType_QStringList, a2State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_insertRows, doc_QtDataVisualization_QBarDataProxy_insertRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_removeRows, "removeRows(self, rowIndex: int, removeCount: int, removeLabels: bool = True)");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_removeRows(PyObject *, PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_removeRows(PyObject *sipSelf, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        int a0;
        int a1;
        bool a2 = 1;
        ::QtDataVisualization::QBarDataProxy *sipCpp;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_removeLabels,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "Bii|b", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp, &a0, &a1, &a2))
        {
            sipCpp->removeRows(a0, a1, a2);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_removeRows, doc_QtDataVisualization_QBarDataProxy_removeRows);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy_series, "series(self) -> QBar3DSeries|None");

extern "C" {static PyObject *meth_QtDataVisualization_QBarDataProxy_series(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QBarDataProxy_series(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QBarDataProxy *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QBarDataProxy, &sipCpp))
        {
            ::QtDataVisualization::QBar3DSeries*sipRes;

            sipRes = sipCpp->series();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_QBar3DSeries, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QBarDataProxy, sipName_series, doc_QtDataVisualization_QBarDataProxy_series);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QBarDataProxy(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QBarDataProxy(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QBarDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QBarDataProxy *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QBarDataProxy)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QAbstractDataProxy)->ctd_cast(static_cast< ::QtDataVisualization::QAbstractDataProxy *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QBarDataProxy(void *, int);}
static void release_QtDataVisualization_QBarDataProxy(void *sipCppV, int)
{
    ::QtDataVisualization::QBarDataProxy *sipCpp = reinterpret_cast< ::QtDataVisualization::QBarDataProxy *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QBarDataProxy(Py_ssize_t);}
static void *array_QtDataVisualization_QBarDataProxy(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QBarDataProxy[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QBarDataProxy(void *);}
static void array_delete_QtDataVisualization_QBarDataProxy(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QBarDataProxy *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QBarDataProxy(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QBarDataProxy(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QBarDataProxy *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QBarDataProxy(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QBarDataProxy(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QBarDataProxy(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QBarDataProxy *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QBarDataProxy(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QBarDataProxy[] = {{44, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QBarDataProxy[] = {
    {sipName_addRow, meth_QtDataVisualization_QBarDataProxy_addRow, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_addRow},
    {sipName_addRows, meth_QtDataVisualization_QBarDataProxy_addRows, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_addRows},
    {sipName_array, meth_QtDataVisualization_QBarDataProxy_array, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_array},
    {sipName_columnLabels, meth_QtDataVisualization_QBarDataProxy_columnLabels, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_columnLabels},
    {sipName_insertRow, meth_QtDataVisualization_QBarDataProxy_insertRow, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_insertRow},
    {sipName_insertRows, meth_QtDataVisualization_QBarDataProxy_insertRows, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_insertRows},
    {sipName_itemAt, meth_QtDataVisualization_QBarDataProxy_itemAt, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_itemAt},
    {sipName_removeRows, SIP_MLMETH_CAST(meth_QtDataVisualization_QBarDataProxy_removeRows), METH_VARARGS|METH_KEYWORDS, doc_QtDataVisualization_QBarDataProxy_removeRows},
    {sipName_resetArray, meth_QtDataVisualization_QBarDataProxy_resetArray, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_resetArray},
    {sipName_rowAt, meth_QtDataVisualization_QBarDataProxy_rowAt, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_rowAt},
    {sipName_rowCount, meth_QtDataVisualization_QBarDataProxy_rowCount, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_rowCount},
    {sipName_rowLabels, meth_QtDataVisualization_QBarDataProxy_rowLabels, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_rowLabels},
    {sipName_series, meth_QtDataVisualization_QBarDataProxy_series, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_series},
    {sipName_setColumnLabels, meth_QtDataVisualization_QBarDataProxy_setColumnLabels, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_setColumnLabels},
    {sipName_setItem, meth_QtDataVisualization_QBarDataProxy_setItem, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_setItem},
    {sipName_setRow, meth_QtDataVisualization_QBarDataProxy_setRow, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_setRow},
    {sipName_setRowLabels, meth_QtDataVisualization_QBarDataProxy_setRowLabels, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_setRowLabels},
    {sipName_setRows, meth_QtDataVisualization_QBarDataProxy_setRows, METH_VARARGS, doc_QtDataVisualization_QBarDataProxy_setRows}
};

PyDoc_STRVAR(doc_QtDataVisualization_QBarDataProxy, "\1QBarDataProxy(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QBarDataProxy[] = {
    {"seriesChanged(QBar3DSeries*)|(QtDataVisualization::QBar3DSeries*)", "\1seriesChanged(self, series: QBar3DSeries|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"columnLabelsChanged()", "\1columnLabelsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowLabelsChanged()", "\1rowLabelsChanged(self)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowCountChanged(int)", "\1rowCountChanged(self, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"itemChanged(int,int)", "\1itemChanged(self, rowIndex: int, columnIndex: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsInserted(int,int)", "\1rowsInserted(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsRemoved(int,int)", "\1rowsRemoved(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsChanged(int,int)", "\1rowsChanged(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"rowsAdded(int,int)", "\1rowsAdded(self, startIndex: int, count: int)", SIP_NULLPTR, SIP_NULLPTR},
    {"arrayReset()", "\1arrayReset(self)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QBarDataProxy = {
    &::QtDataVisualization::QBarDataProxy::staticMetaObject,
    0,
    signals_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataProxy = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QBarDataProxy,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QBarDataProxy,
    },
    {
        sipNameNr_QBarDataProxy,
        {0, 0, 1},
        18, methods_QtDataVisualization_QBarDataProxy,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QBarDataProxy,
    -1,
    -1,
    supers_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR,
    array_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR,
    release_QtDataVisualization_QBarDataProxy,
    cast_QtDataVisualization_QBarDataProxy,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QBarDataProxy,
    sizeof (::QtDataVisualization::QBarDataProxy),
};
