/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 43 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 47 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 50 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 61 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 68 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qrect.sip"
#include <qrect.h>
#line 71 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 76 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 79 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 82 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 85 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 88 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 91 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 94 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 97 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 103 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 106 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 109 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 112 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 115 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 118 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 121 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DScene.cpp"


class sipQtDataVisualization_Q3DScene : public ::QtDataVisualization::Q3DScene
{
public:
    sipQtDataVisualization_Q3DScene(::QObject*);
    virtual ~sipQtDataVisualization_Q3DScene();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_Q3DScene(const sipQtDataVisualization_Q3DScene &);
    sipQtDataVisualization_Q3DScene &operator = (const sipQtDataVisualization_Q3DScene &);

    char sipPyMethods[7];
};

sipQtDataVisualization_Q3DScene::sipQtDataVisualization_Q3DScene(::QObject*a0): ::QtDataVisualization::Q3DScene(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_Q3DScene::~sipQtDataVisualization_Q3DScene()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_Q3DScene::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_Q3DScene);

    return ::QtDataVisualization::Q3DScene::metaObject();
}

int sipQtDataVisualization_Q3DScene::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::Q3DScene::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_Q3DScene, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_Q3DScene::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_Q3DScene, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::Q3DScene::qt_metacast(_clname));
}

bool sipQtDataVisualization_Q3DScene::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DScene::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_Q3DScene::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DScene::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_Q3DScene::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DScene::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DScene::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DScene::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DScene::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DScene::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DScene::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DScene::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DScene::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DScene::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_viewport, "viewport(self) -> QRect");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_viewport(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_viewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->viewport());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_viewport, doc_QtDataVisualization_Q3DScene_viewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_primarySubViewport, "primarySubViewport(self) -> QRect");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_primarySubViewport(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_primarySubViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->primarySubViewport());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_primarySubViewport, doc_QtDataVisualization_Q3DScene_primarySubViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setPrimarySubViewport, "setPrimarySubViewport(self, primarySubViewport: QRect)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setPrimarySubViewport(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setPrimarySubViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setPrimarySubViewport(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setPrimarySubViewport, doc_QtDataVisualization_Q3DScene_setPrimarySubViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_isPointInPrimarySubView, "isPointInPrimarySubView(self, point: QPoint) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_isPointInPrimarySubView(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_isPointInPrimarySubView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QPoint, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isPointInPrimarySubView(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_isPointInPrimarySubView, doc_QtDataVisualization_Q3DScene_isPointInPrimarySubView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_secondarySubViewport, "secondarySubViewport(self) -> QRect");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_secondarySubViewport(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_secondarySubViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QRect*sipRes;

            sipRes = new ::QRect(sipCpp->secondarySubViewport());

            return sipConvertFromNewType(sipRes, sipType_QRect, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_secondarySubViewport, doc_QtDataVisualization_Q3DScene_secondarySubViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setSecondarySubViewport, "setSecondarySubViewport(self, secondarySubViewport: QRect)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setSecondarySubViewport(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setSecondarySubViewport(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QRect* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QRect, &a0))
        {
            sipCpp->setSecondarySubViewport(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setSecondarySubViewport, doc_QtDataVisualization_Q3DScene_setSecondarySubViewport);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_isPointInSecondarySubView, "isPointInSecondarySubView(self, point: QPoint) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_isPointInSecondarySubView(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_isPointInSecondarySubView(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QPoint, &a0))
        {
            bool sipRes;

            sipRes = sipCpp->isPointInSecondarySubView(*a0);

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_isPointInSecondarySubView, doc_QtDataVisualization_Q3DScene_isPointInSecondarySubView);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setSelectionQueryPosition, "setSelectionQueryPosition(self, point: QPoint)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setSelectionQueryPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setSelectionQueryPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setSelectionQueryPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setSelectionQueryPosition, doc_QtDataVisualization_Q3DScene_setSelectionQueryPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_selectionQueryPosition, "selectionQueryPosition(self) -> QPoint");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_selectionQueryPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_selectionQueryPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->selectionQueryPosition());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_selectionQueryPosition, doc_QtDataVisualization_Q3DScene_selectionQueryPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_invalidSelectionPoint, "invalidSelectionPoint() -> QPoint");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_invalidSelectionPoint(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_invalidSelectionPoint(PyObject *, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        if (sipParseArgs(&sipParseErr, sipArgs, ""))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(::QtDataVisualization::Q3DScene::invalidSelectionPoint());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_invalidSelectionPoint, doc_QtDataVisualization_Q3DScene_invalidSelectionPoint);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setSlicingActive, "setSlicingActive(self, isSlicing: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setSlicingActive(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setSlicingActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, &a0))
        {
            sipCpp->setSlicingActive(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setSlicingActive, doc_QtDataVisualization_Q3DScene_setSlicingActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_isSlicingActive, "isSlicingActive(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_isSlicingActive(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_isSlicingActive(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSlicingActive();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_isSlicingActive, doc_QtDataVisualization_Q3DScene_isSlicingActive);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop, "setSecondarySubviewOnTop(self, isSecondaryOnTop: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, &a0))
        {
            sipCpp->setSecondarySubviewOnTop(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setSecondarySubviewOnTop, doc_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop, "isSecondarySubviewOnTop(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isSecondarySubviewOnTop();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_isSecondarySubviewOnTop, doc_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_activeCamera, "activeCamera(self) -> Q3DCamera|None");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_activeCamera(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_activeCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QtDataVisualization::Q3DCamera*sipRes;

            sipRes = sipCpp->activeCamera();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_Q3DCamera, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_activeCamera, doc_QtDataVisualization_Q3DScene_activeCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setActiveCamera, "setActiveCamera(self, camera: Q3DCamera|None)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setActiveCamera(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setActiveCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DCamera* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QtDataVisualization_Q3DCamera, &a0))
        {
            sipCpp->setActiveCamera(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setActiveCamera, doc_QtDataVisualization_Q3DScene_setActiveCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_activeLight, "activeLight(self) -> Q3DLight|None");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_activeLight(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_activeLight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QtDataVisualization::Q3DLight*sipRes;

            sipRes = sipCpp->activeLight();

            return sipConvertFromType(sipRes, sipType_QtDataVisualization_Q3DLight, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_activeLight, doc_QtDataVisualization_Q3DScene_activeLight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setActiveLight, "setActiveLight(self, light: Q3DLight|None)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setActiveLight(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setActiveLight(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DLight* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ:", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QtDataVisualization_Q3DLight, &a0))
        {
            sipCpp->setActiveLight(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setActiveLight, doc_QtDataVisualization_Q3DScene_setActiveLight);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_devicePixelRatio, "devicePixelRatio(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_devicePixelRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_devicePixelRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->devicePixelRatio();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_devicePixelRatio, doc_QtDataVisualization_Q3DScene_devicePixelRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setDevicePixelRatio, "setDevicePixelRatio(self, pixelRatio: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setDevicePixelRatio(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setDevicePixelRatio(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, &a0))
        {
            sipCpp->setDevicePixelRatio(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setDevicePixelRatio, doc_QtDataVisualization_Q3DScene_setDevicePixelRatio);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_setGraphPositionQuery, "setGraphPositionQuery(self, point: QPoint)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_setGraphPositionQuery(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_setGraphPositionQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QPoint* a0;
        ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp, sipType_QPoint, &a0))
        {
            sipCpp->setGraphPositionQuery(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_setGraphPositionQuery, doc_QtDataVisualization_Q3DScene_setGraphPositionQuery);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene_graphPositionQuery, "graphPositionQuery(self) -> QPoint");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DScene_graphPositionQuery(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DScene_graphPositionQuery(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DScene *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DScene, &sipCpp))
        {
            ::QPoint*sipRes;

            sipRes = new ::QPoint(sipCpp->graphPositionQuery());

            return sipConvertFromNewType(sipRes, sipType_QPoint, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DScene, sipName_graphPositionQuery, doc_QtDataVisualization_Q3DScene_graphPositionQuery);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_Q3DScene(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_Q3DScene(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::Q3DScene *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DScene *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_Q3DScene)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_Q3DScene(void *, int);}
static void release_QtDataVisualization_Q3DScene(void *sipCppV, int)
{
    ::QtDataVisualization::Q3DScene *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DScene *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_Q3DScene(Py_ssize_t);}
static void *array_QtDataVisualization_Q3DScene(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::Q3DScene[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_Q3DScene(void *);}
static void array_delete_QtDataVisualization_Q3DScene(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::Q3DScene *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_Q3DScene(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_Q3DScene(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_Q3DScene *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_Q3DScene(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_Q3DScene(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_Q3DScene(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_Q3DScene *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_Q3DScene(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_Q3DScene[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_Q3DScene[] = {
    {sipName_activeCamera, meth_QtDataVisualization_Q3DScene_activeCamera, METH_VARARGS, doc_QtDataVisualization_Q3DScene_activeCamera},
    {sipName_activeLight, meth_QtDataVisualization_Q3DScene_activeLight, METH_VARARGS, doc_QtDataVisualization_Q3DScene_activeLight},
    {sipName_devicePixelRatio, meth_QtDataVisualization_Q3DScene_devicePixelRatio, METH_VARARGS, doc_QtDataVisualization_Q3DScene_devicePixelRatio},
    {sipName_graphPositionQuery, meth_QtDataVisualization_Q3DScene_graphPositionQuery, METH_VARARGS, doc_QtDataVisualization_Q3DScene_graphPositionQuery},
    {sipName_invalidSelectionPoint, meth_QtDataVisualization_Q3DScene_invalidSelectionPoint, METH_VARARGS, doc_QtDataVisualization_Q3DScene_invalidSelectionPoint},
    {sipName_isPointInPrimarySubView, meth_QtDataVisualization_Q3DScene_isPointInPrimarySubView, METH_VARARGS, doc_QtDataVisualization_Q3DScene_isPointInPrimarySubView},
    {sipName_isPointInSecondarySubView, meth_QtDataVisualization_Q3DScene_isPointInSecondarySubView, METH_VARARGS, doc_QtDataVisualization_Q3DScene_isPointInSecondarySubView},
    {sipName_isSecondarySubviewOnTop, meth_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop, METH_VARARGS, doc_QtDataVisualization_Q3DScene_isSecondarySubviewOnTop},
    {sipName_isSlicingActive, meth_QtDataVisualization_Q3DScene_isSlicingActive, METH_VARARGS, doc_QtDataVisualization_Q3DScene_isSlicingActive},
    {sipName_primarySubViewport, meth_QtDataVisualization_Q3DScene_primarySubViewport, METH_VARARGS, doc_QtDataVisualization_Q3DScene_primarySubViewport},
    {sipName_secondarySubViewport, meth_QtDataVisualization_Q3DScene_secondarySubViewport, METH_VARARGS, doc_QtDataVisualization_Q3DScene_secondarySubViewport},
    {sipName_selectionQueryPosition, meth_QtDataVisualization_Q3DScene_selectionQueryPosition, METH_VARARGS, doc_QtDataVisualization_Q3DScene_selectionQueryPosition},
    {sipName_setActiveCamera, meth_QtDataVisualization_Q3DScene_setActiveCamera, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setActiveCamera},
    {sipName_setActiveLight, meth_QtDataVisualization_Q3DScene_setActiveLight, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setActiveLight},
    {sipName_setDevicePixelRatio, meth_QtDataVisualization_Q3DScene_setDevicePixelRatio, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setDevicePixelRatio},
    {sipName_setGraphPositionQuery, meth_QtDataVisualization_Q3DScene_setGraphPositionQuery, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setGraphPositionQuery},
    {sipName_setPrimarySubViewport, meth_QtDataVisualization_Q3DScene_setPrimarySubViewport, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setPrimarySubViewport},
    {sipName_setSecondarySubViewport, meth_QtDataVisualization_Q3DScene_setSecondarySubViewport, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setSecondarySubViewport},
    {sipName_setSecondarySubviewOnTop, meth_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setSecondarySubviewOnTop},
    {sipName_setSelectionQueryPosition, meth_QtDataVisualization_Q3DScene_setSelectionQueryPosition, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setSelectionQueryPosition},
    {sipName_setSlicingActive, meth_QtDataVisualization_Q3DScene_setSlicingActive, METH_VARARGS, doc_QtDataVisualization_Q3DScene_setSlicingActive},
    {sipName_viewport, meth_QtDataVisualization_Q3DScene_viewport, METH_VARARGS, doc_QtDataVisualization_Q3DScene_viewport}
};

PyDoc_STRVAR(doc_QtDataVisualization_Q3DScene, "\1Q3DScene(parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_Q3DScene[] = {
    {"graphPositionQueryChanged(QPoint)", "\1graphPositionQueryChanged(self, position: QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"selectionQueryPositionChanged(QPoint)", "\1selectionQueryPositionChanged(self, position: QPoint)", SIP_NULLPTR, SIP_NULLPTR},
    {"devicePixelRatioChanged(float)", "\1devicePixelRatioChanged(self, pixelRatio: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeLightChanged(Q3DLight*)|(QtDataVisualization::Q3DLight*)", "\1activeLightChanged(self, light: Q3DLight|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"activeCameraChanged(Q3DCamera*)|(QtDataVisualization::Q3DCamera*)", "\1activeCameraChanged(self, camera: Q3DCamera|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"slicingActiveChanged(bool)", "\1slicingActiveChanged(self, isSlicingActive: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"secondarySubviewOnTopChanged(bool)", "\1secondarySubviewOnTopChanged(self, isSecondaryOnTop: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"secondarySubViewportChanged(QRect)", "\1secondarySubViewportChanged(self, subViewport: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {"primarySubViewportChanged(QRect)", "\1primarySubViewportChanged(self, subViewport: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {"viewportChanged(QRect)", "\1viewportChanged(self, viewport: QRect)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_Q3DScene = {
    &::QtDataVisualization::Q3DScene::staticMetaObject,
    0,
    signals_QtDataVisualization_Q3DScene,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DScene = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__Q3DScene,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_Q3DScene,
    },
    {
        sipNameNr_Q3DScene,
        {0, 0, 1},
        22, methods_QtDataVisualization_Q3DScene,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_Q3DScene,
    -1,
    -1,
    supers_QtDataVisualization_Q3DScene,
    SIP_NULLPTR,
    init_type_QtDataVisualization_Q3DScene,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_Q3DScene,
    SIP_NULLPTR,
    array_QtDataVisualization_Q3DScene,
    SIP_NULLPTR,
    release_QtDataVisualization_Q3DScene,
    cast_QtDataVisualization_Q3DScene,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_Q3DScene,
    sizeof (::QtDataVisualization::Q3DScene),
};
