/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 69 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 73 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 76 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 79 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 82 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 85 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 88 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 91 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 96 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 99 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 102 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 105 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 111 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 114 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 117 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 120 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 123 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 126 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 129 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 132 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 135 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 138 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DLabel.cpp"


class sipQtDataVisualization_QCustom3DLabel : public ::QtDataVisualization::QCustom3DLabel
{
public:
    sipQtDataVisualization_QCustom3DLabel(::QObject*);
    sipQtDataVisualization_QCustom3DLabel(const ::QString&, const ::QFont&, const ::QVector3D&, const ::QVector3D&, const ::QQuaternion&, ::QObject*);
    virtual ~sipQtDataVisualization_QCustom3DLabel();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    bool event(::QEvent*) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QCustom3DLabel(const sipQtDataVisualization_QCustom3DLabel &);
    sipQtDataVisualization_QCustom3DLabel &operator = (const sipQtDataVisualization_QCustom3DLabel &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QCustom3DLabel::sipQtDataVisualization_QCustom3DLabel(::QObject*a0): ::QtDataVisualization::QCustom3DLabel(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DLabel::sipQtDataVisualization_QCustom3DLabel(const ::QString& a0, const ::QFont& a1, const ::QVector3D& a2, const ::QVector3D& a3, const ::QQuaternion& a4, ::QObject*a5): ::QtDataVisualization::QCustom3DLabel(a0, a1, a2, a3, a4, a5), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DLabel::~sipQtDataVisualization_QCustom3DLabel()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QCustom3DLabel::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QCustom3DLabel);

    return ::QtDataVisualization::QCustom3DLabel::metaObject();
}

int sipQtDataVisualization_QCustom3DLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QCustom3DLabel::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QCustom3DLabel, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QCustom3DLabel::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QCustom3DLabel, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QCustom3DLabel::qt_metacast(_clname));
}

void sipQtDataVisualization_QCustom3DLabel::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DLabel::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DLabel::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DLabel::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DLabel::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DLabel::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DLabel::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DLabel::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DLabel::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DLabel::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QCustom3DLabel::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DLabel::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

bool sipQtDataVisualization_QCustom3DLabel::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DLabel::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setText, "setText(self, text: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setText(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setText(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setText(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setText, doc_QtDataVisualization_QCustom3DLabel_setText);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_text, "text(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_text(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_text(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->text());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_text, doc_QtDataVisualization_QCustom3DLabel_text);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setFont, "setFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setFont(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setFont, doc_QtDataVisualization_QCustom3DLabel_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_font(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_font, doc_QtDataVisualization_QCustom3DLabel_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setTextColor, "setTextColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setTextColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setTextColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setTextColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setTextColor, doc_QtDataVisualization_QCustom3DLabel_setTextColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_textColor, "textColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_textColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_textColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->textColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_textColor, doc_QtDataVisualization_QCustom3DLabel_textColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setBackgroundColor, "setBackgroundColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBackgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBackgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBackgroundColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setBackgroundColor, doc_QtDataVisualization_QCustom3DLabel_setBackgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_backgroundColor, "backgroundColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_backgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_backgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->backgroundColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_backgroundColor, doc_QtDataVisualization_QCustom3DLabel_backgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setBorderEnabled, "setBorderEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBorderEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBorderEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, &a0))
        {
            sipCpp->setBorderEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setBorderEnabled, doc_QtDataVisualization_QCustom3DLabel_setBorderEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_isBorderEnabled, "isBorderEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_isBorderEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_isBorderEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBorderEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_isBorderEnabled, doc_QtDataVisualization_QCustom3DLabel_isBorderEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled, "setBackgroundEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, &a0))
        {
            sipCpp->setBackgroundEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setBackgroundEnabled, doc_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled, "isBackgroundEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBackgroundEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_isBackgroundEnabled, doc_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_setFacingCamera, "setFacingCamera(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_setFacingCamera(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_setFacingCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp, &a0))
        {
            sipCpp->setFacingCamera(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_setFacingCamera, doc_QtDataVisualization_QCustom3DLabel_setFacingCamera);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel_isFacingCamera, "isFacingCamera(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DLabel_isFacingCamera(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DLabel_isFacingCamera(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DLabel *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DLabel, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isFacingCamera();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DLabel, sipName_isFacingCamera, doc_QtDataVisualization_QCustom3DLabel_isFacingCamera);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QCustom3DLabel(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QCustom3DLabel(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QCustom3DLabel *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DLabel *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QCustom3DLabel)
        return sipCppV;

    sipCppV = ((const sipClassTypeDef *)sipType_QtDataVisualization_QCustom3DItem)->ctd_cast(static_cast< ::QtDataVisualization::QCustom3DItem *>(sipCpp), targetType);
    if (sipCppV)
        return sipCppV;

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QCustom3DLabel(void *, int);}
static void release_QtDataVisualization_QCustom3DLabel(void *sipCppV, int)
{
    ::QtDataVisualization::QCustom3DLabel *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DLabel *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QCustom3DLabel(Py_ssize_t);}
static void *array_QtDataVisualization_QCustom3DLabel(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QCustom3DLabel[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QCustom3DLabel(void *);}
static void array_delete_QtDataVisualization_QCustom3DLabel(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QCustom3DLabel *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QCustom3DLabel(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QCustom3DLabel(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QCustom3DLabel *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QCustom3DLabel(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QCustom3DLabel(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QCustom3DLabel(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QCustom3DLabel *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DLabel(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QFont* a1;
        const ::QVector3D* a2;
        const ::QVector3D* a3;
        const ::QQuaternion* a4;
        ::QObject* a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1J9J9J9J9|JH", sipType_QString, &a0, &a0State, sipType_QFont, &a1, sipType_QVector3D, &a2, sipType_QVector3D, &a3, sipType_QQuaternion, &a4, sipType_QObject, &a5, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DLabel(*a0, *a1, *a2, *a3, *a4, a5);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QCustom3DLabel[] = {{50, 255, 1}};


static PyMethodDef methods_QtDataVisualization_QCustom3DLabel[] = {
    {sipName_backgroundColor, meth_QtDataVisualization_QCustom3DLabel_backgroundColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_backgroundColor},
    {sipName_font, meth_QtDataVisualization_QCustom3DLabel_font, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_font},
    {sipName_isBackgroundEnabled, meth_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_isBackgroundEnabled},
    {sipName_isBorderEnabled, meth_QtDataVisualization_QCustom3DLabel_isBorderEnabled, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_isBorderEnabled},
    {sipName_isFacingCamera, meth_QtDataVisualization_QCustom3DLabel_isFacingCamera, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_isFacingCamera},
    {sipName_setBackgroundColor, meth_QtDataVisualization_QCustom3DLabel_setBackgroundColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setBackgroundColor},
    {sipName_setBackgroundEnabled, meth_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setBackgroundEnabled},
    {sipName_setBorderEnabled, meth_QtDataVisualization_QCustom3DLabel_setBorderEnabled, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setBorderEnabled},
    {sipName_setFacingCamera, meth_QtDataVisualization_QCustom3DLabel_setFacingCamera, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setFacingCamera},
    {sipName_setFont, meth_QtDataVisualization_QCustom3DLabel_setFont, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setFont},
    {sipName_setText, meth_QtDataVisualization_QCustom3DLabel_setText, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setText},
    {sipName_setTextColor, meth_QtDataVisualization_QCustom3DLabel_setTextColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_setTextColor},
    {sipName_text, meth_QtDataVisualization_QCustom3DLabel_text, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_text},
    {sipName_textColor, meth_QtDataVisualization_QCustom3DLabel_textColor, METH_VARARGS, doc_QtDataVisualization_QCustom3DLabel_textColor}
};

PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DLabel, "\1QCustom3DLabel(parent: QObject|None = None)\n"
"QCustom3DLabel(text: str|None, font: QFont, position: QVector3D, scaling: QVector3D, rotation: QQuaternion, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QCustom3DLabel[] = {
    {"facingCameraChanged(bool)", "\1facingCameraChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"backgroundEnabledChanged(bool)", "\1backgroundEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"borderEnabledChanged(bool)", "\1borderEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"backgroundColorChanged(QColor)", "\1backgroundColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"textColorChanged(QColor)", "\1textColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"fontChanged(QFont)", "\1fontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"textChanged(QString)", "\1textChanged(self, text: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QCustom3DLabel = {
    &::QtDataVisualization::QCustom3DLabel::staticMetaObject,
    0,
    signals_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DLabel = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QCustom3DLabel,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QCustom3DLabel,
    },
    {
        sipNameNr_QCustom3DLabel,
        {0, 0, 1},
        14, methods_QtDataVisualization_QCustom3DLabel,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QCustom3DLabel,
    -1,
    -1,
    supers_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR,
    array_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR,
    release_QtDataVisualization_QCustom3DLabel,
    cast_QtDataVisualization_QCustom3DLabel,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QCustom3DLabel,
    sizeof (::QtDataVisualization::QCustom3DLabel),
};
