/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 67 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 71 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 74 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 77 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 80 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qimage.sip"
#include <qimage.h>
#line 83 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 88 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 91 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 94 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 97 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 100 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 103 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 106 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 109 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 112 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 115 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 118 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 121 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 124 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 127 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 130 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQCustom3DItem.cpp"


class sipQtDataVisualization_QCustom3DItem : public ::QtDataVisualization::QCustom3DItem
{
public:
    sipQtDataVisualization_QCustom3DItem(::QObject*);
    sipQtDataVisualization_QCustom3DItem(const ::QString&, const ::QVector3D&, const ::QVector3D&, const ::QQuaternion&, const ::QImage&, ::QObject*);
    virtual ~sipQtDataVisualization_QCustom3DItem();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_QCustom3DItem(const sipQtDataVisualization_QCustom3DItem &);
    sipQtDataVisualization_QCustom3DItem &operator = (const sipQtDataVisualization_QCustom3DItem &);

    char sipPyMethods[7];
};

sipQtDataVisualization_QCustom3DItem::sipQtDataVisualization_QCustom3DItem(::QObject*a0): ::QtDataVisualization::QCustom3DItem(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DItem::sipQtDataVisualization_QCustom3DItem(const ::QString& a0, const ::QVector3D& a1, const ::QVector3D& a2, const ::QQuaternion& a3, const ::QImage& a4, ::QObject*a5): ::QtDataVisualization::QCustom3DItem(a0, a1, a2, a3, a4, a5), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_QCustom3DItem::~sipQtDataVisualization_QCustom3DItem()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_QCustom3DItem::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_QCustom3DItem);

    return ::QtDataVisualization::QCustom3DItem::metaObject();
}

int sipQtDataVisualization_QCustom3DItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::QCustom3DItem::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_QCustom3DItem, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_QCustom3DItem::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_QCustom3DItem, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::QCustom3DItem::qt_metacast(_clname));
}

bool sipQtDataVisualization_QCustom3DItem::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DItem::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_QCustom3DItem::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::QCustom3DItem::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_QCustom3DItem::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DItem::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DItem::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DItem::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DItem::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DItem::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DItem::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DItem::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_QCustom3DItem::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::QCustom3DItem::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setMeshFile, "setMeshFile(self, meshFile: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setMeshFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setMeshFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setMeshFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setMeshFile, doc_QtDataVisualization_QCustom3DItem_setMeshFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_meshFile, "meshFile(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_meshFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_meshFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->meshFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_meshFile, doc_QtDataVisualization_QCustom3DItem_meshFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setTextureFile, "setTextureFile(self, textureFile: str|None)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setTextureFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setTextureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QString* a0;
        int a0State = 0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QString, &a0, &a0State))
        {
            sipCpp->setTextureFile(*a0);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setTextureFile, doc_QtDataVisualization_QCustom3DItem_setTextureFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_textureFile, "textureFile(self) -> str");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_textureFile(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_textureFile(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            ::QString*sipRes;

            sipRes = new ::QString(sipCpp->textureFile());

            return sipConvertFromNewType(sipRes, sipType_QString, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_textureFile, doc_QtDataVisualization_QCustom3DItem_textureFile);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setPosition, "setPosition(self, position: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setPosition, doc_QtDataVisualization_QCustom3DItem_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_position(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_position, doc_QtDataVisualization_QCustom3DItem_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setPositionAbsolute, "setPositionAbsolute(self, positionAbsolute: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setPositionAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setPositionAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, &a0))
        {
            sipCpp->setPositionAbsolute(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setPositionAbsolute, doc_QtDataVisualization_QCustom3DItem_setPositionAbsolute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_isPositionAbsolute, "isPositionAbsolute(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_isPositionAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_isPositionAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isPositionAbsolute();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_isPositionAbsolute, doc_QtDataVisualization_QCustom3DItem_isPositionAbsolute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setScaling, "setScaling(self, scaling: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setScaling(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setScaling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setScaling(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setScaling, doc_QtDataVisualization_QCustom3DItem_setScaling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_scaling, "scaling(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_scaling(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_scaling(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->scaling());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_scaling, doc_QtDataVisualization_QCustom3DItem_scaling);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setRotation, "setRotation(self, rotation: QQuaternion)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setRotation, doc_QtDataVisualization_QCustom3DItem_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_rotation, "rotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_rotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_rotation, doc_QtDataVisualization_QCustom3DItem_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setVisible, "setVisible(self, visible: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, &a0))
        {
            sipCpp->setVisible(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setVisible, doc_QtDataVisualization_QCustom3DItem_setVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_isVisible, "isVisible(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_isVisible(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_isVisible(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isVisible();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_isVisible, doc_QtDataVisualization_QCustom3DItem_isVisible);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setShadowCasting, "setShadowCasting(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setShadowCasting(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setShadowCasting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, &a0))
        {
            sipCpp->setShadowCasting(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setShadowCasting, doc_QtDataVisualization_QCustom3DItem_setShadowCasting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_isShadowCasting, "isShadowCasting(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_isShadowCasting(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_isShadowCasting(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isShadowCasting();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_isShadowCasting, doc_QtDataVisualization_QCustom3DItem_isShadowCasting);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle, "setRotationAxisAndAngle(self, axis: QVector3D, angle: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        float a1;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9f", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QVector3D, &a0, &a1))
        {
            sipCpp->setRotationAxisAndAngle(*a0, a1);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setRotationAxisAndAngle, doc_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setTextureImage, "setTextureImage(self, textureImage: QImage)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setTextureImage(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setTextureImage(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QImage* a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, sipType_QImage, &a0))
        {
            sipCpp->setTextureImage(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setTextureImage, doc_QtDataVisualization_QCustom3DItem_setTextureImage);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_setScalingAbsolute, "setScalingAbsolute(self, scalingAbsolute: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_setScalingAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_setScalingAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp, &a0))
        {
            sipCpp->setScalingAbsolute(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_setScalingAbsolute, doc_QtDataVisualization_QCustom3DItem_setScalingAbsolute);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem_isScalingAbsolute, "isScalingAbsolute(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_QCustom3DItem_isScalingAbsolute(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QCustom3DItem_isScalingAbsolute(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QCustom3DItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QCustom3DItem, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isScalingAbsolute();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QCustom3DItem, sipName_isScalingAbsolute, doc_QtDataVisualization_QCustom3DItem_isScalingAbsolute);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_QCustom3DItem(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_QCustom3DItem(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::QCustom3DItem *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DItem *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_QCustom3DItem)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QCustom3DItem(void *, int);}
static void release_QtDataVisualization_QCustom3DItem(void *sipCppV, int)
{
    ::QtDataVisualization::QCustom3DItem *sipCpp = reinterpret_cast< ::QtDataVisualization::QCustom3DItem *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_QCustom3DItem(Py_ssize_t);}
static void *array_QtDataVisualization_QCustom3DItem(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QCustom3DItem[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QCustom3DItem(void *);}
static void array_delete_QtDataVisualization_QCustom3DItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QCustom3DItem *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_QCustom3DItem(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QCustom3DItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_QCustom3DItem *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QCustom3DItem(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_QCustom3DItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QCustom3DItem(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_QCustom3DItem *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DItem(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        const ::QString* a0;
        int a0State = 0;
        const ::QVector3D* a1;
        const ::QVector3D* a2;
        const ::QQuaternion* a3;
        const ::QImage* a4;
        ::QObject* a5 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "J1J9J9J9J9|JH", sipType_QString, &a0, &a0State, sipType_QVector3D, &a1, sipType_QVector3D, &a2, sipType_QQuaternion, &a3, sipType_QImage, &a4, sipType_QObject, &a5, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_QCustom3DItem(*a0, *a1, *a2, *a3, *a4, a5);
            sipReleaseType(const_cast< ::QString *>(a0), sipType_QString, a0State);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_QCustom3DItem[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_QCustom3DItem[] = {
    {sipName_isPositionAbsolute, meth_QtDataVisualization_QCustom3DItem_isPositionAbsolute, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_isPositionAbsolute},
    {sipName_isScalingAbsolute, meth_QtDataVisualization_QCustom3DItem_isScalingAbsolute, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_isScalingAbsolute},
    {sipName_isShadowCasting, meth_QtDataVisualization_QCustom3DItem_isShadowCasting, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_isShadowCasting},
    {sipName_isVisible, meth_QtDataVisualization_QCustom3DItem_isVisible, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_isVisible},
    {sipName_meshFile, meth_QtDataVisualization_QCustom3DItem_meshFile, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_meshFile},
    {sipName_position, meth_QtDataVisualization_QCustom3DItem_position, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_position},
    {sipName_rotation, meth_QtDataVisualization_QCustom3DItem_rotation, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_rotation},
    {sipName_scaling, meth_QtDataVisualization_QCustom3DItem_scaling, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_scaling},
    {sipName_setMeshFile, meth_QtDataVisualization_QCustom3DItem_setMeshFile, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setMeshFile},
    {sipName_setPosition, meth_QtDataVisualization_QCustom3DItem_setPosition, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setPosition},
    {sipName_setPositionAbsolute, meth_QtDataVisualization_QCustom3DItem_setPositionAbsolute, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setPositionAbsolute},
    {sipName_setRotation, meth_QtDataVisualization_QCustom3DItem_setRotation, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setRotation},
    {sipName_setRotationAxisAndAngle, meth_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setRotationAxisAndAngle},
    {sipName_setScaling, meth_QtDataVisualization_QCustom3DItem_setScaling, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setScaling},
    {sipName_setScalingAbsolute, meth_QtDataVisualization_QCustom3DItem_setScalingAbsolute, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setScalingAbsolute},
    {sipName_setShadowCasting, meth_QtDataVisualization_QCustom3DItem_setShadowCasting, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setShadowCasting},
    {sipName_setTextureFile, meth_QtDataVisualization_QCustom3DItem_setTextureFile, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setTextureFile},
    {sipName_setTextureImage, meth_QtDataVisualization_QCustom3DItem_setTextureImage, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setTextureImage},
    {sipName_setVisible, meth_QtDataVisualization_QCustom3DItem_setVisible, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_setVisible},
    {sipName_textureFile, meth_QtDataVisualization_QCustom3DItem_textureFile, METH_VARARGS, doc_QtDataVisualization_QCustom3DItem_textureFile}
};

PyDoc_STRVAR(doc_QtDataVisualization_QCustom3DItem, "\1QCustom3DItem(parent: QObject|None = None)\n"
"QCustom3DItem(meshFile: str|None, position: QVector3D, scaling: QVector3D, rotation: QQuaternion, texture: QImage, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_QCustom3DItem[] = {
    {"scalingAbsoluteChanged(bool)", "\1scalingAbsoluteChanged(self, scalingAbsolute: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"shadowCastingChanged(bool)", "\1shadowCastingChanged(self, shadowCasting: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"visibleChanged(bool)", "\1visibleChanged(self, visible: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"rotationChanged(QQuaternion)", "\1rotationChanged(self, rotation: QQuaternion)", SIP_NULLPTR, SIP_NULLPTR},
    {"scalingChanged(QVector3D)", "\1scalingChanged(self, scaling: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionAbsoluteChanged(bool)", "\1positionAbsoluteChanged(self, positionAbsolute: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"positionChanged(QVector3D)", "\1positionChanged(self, position: QVector3D)", SIP_NULLPTR, SIP_NULLPTR},
    {"textureFileChanged(QString)", "\1textureFileChanged(self, textureFile: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {"meshFileChanged(QString)", "\1meshFileChanged(self, meshFile: str|None)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_QCustom3DItem = {
    &::QtDataVisualization::QCustom3DItem::staticMetaObject,
    0,
    signals_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QCustom3DItem,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QCustom3DItem,
    },
    {
        sipNameNr_QCustom3DItem,
        {0, 0, 1},
        20, methods_QtDataVisualization_QCustom3DItem,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QCustom3DItem,
    -1,
    -1,
    supers_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR,
    array_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR,
    release_QtDataVisualization_QCustom3DItem,
    cast_QtDataVisualization_QCustom3DItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QCustom3DItem,
    sizeof (::QtDataVisualization::QCustom3DItem),
};
