/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 47 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 51 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qfont.sip"
#include <qfont.h>
#line 54 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 372 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qbrush.sip"
#include <qbrush.h>
#line 57 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 60 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qcolor.sip"
#include <qcolor.h>
#line 63 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 66 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 146 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 71 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 74 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 77 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 80 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 83 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 86 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qvariant.sip"
#include <qvariant.h>
#line 89 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 38 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 92 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qbytearray.sip"
#include <qbytearray.h>
#line 95 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 149 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpycore_qlist.sip"
#include <qlist.h>
#line 98 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 101 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qthread.sip"
#include <qthread.h>
#line 104 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qnamespace.sip"
#include <qnamespace.h>
#line 107 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregexp.sip"
#include <qregexp.h>
#line 110 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qregularexpression.sip"
#include <qregularexpression.h>
#line 113 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobjectdefs.sip"
#include <qobjectdefs.h>
#line 116 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQ3DTheme.cpp"


class sipQtDataVisualization_Q3DTheme : public ::QtDataVisualization::Q3DTheme
{
public:
    sipQtDataVisualization_Q3DTheme(::QObject*);
    sipQtDataVisualization_Q3DTheme(::QtDataVisualization::Q3DTheme::Theme, ::QObject*);
    virtual ~sipQtDataVisualization_Q3DTheme();

    int qt_metacall(QMetaObject::Call, int, void **) SIP_OVERRIDE;
    void *qt_metacast(const char *) SIP_OVERRIDE;
    const QMetaObject *metaObject() const SIP_OVERRIDE;

    /*
     * There is a protected method for every virtual method visible from
     * this class.
     */
protected:
    bool event(::QEvent*) SIP_OVERRIDE;
    bool eventFilter(::QObject*, ::QEvent*) SIP_OVERRIDE;
    void timerEvent(::QTimerEvent*) SIP_OVERRIDE;
    void childEvent(::QChildEvent*) SIP_OVERRIDE;
    void customEvent(::QEvent*) SIP_OVERRIDE;
    void connectNotify(const ::QMetaMethod&) SIP_OVERRIDE;
    void disconnectNotify(const ::QMetaMethod&) SIP_OVERRIDE;

public:
    sipSimpleWrapper *sipPySelf;

private:
    sipQtDataVisualization_Q3DTheme(const sipQtDataVisualization_Q3DTheme &);
    sipQtDataVisualization_Q3DTheme &operator = (const sipQtDataVisualization_Q3DTheme &);

    char sipPyMethods[7];
};

sipQtDataVisualization_Q3DTheme::sipQtDataVisualization_Q3DTheme(::QObject*a0): ::QtDataVisualization::Q3DTheme(a0), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_Q3DTheme::sipQtDataVisualization_Q3DTheme(::QtDataVisualization::Q3DTheme::Theme a0, ::QObject*a1): ::QtDataVisualization::Q3DTheme(a0, a1), sipPySelf(SIP_NULLPTR)
{
    memset(sipPyMethods, 0, sizeof (sipPyMethods));
}

sipQtDataVisualization_Q3DTheme::~sipQtDataVisualization_Q3DTheme()
{
    sipInstanceDestroyedEx(&sipPySelf);
}

const QMetaObject *sipQtDataVisualization_Q3DTheme::metaObject() const
{
    if (sipGetInterpreter())
        return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : sip_QtDataVisualization_qt_metaobject(sipPySelf, sipType_QtDataVisualization_Q3DTheme);

    return ::QtDataVisualization::Q3DTheme::metaObject();
}

int sipQtDataVisualization_Q3DTheme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ::QtDataVisualization::Q3DTheme::qt_metacall(_c, _id, _a);

    if (_id >= 0)
    {
        SIP_BLOCK_THREADS
        _id = sip_QtDataVisualization_qt_metacall(sipPySelf, sipType_QtDataVisualization_Q3DTheme, _c, _id, _a);
        SIP_UNBLOCK_THREADS
    }

    return _id;
}

void *sipQtDataVisualization_Q3DTheme::qt_metacast(const char *_clname)
{
    void *sipCpp;

    return (sip_QtDataVisualization_qt_metacast(sipPySelf, sipType_QtDataVisualization_Q3DTheme, _clname, &sipCpp) ? sipCpp : ::QtDataVisualization::Q3DTheme::qt_metacast(_clname));
}

bool sipQtDataVisualization_Q3DTheme::event(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[0], &sipPySelf, SIP_NULLPTR, sipName_event);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DTheme::event(a0);

    extern bool sipVH_QtDataVisualization_15(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    return sipVH_QtDataVisualization_15(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

bool sipQtDataVisualization_Q3DTheme::eventFilter(::QObject*a0, ::QEvent*a1)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[1], &sipPySelf, SIP_NULLPTR, sipName_eventFilter);

    if (!sipMeth)
        return ::QtDataVisualization::Q3DTheme::eventFilter(a0, a1);

    extern bool sipVH_QtDataVisualization_16(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QObject*, ::QEvent*);

    return sipVH_QtDataVisualization_16(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0, a1);
}

void sipQtDataVisualization_Q3DTheme::timerEvent(::QTimerEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[2], &sipPySelf, SIP_NULLPTR, sipName_timerEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DTheme::timerEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_17(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QTimerEvent*);

    sipVH_QtDataVisualization_17(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DTheme::childEvent(::QChildEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[3], &sipPySelf, SIP_NULLPTR, sipName_childEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DTheme::childEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_18(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QChildEvent*);

    sipVH_QtDataVisualization_18(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DTheme::customEvent(::QEvent*a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[4], &sipPySelf, SIP_NULLPTR, sipName_customEvent);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DTheme::customEvent(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_19(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, ::QEvent*);

    sipVH_QtDataVisualization_19(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DTheme::connectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[5], &sipPySelf, SIP_NULLPTR, sipName_connectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DTheme::connectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}

void sipQtDataVisualization_Q3DTheme::disconnectNotify(const ::QMetaMethod& a0)
{
    sip_gilstate_t sipGILState;
    PyObject *sipMeth;

    sipMeth = sipIsPyMethod(&sipGILState, &sipPyMethods[6], &sipPySelf, SIP_NULLPTR, sipName_disconnectNotify);

    if (!sipMeth)
    {
        ::QtDataVisualization::Q3DTheme::disconnectNotify(a0);
        return;
    }

    extern void sipVH_QtDataVisualization_20(sip_gilstate_t, sipVirtErrorHandlerFunc, sipSimpleWrapper *, PyObject *, const ::QMetaMethod&);

    sipVH_QtDataVisualization_20(sipGILState, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[0].iveh_handler, sipPySelf, sipMeth, a0);
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setType, "setType(self, themeType: Q3DTheme.Theme)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setType(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setType(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme::Theme a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QtDataVisualization_Q3DTheme_Theme, &a0))
        {
            sipCpp->setType(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setType, doc_QtDataVisualization_Q3DTheme_setType);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_type, "type(self) -> Q3DTheme.Theme");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_type(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_type(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QtDataVisualization::Q3DTheme::Theme sipRes;

            sipRes = sipCpp->type();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_Q3DTheme_Theme);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_type, doc_QtDataVisualization_Q3DTheme_type);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setBaseColors, "setBaseColors(self, colors: Iterable[QColor|Qt.GlobalColor])");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setBaseColors(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setBaseColors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QColor>* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QList_0100QColor, &a0, &a0State))
        {
            sipCpp->setBaseColors(*a0);
            sipReleaseType(const_cast<QList< ::QColor> *>(a0), sipType_QList_0100QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setBaseColors, doc_QtDataVisualization_Q3DTheme_setBaseColors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_baseColors, "baseColors(self) -> list[QColor]");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_baseColors(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_baseColors(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            QList< ::QColor>*sipRes;

            sipRes = new QList< ::QColor>(sipCpp->baseColors());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_baseColors, doc_QtDataVisualization_Q3DTheme_baseColors);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setBackgroundColor, "setBackgroundColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setBackgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setBackgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setBackgroundColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setBackgroundColor, doc_QtDataVisualization_Q3DTheme_setBackgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_backgroundColor, "backgroundColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_backgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_backgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->backgroundColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_backgroundColor, doc_QtDataVisualization_Q3DTheme_backgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setWindowColor, "setWindowColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setWindowColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setWindowColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setWindowColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setWindowColor, doc_QtDataVisualization_Q3DTheme_setWindowColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_windowColor, "windowColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_windowColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_windowColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->windowColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_windowColor, doc_QtDataVisualization_Q3DTheme_windowColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLabelTextColor, "setLabelTextColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelTextColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelTextColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelTextColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLabelTextColor, doc_QtDataVisualization_Q3DTheme_setLabelTextColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_labelTextColor, "labelTextColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_labelTextColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_labelTextColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelTextColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_labelTextColor, doc_QtDataVisualization_Q3DTheme_labelTextColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLabelBackgroundColor, "setLabelBackgroundColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBackgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBackgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLabelBackgroundColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLabelBackgroundColor, doc_QtDataVisualization_Q3DTheme_setLabelBackgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_labelBackgroundColor, "labelBackgroundColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_labelBackgroundColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_labelBackgroundColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->labelBackgroundColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_labelBackgroundColor, doc_QtDataVisualization_Q3DTheme_labelBackgroundColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setGridLineColor, "setGridLineColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setGridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setGridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setGridLineColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setGridLineColor, doc_QtDataVisualization_Q3DTheme_setGridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_gridLineColor, "gridLineColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_gridLineColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_gridLineColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->gridLineColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_gridLineColor, doc_QtDataVisualization_Q3DTheme_gridLineColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setSingleHighlightColor, "setSingleHighlightColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setSingleHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setSingleHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setSingleHighlightColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setSingleHighlightColor, doc_QtDataVisualization_Q3DTheme_setSingleHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_singleHighlightColor, "singleHighlightColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_singleHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_singleHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->singleHighlightColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_singleHighlightColor, doc_QtDataVisualization_Q3DTheme_singleHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setMultiHighlightColor, "setMultiHighlightColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setMultiHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setMultiHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setMultiHighlightColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setMultiHighlightColor, doc_QtDataVisualization_Q3DTheme_setMultiHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_multiHighlightColor, "multiHighlightColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_multiHighlightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_multiHighlightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->multiHighlightColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_multiHighlightColor, doc_QtDataVisualization_Q3DTheme_multiHighlightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLightColor, "setLightColor(self, color: QColor|Qt.GlobalColor)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QColor* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QColor, &a0, &a0State))
        {
            sipCpp->setLightColor(*a0);
            sipReleaseType(const_cast< ::QColor *>(a0), sipType_QColor, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLightColor, doc_QtDataVisualization_Q3DTheme_setLightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_lightColor, "lightColor(self) -> QColor");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_lightColor(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_lightColor(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QColor*sipRes;

            sipRes = new ::QColor(sipCpp->lightColor());

            return sipConvertFromNewType(sipRes, sipType_QColor, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_lightColor, doc_QtDataVisualization_Q3DTheme_lightColor);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setBaseGradients, "setBaseGradients(self, gradients: Iterable[QLinearGradient])");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setBaseGradients(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setBaseGradients(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const QList< ::QLinearGradient>* a0;
        int a0State = 0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ1", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QList_0100QLinearGradient, &a0, &a0State))
        {
            sipCpp->setBaseGradients(*a0);
            sipReleaseType(const_cast<QList< ::QLinearGradient> *>(a0), sipType_QList_0100QLinearGradient, a0State);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setBaseGradients, doc_QtDataVisualization_Q3DTheme_setBaseGradients);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_baseGradients, "baseGradients(self) -> list[QLinearGradient]");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_baseGradients(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_baseGradients(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            QList< ::QLinearGradient>*sipRes;

            sipRes = new QList< ::QLinearGradient>(sipCpp->baseGradients());

            return sipConvertFromNewType(sipRes, sipType_QList_0100QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_baseGradients, doc_QtDataVisualization_Q3DTheme_baseGradients);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setSingleHighlightGradient, "setSingleHighlightGradient(self, gradient: QLinearGradient)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setSingleHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setSingleHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLinearGradient* a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QLinearGradient, &a0))
        {
            sipCpp->setSingleHighlightGradient(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setSingleHighlightGradient, doc_QtDataVisualization_Q3DTheme_setSingleHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_singleHighlightGradient, "singleHighlightGradient(self) -> QLinearGradient");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_singleHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_singleHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QLinearGradient*sipRes;

            sipRes = new ::QLinearGradient(sipCpp->singleHighlightGradient());

            return sipConvertFromNewType(sipRes, sipType_QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_singleHighlightGradient, doc_QtDataVisualization_Q3DTheme_singleHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setMultiHighlightGradient, "setMultiHighlightGradient(self, gradient: QLinearGradient)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setMultiHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setMultiHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QLinearGradient* a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QLinearGradient, &a0))
        {
            sipCpp->setMultiHighlightGradient(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setMultiHighlightGradient, doc_QtDataVisualization_Q3DTheme_setMultiHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_multiHighlightGradient, "multiHighlightGradient(self) -> QLinearGradient");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_multiHighlightGradient(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_multiHighlightGradient(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QLinearGradient*sipRes;

            sipRes = new ::QLinearGradient(sipCpp->multiHighlightGradient());

            return sipConvertFromNewType(sipRes, sipType_QLinearGradient, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_multiHighlightGradient, doc_QtDataVisualization_Q3DTheme_multiHighlightGradient);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLightStrength, "setLightStrength(self, strength: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setLightStrength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLightStrength, doc_QtDataVisualization_Q3DTheme_setLightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_lightStrength, "lightStrength(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_lightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_lightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->lightStrength();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_lightStrength, doc_QtDataVisualization_Q3DTheme_lightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setAmbientLightStrength, "setAmbientLightStrength(self, strength: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setAmbientLightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setAmbientLightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setAmbientLightStrength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setAmbientLightStrength, doc_QtDataVisualization_Q3DTheme_setAmbientLightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_ambientLightStrength, "ambientLightStrength(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_ambientLightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_ambientLightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->ambientLightStrength();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_ambientLightStrength, doc_QtDataVisualization_Q3DTheme_ambientLightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setHighlightLightStrength, "setHighlightLightStrength(self, strength: float)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setHighlightLightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setHighlightLightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setHighlightLightStrength(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setHighlightLightStrength, doc_QtDataVisualization_Q3DTheme_setHighlightLightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_highlightLightStrength, "highlightLightStrength(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_highlightLightStrength(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_highlightLightStrength(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->highlightLightStrength();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_highlightLightStrength, doc_QtDataVisualization_Q3DTheme_highlightLightStrength);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLabelBorderEnabled, "setLabelBorderEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBorderEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBorderEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setLabelBorderEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLabelBorderEnabled, doc_QtDataVisualization_Q3DTheme_setLabelBorderEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_isLabelBorderEnabled, "isLabelBorderEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_isLabelBorderEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_isLabelBorderEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLabelBorderEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_isLabelBorderEnabled, doc_QtDataVisualization_Q3DTheme_isLabelBorderEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setFont, "setFont(self, font: QFont)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setFont(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setFont(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QFont* a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QFont, &a0))
        {
            sipCpp->setFont(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setFont, doc_QtDataVisualization_Q3DTheme_setFont);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_font, "font(self) -> QFont");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_font(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_font(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QFont*sipRes;

            sipRes = new ::QFont(sipCpp->font());

            return sipConvertFromNewType(sipRes, sipType_QFont, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_font, doc_QtDataVisualization_Q3DTheme_font);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setBackgroundEnabled, "setBackgroundEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setBackgroundEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setBackgroundEnabled, doc_QtDataVisualization_Q3DTheme_setBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_isBackgroundEnabled, "isBackgroundEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_isBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_isBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isBackgroundEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_isBackgroundEnabled, doc_QtDataVisualization_Q3DTheme_isBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setGridEnabled, "setGridEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setGridEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setGridEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setGridEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setGridEnabled, doc_QtDataVisualization_Q3DTheme_setGridEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_isGridEnabled, "isGridEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_isGridEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_isGridEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isGridEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_isGridEnabled, doc_QtDataVisualization_Q3DTheme_isGridEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled, "setLabelBackgroundEnabled(self, enabled: bool)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bb", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, &a0))
        {
            sipCpp->setLabelBackgroundEnabled(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setLabelBackgroundEnabled, doc_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled, "isLabelBackgroundEnabled(self) -> bool");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            bool sipRes;

            sipRes = sipCpp->isLabelBackgroundEnabled();

            return PyBool_FromLong(sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_isLabelBackgroundEnabled, doc_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_setColorStyle, "setColorStyle(self, style: Q3DTheme.ColorStyle)");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_setColorStyle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_setColorStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::Q3DTheme::ColorStyle a0;
        ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BE", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp, sipType_QtDataVisualization_Q3DTheme_ColorStyle, &a0))
        {
            sipCpp->setColorStyle(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_setColorStyle, doc_QtDataVisualization_Q3DTheme_setColorStyle);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme_colorStyle, "colorStyle(self) -> Q3DTheme.ColorStyle");

extern "C" {static PyObject *meth_QtDataVisualization_Q3DTheme_colorStyle(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_Q3DTheme_colorStyle(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::Q3DTheme *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_Q3DTheme, &sipCpp))
        {
            ::QtDataVisualization::Q3DTheme::ColorStyle sipRes;

            sipRes = sipCpp->colorStyle();

            return sipConvertFromEnum(static_cast<int>(sipRes), sipType_QtDataVisualization_Q3DTheme_ColorStyle);
        }
    }

    sipNoMethod(sipParseErr, sipName_Q3DTheme, sipName_colorStyle, doc_QtDataVisualization_Q3DTheme_colorStyle);

    return SIP_NULLPTR;
}


/* Cast a pointer to a type somewhere in its inheritance hierarchy. */
extern "C" {static void *cast_QtDataVisualization_Q3DTheme(void *, const sipTypeDef *);}
static void *cast_QtDataVisualization_Q3DTheme(void *sipCppV, const sipTypeDef *targetType)
{
    ::QtDataVisualization::Q3DTheme *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DTheme *>(sipCppV);

    if (targetType == sipType_QtDataVisualization_Q3DTheme)
        return sipCppV;

    if (targetType == sipType_QObject)
        return static_cast< ::QObject *>(sipCpp);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_Q3DTheme(void *, int);}
static void release_QtDataVisualization_Q3DTheme(void *sipCppV, int)
{
    ::QtDataVisualization::Q3DTheme *sipCpp = reinterpret_cast< ::QtDataVisualization::Q3DTheme *>(sipCppV);

    if (QThread::currentThread() == sipCpp->thread())
        delete sipCpp;
    else
        sipCpp->deleteLater();
}


extern "C" {static void *array_QtDataVisualization_Q3DTheme(Py_ssize_t);}
static void *array_QtDataVisualization_Q3DTheme(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::Q3DTheme[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_Q3DTheme(void *);}
static void array_delete_QtDataVisualization_Q3DTheme(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::Q3DTheme *>(sipCpp);
}


extern "C" {static void dealloc_QtDataVisualization_Q3DTheme(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_Q3DTheme(sipSimpleWrapper *sipSelf)
{
    if (sipIsDerivedClass(sipSelf))
        reinterpret_cast<sipQtDataVisualization_Q3DTheme *>(sipGetAddress(sipSelf))->sipPySelf = SIP_NULLPTR;

    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_Q3DTheme(sipGetAddress(sipSelf), sipIsDerivedClass(sipSelf));
    }
}


extern "C" {static void *init_type_QtDataVisualization_Q3DTheme(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_Q3DTheme(sipSimpleWrapper *sipSelf, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **sipOwner, PyObject **sipParseErr)
{
    sipQtDataVisualization_Q3DTheme *sipCpp = SIP_NULLPTR;

    {
        ::QObject* a0 = 0;

        static const char *sipKwdList[] = {
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "|JH", sipType_QObject, &a0, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_Q3DTheme(a0);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    {
        ::QtDataVisualization::Q3DTheme::Theme a0;
        ::QObject* a1 = 0;

        static const char *sipKwdList[] = {
            SIP_NULLPTR,
            sipName_parent,
        };

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, sipKwdList, sipUnused, "E|JH", sipType_QtDataVisualization_Q3DTheme_Theme, &a0, sipType_QObject, &a1, sipOwner))
        {
            sipCpp = new sipQtDataVisualization_Q3DTheme(a0, a1);

            sipCpp->sipPySelf = sipSelf;

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


/* Define this type's super-types. */
static sipEncodedTypeDef supers_QtDataVisualization_Q3DTheme[] = {{5, 0, 1}};


static PyMethodDef methods_QtDataVisualization_Q3DTheme[] = {
    {sipName_ambientLightStrength, meth_QtDataVisualization_Q3DTheme_ambientLightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_ambientLightStrength},
    {sipName_backgroundColor, meth_QtDataVisualization_Q3DTheme_backgroundColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_backgroundColor},
    {sipName_baseColors, meth_QtDataVisualization_Q3DTheme_baseColors, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_baseColors},
    {sipName_baseGradients, meth_QtDataVisualization_Q3DTheme_baseGradients, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_baseGradients},
    {sipName_colorStyle, meth_QtDataVisualization_Q3DTheme_colorStyle, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_colorStyle},
    {sipName_font, meth_QtDataVisualization_Q3DTheme_font, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_font},
    {sipName_gridLineColor, meth_QtDataVisualization_Q3DTheme_gridLineColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_gridLineColor},
    {sipName_highlightLightStrength, meth_QtDataVisualization_Q3DTheme_highlightLightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_highlightLightStrength},
    {sipName_isBackgroundEnabled, meth_QtDataVisualization_Q3DTheme_isBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_isBackgroundEnabled},
    {sipName_isGridEnabled, meth_QtDataVisualization_Q3DTheme_isGridEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_isGridEnabled},
    {sipName_isLabelBackgroundEnabled, meth_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_isLabelBackgroundEnabled},
    {sipName_isLabelBorderEnabled, meth_QtDataVisualization_Q3DTheme_isLabelBorderEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_isLabelBorderEnabled},
    {sipName_labelBackgroundColor, meth_QtDataVisualization_Q3DTheme_labelBackgroundColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_labelBackgroundColor},
    {sipName_labelTextColor, meth_QtDataVisualization_Q3DTheme_labelTextColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_labelTextColor},
    {sipName_lightColor, meth_QtDataVisualization_Q3DTheme_lightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_lightColor},
    {sipName_lightStrength, meth_QtDataVisualization_Q3DTheme_lightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_lightStrength},
    {sipName_multiHighlightColor, meth_QtDataVisualization_Q3DTheme_multiHighlightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_multiHighlightColor},
    {sipName_multiHighlightGradient, meth_QtDataVisualization_Q3DTheme_multiHighlightGradient, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_multiHighlightGradient},
    {sipName_setAmbientLightStrength, meth_QtDataVisualization_Q3DTheme_setAmbientLightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setAmbientLightStrength},
    {sipName_setBackgroundColor, meth_QtDataVisualization_Q3DTheme_setBackgroundColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setBackgroundColor},
    {sipName_setBackgroundEnabled, meth_QtDataVisualization_Q3DTheme_setBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setBackgroundEnabled},
    {sipName_setBaseColors, meth_QtDataVisualization_Q3DTheme_setBaseColors, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setBaseColors},
    {sipName_setBaseGradients, meth_QtDataVisualization_Q3DTheme_setBaseGradients, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setBaseGradients},
    {sipName_setColorStyle, meth_QtDataVisualization_Q3DTheme_setColorStyle, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setColorStyle},
    {sipName_setFont, meth_QtDataVisualization_Q3DTheme_setFont, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setFont},
    {sipName_setGridEnabled, meth_QtDataVisualization_Q3DTheme_setGridEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setGridEnabled},
    {sipName_setGridLineColor, meth_QtDataVisualization_Q3DTheme_setGridLineColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setGridLineColor},
    {sipName_setHighlightLightStrength, meth_QtDataVisualization_Q3DTheme_setHighlightLightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setHighlightLightStrength},
    {sipName_setLabelBackgroundColor, meth_QtDataVisualization_Q3DTheme_setLabelBackgroundColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLabelBackgroundColor},
    {sipName_setLabelBackgroundEnabled, meth_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLabelBackgroundEnabled},
    {sipName_setLabelBorderEnabled, meth_QtDataVisualization_Q3DTheme_setLabelBorderEnabled, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLabelBorderEnabled},
    {sipName_setLabelTextColor, meth_QtDataVisualization_Q3DTheme_setLabelTextColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLabelTextColor},
    {sipName_setLightColor, meth_QtDataVisualization_Q3DTheme_setLightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLightColor},
    {sipName_setLightStrength, meth_QtDataVisualization_Q3DTheme_setLightStrength, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setLightStrength},
    {sipName_setMultiHighlightColor, meth_QtDataVisualization_Q3DTheme_setMultiHighlightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setMultiHighlightColor},
    {sipName_setMultiHighlightGradient, meth_QtDataVisualization_Q3DTheme_setMultiHighlightGradient, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setMultiHighlightGradient},
    {sipName_setSingleHighlightColor, meth_QtDataVisualization_Q3DTheme_setSingleHighlightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setSingleHighlightColor},
    {sipName_setSingleHighlightGradient, meth_QtDataVisualization_Q3DTheme_setSingleHighlightGradient, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setSingleHighlightGradient},
    {sipName_setType, meth_QtDataVisualization_Q3DTheme_setType, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setType},
    {sipName_setWindowColor, meth_QtDataVisualization_Q3DTheme_setWindowColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_setWindowColor},
    {sipName_singleHighlightColor, meth_QtDataVisualization_Q3DTheme_singleHighlightColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_singleHighlightColor},
    {sipName_singleHighlightGradient, meth_QtDataVisualization_Q3DTheme_singleHighlightGradient, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_singleHighlightGradient},
    {sipName_type, meth_QtDataVisualization_Q3DTheme_type, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_type},
    {sipName_windowColor, meth_QtDataVisualization_Q3DTheme_windowColor, METH_VARARGS, doc_QtDataVisualization_Q3DTheme_windowColor}
};

static sipEnumMemberDef enummembers_QtDataVisualization_Q3DTheme[] = {
    {sipName_ColorStyleObjectGradient, static_cast<int>(::QtDataVisualization::Q3DTheme::ColorStyleObjectGradient), 27},
    {sipName_ColorStyleRangeGradient, static_cast<int>(::QtDataVisualization::Q3DTheme::ColorStyleRangeGradient), 27},
    {sipName_ColorStyleUniform, static_cast<int>(::QtDataVisualization::Q3DTheme::ColorStyleUniform), 27},
    {sipName_ThemeArmyBlue, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeArmyBlue), 28},
    {sipName_ThemeDigia, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeDigia), 28},
    {sipName_ThemeEbony, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeEbony), 28},
    {sipName_ThemeIsabelle, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeIsabelle), 28},
    {sipName_ThemePrimaryColors, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemePrimaryColors), 28},
    {sipName_ThemeQt, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeQt), 28},
    {sipName_ThemeRetro, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeRetro), 28},
    {sipName_ThemeStoneMoss, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeStoneMoss), 28},
    {sipName_ThemeUserDefined, static_cast<int>(::QtDataVisualization::Q3DTheme::ThemeUserDefined), 28},
};

PyDoc_STRVAR(doc_QtDataVisualization_Q3DTheme, "\1Q3DTheme(parent: QObject|None = None)\n"
"Q3DTheme(themeType: Q3DTheme.Theme, parent: QObject|None = None)");


/* Define this type's signals. */
static const pyqt5QtSignal signals_QtDataVisualization_Q3DTheme[] = {
    {"colorStyleChanged(Q3DTheme::ColorStyle)|(QtDataVisualization::Q3DTheme::ColorStyle)", "\1colorStyleChanged(self, style: Q3DTheme.ColorStyle)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBackgroundEnabledChanged(bool)", "\1labelBackgroundEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"gridEnabledChanged(bool)", "\1gridEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"backgroundEnabledChanged(bool)", "\1backgroundEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"fontChanged(QFont)", "\1fontChanged(self, font: QFont)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBorderEnabledChanged(bool)", "\1labelBorderEnabledChanged(self, enabled: bool)", SIP_NULLPTR, SIP_NULLPTR},
    {"highlightLightStrengthChanged(float)", "\1highlightLightStrengthChanged(self, strength: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"ambientLightStrengthChanged(float)", "\1ambientLightStrengthChanged(self, strength: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"lightStrengthChanged(float)", "\1lightStrengthChanged(self, strength: float)", SIP_NULLPTR, SIP_NULLPTR},
    {"multiHighlightGradientChanged(QLinearGradient)", "\1multiHighlightGradientChanged(self, gradient: QLinearGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"singleHighlightGradientChanged(QLinearGradient)", "\1singleHighlightGradientChanged(self, gradient: QLinearGradient)", SIP_NULLPTR, SIP_NULLPTR},
    {"baseGradientsChanged(QList<QLinearGradient>)", "\1baseGradientsChanged(self, gradients: Iterable[QLinearGradient])", SIP_NULLPTR, SIP_NULLPTR},
    {"lightColorChanged(QColor)", "\1lightColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"multiHighlightColorChanged(QColor)", "\1multiHighlightColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"singleHighlightColorChanged(QColor)", "\1singleHighlightColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"gridLineColorChanged(QColor)", "\1gridLineColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelBackgroundColorChanged(QColor)", "\1labelBackgroundColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"labelTextColorChanged(QColor)", "\1labelTextColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"windowColorChanged(QColor)", "\1windowColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"backgroundColorChanged(QColor)", "\1backgroundColorChanged(self, color: QColor|Qt.GlobalColor)", SIP_NULLPTR, SIP_NULLPTR},
    {"baseColorsChanged(QList<QColor>)", "\1baseColorsChanged(self, colors: Iterable[QColor|Qt.GlobalColor])", SIP_NULLPTR, SIP_NULLPTR},
    {"typeChanged(Q3DTheme::Theme)|(QtDataVisualization::Q3DTheme::Theme)", "\1typeChanged(self, themeType: Q3DTheme.Theme)", SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


static pyqt5ClassPluginDef plugin_QtDataVisualization_Q3DTheme = {
    &::QtDataVisualization::Q3DTheme::staticMetaObject,
    0,
    signals_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DTheme = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SCC|SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__Q3DTheme,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_Q3DTheme,
    },
    {
        sipNameNr_Q3DTheme,
        {0, 0, 1},
        44, methods_QtDataVisualization_Q3DTheme,
        12, enummembers_QtDataVisualization_Q3DTheme,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_Q3DTheme,
    -1,
    -1,
    supers_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR,
    init_type_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR,
    array_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR,
    release_QtDataVisualization_Q3DTheme,
    cast_QtDataVisualization_Q3DTheme,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_Q3DTheme,
    sizeof (::QtDataVisualization::Q3DTheme),
};
