/*
 * Interface wrapper code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 85 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQScatterDataItem.cpp"

#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qvector3d.sip"
#include <qvector3d.h>
#line 89 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQScatterDataItem.cpp"
#line 30 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qquaternion.sip"
#include <qquaternion.h>
#line 92 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationQtDataVisualizationQScatterDataItem.cpp"


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_setPosition, "setPosition(self, position: QVector3D)");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_setPosition(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_setPosition(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QVector3D* a0;
        ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp, sipType_QVector3D, &a0))
        {
            sipCpp->setPosition(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_setPosition, doc_QtDataVisualization_QScatterDataItem_setPosition);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_position, "position(self) -> QVector3D");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_position(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_position(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp))
        {
            ::QVector3D*sipRes;

            sipRes = new ::QVector3D(sipCpp->position());

            return sipConvertFromNewType(sipRes, sipType_QVector3D, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_position, doc_QtDataVisualization_QScatterDataItem_position);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_setRotation, "setRotation(self, rotation: QQuaternion)");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_setRotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_setRotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QQuaternion* a0;
        ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "BJ9", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp, sipType_QQuaternion, &a0))
        {
            sipCpp->setRotation(*a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_setRotation, doc_QtDataVisualization_QScatterDataItem_setRotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_rotation, "rotation(self) -> QQuaternion");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_rotation(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_rotation(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp))
        {
            ::QQuaternion*sipRes;

            sipRes = new ::QQuaternion(sipCpp->rotation());

            return sipConvertFromNewType(sipRes, sipType_QQuaternion, SIP_NULLPTR);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_rotation, doc_QtDataVisualization_QScatterDataItem_rotation);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_setX, "setX(self, value: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_setX(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_setX(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp, &a0))
        {
            sipCpp->setX(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_setX, doc_QtDataVisualization_QScatterDataItem_setX);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_setY, "setY(self, value: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_setY(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_setY(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp, &a0))
        {
            sipCpp->setY(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_setY, doc_QtDataVisualization_QScatterDataItem_setY);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_setZ, "setZ(self, value: float)");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_setZ(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_setZ(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        float a0;
        ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "Bf", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp, &a0))
        {
            sipCpp->setZ(a0);

            Py_INCREF(Py_None);
            return Py_None;
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_setZ, doc_QtDataVisualization_QScatterDataItem_setZ);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_x, "x(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_x(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_x(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->x();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_x, doc_QtDataVisualization_QScatterDataItem_x);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_y, "y(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_y(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_y(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->y();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_y, doc_QtDataVisualization_QScatterDataItem_y);

    return SIP_NULLPTR;
}


PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem_z, "z(self) -> float");

extern "C" {static PyObject *meth_QtDataVisualization_QScatterDataItem_z(PyObject *, PyObject *);}
static PyObject *meth_QtDataVisualization_QScatterDataItem_z(PyObject *sipSelf, PyObject *sipArgs)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        const ::QtDataVisualization::QScatterDataItem *sipCpp;

        if (sipParseArgs(&sipParseErr, sipArgs, "B", &sipSelf, sipType_QtDataVisualization_QScatterDataItem, &sipCpp))
        {
            float sipRes;

            sipRes = sipCpp->z();

            return PyFloat_FromDouble((double)sipRes);
        }
    }

    sipNoMethod(sipParseErr, sipName_QScatterDataItem, sipName_z, doc_QtDataVisualization_QScatterDataItem_z);

    return SIP_NULLPTR;
}


/* Call the instance's destructor. */
extern "C" {static void release_QtDataVisualization_QScatterDataItem(void *, int);}
static void release_QtDataVisualization_QScatterDataItem(void *sipCppV, int)
{
    delete reinterpret_cast< ::QtDataVisualization::QScatterDataItem *>(sipCppV);
}


extern "C" {static void *array_QtDataVisualization_QScatterDataItem(Py_ssize_t);}
static void *array_QtDataVisualization_QScatterDataItem(Py_ssize_t sipNrElem)
{
    return new ::QtDataVisualization::QScatterDataItem[sipNrElem];
}


extern "C" {static void array_delete_QtDataVisualization_QScatterDataItem(void *);}
static void array_delete_QtDataVisualization_QScatterDataItem(void *sipCpp)
{
    delete[] reinterpret_cast< ::QtDataVisualization::QScatterDataItem *>(sipCpp);
}


extern "C" {static void assign_QtDataVisualization_QScatterDataItem(void *, Py_ssize_t, void *);}
static void assign_QtDataVisualization_QScatterDataItem(void *sipDst, Py_ssize_t sipDstIdx, void *sipSrc)
{
    reinterpret_cast< ::QtDataVisualization::QScatterDataItem *>(sipDst)[sipDstIdx] = *reinterpret_cast< ::QtDataVisualization::QScatterDataItem *>(sipSrc);
}


extern "C" {static void *copy_QtDataVisualization_QScatterDataItem(const void *, Py_ssize_t);}
static void *copy_QtDataVisualization_QScatterDataItem(const void *sipSrc, Py_ssize_t sipSrcIdx)
{
    return new ::QtDataVisualization::QScatterDataItem(reinterpret_cast<const ::QtDataVisualization::QScatterDataItem *>(sipSrc)[sipSrcIdx]);
}


extern "C" {static void dealloc_QtDataVisualization_QScatterDataItem(sipSimpleWrapper *);}
static void dealloc_QtDataVisualization_QScatterDataItem(sipSimpleWrapper *sipSelf)
{
    if (sipIsOwnedByPython(sipSelf))
    {
        release_QtDataVisualization_QScatterDataItem(sipGetAddress(sipSelf), 0);
    }
}


extern "C" {static void *init_type_QtDataVisualization_QScatterDataItem(sipSimpleWrapper *, PyObject *, PyObject *, PyObject **, PyObject **, PyObject **);}
static void *init_type_QtDataVisualization_QScatterDataItem(sipSimpleWrapper *, PyObject *sipArgs, PyObject *sipKwds, PyObject **sipUnused, PyObject **, PyObject **sipParseErr)
{
    ::QtDataVisualization::QScatterDataItem *sipCpp = SIP_NULLPTR;

    {
        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, ""))
        {
            sipCpp = new ::QtDataVisualization::QScatterDataItem();

            return sipCpp;
        }
    }

    {
        const ::QVector3D* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QVector3D, &a0))
        {
            sipCpp = new ::QtDataVisualization::QScatterDataItem(*a0);

            return sipCpp;
        }
    }

    {
        const ::QVector3D* a0;
        const ::QQuaternion* a1;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9J9", sipType_QVector3D, &a0, sipType_QQuaternion, &a1))
        {
            sipCpp = new ::QtDataVisualization::QScatterDataItem(*a0, *a1);

            return sipCpp;
        }
    }

    {
        const ::QtDataVisualization::QScatterDataItem* a0;

        if (sipParseKwdArgs(sipParseErr, sipArgs, sipKwds, SIP_NULLPTR, sipUnused, "J9", sipType_QtDataVisualization_QScatterDataItem, &a0))
        {
            sipCpp = new ::QtDataVisualization::QScatterDataItem(*a0);

            return sipCpp;
        }
    }

    return SIP_NULLPTR;
}


static PyMethodDef methods_QtDataVisualization_QScatterDataItem[] = {
    {sipName_position, meth_QtDataVisualization_QScatterDataItem_position, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_position},
    {sipName_rotation, meth_QtDataVisualization_QScatterDataItem_rotation, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_rotation},
    {sipName_setPosition, meth_QtDataVisualization_QScatterDataItem_setPosition, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_setPosition},
    {sipName_setRotation, meth_QtDataVisualization_QScatterDataItem_setRotation, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_setRotation},
    {sipName_setX, meth_QtDataVisualization_QScatterDataItem_setX, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_setX},
    {sipName_setY, meth_QtDataVisualization_QScatterDataItem_setY, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_setY},
    {sipName_setZ, meth_QtDataVisualization_QScatterDataItem_setZ, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_setZ},
    {sipName_x, meth_QtDataVisualization_QScatterDataItem_x, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_x},
    {sipName_y, meth_QtDataVisualization_QScatterDataItem_y, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_y},
    {sipName_z, meth_QtDataVisualization_QScatterDataItem_z, METH_VARARGS, doc_QtDataVisualization_QScatterDataItem_z}
};

PyDoc_STRVAR(doc_QtDataVisualization_QScatterDataItem, "\1QScatterDataItem()\n"
"QScatterDataItem(position: QVector3D)\n"
"QScatterDataItem(position: QVector3D, rotation: QQuaternion)\n"
"QScatterDataItem(other: QScatterDataItem)");


static pyqt5ClassPluginDef plugin_QtDataVisualization_QScatterDataItem = {
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    SIP_NULLPTR
};


sipClassTypeDef sipTypeDef_QtDataVisualization_QtDataVisualization_QScatterDataItem = {
    {
        -1,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_TYPE_SUPER_INIT|SIP_TYPE_LIMITED_API|SIP_TYPE_CLASS,
        sipNameNr_QtDataVisualization__QScatterDataItem,
        SIP_NULLPTR,
        &plugin_QtDataVisualization_QScatterDataItem,
    },
    {
        sipNameNr_QScatterDataItem,
        {0, 0, 1},
        10, methods_QtDataVisualization_QScatterDataItem,
        0, SIP_NULLPTR,
        0, SIP_NULLPTR,
        {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    },
    doc_QtDataVisualization_QScatterDataItem,
    -1,
    sipNameNr_sip_simplewrapper,
    SIP_NULLPTR,
    SIP_NULLPTR,
    init_type_QtDataVisualization_QScatterDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    dealloc_QtDataVisualization_QScatterDataItem,
    assign_QtDataVisualization_QScatterDataItem,
    array_QtDataVisualization_QScatterDataItem,
    copy_QtDataVisualization_QScatterDataItem,
    release_QtDataVisualization_QScatterDataItem,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    array_delete_QtDataVisualization_QScatterDataItem,
    sizeof (::QtDataVisualization::QScatterDataItem),
};
