/*
 * Module code.
 *
 * Generated by SIP 6.15.3
 *
 * Copyright (c) 2024 Riverbank Computing Limited <info@riverbankcomputing.com>
 * 
 * This file is part of PyQtDataVisualization.
 * 
 * This file may be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file.  Please review the
 * following information to ensure the GNU General Public License version 3.0
 * requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 * 
 * If you do not wish to use this file under the terms of the GPL version 3.0
 * then you may purchase a commercial license.  For more information contact
 * info@riverbankcomputing.com.
 * 
 * This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 * WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 */

#include "sipAPIQtDataVisualization.h"

#line 28 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qobject.sip"
#include <qobject.h>
#line 29 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 54 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 302 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 57 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 726 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 60 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 253 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 63 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 205 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 66 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 363 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 69 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 471 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 72 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 460 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 75 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 384 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 78 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 412 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 81 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 425 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 84 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 795 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qevent.sip"
#include <qevent.h>
#line 87 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurfaceformat.sip"
#include <qsurfaceformat.h>
#line 90 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtGui/qsurface.sip"
#include <qsurface.h>
#line 93 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qsize.sip"
#include <qsize.h>
#line 96 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 99 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 240 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 102 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 252 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qcoreevent.sip"
#include <qcoreevent.h>
#line 105 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qmetaobject.sip"
#include <qmetaobject.h>
#line 108 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 121 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qpoint.sip"
#include <qpoint.h>
#line 124 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qutils.sip"
#include <qutils.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxisformatter.sip"
#include <qvalue3daxisformatter.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxisformatter.sip"
#include <qvalue3daxisformatter.h>
#line 199 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 27 "/usr/lib/python3.14/site-packages/PyQt5/bindings/QtCore/qstring.sip"
#include <qstring.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 207 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 214 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 241 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 250 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 261 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 276 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 293 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 312 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 333 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 358 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 383 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 416 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 451 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 35 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 488 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 527 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 568 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 611 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 208 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 656 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 35 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 723 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 770 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 819 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 880 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 931 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 984 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 34 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 1039 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 1096 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 1155 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 1218 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 1281 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 1346 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 1415 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dbars.sip"
#include <q3dbars.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dcamera.sip"
#include <q3dcamera.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dinputhandler.sip"
#include <q3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dlight.sip"
#include <q3dlight.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dobject.sip"
#include <q3dobject.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscatter.sip"
#include <q3dscatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dscene.sip"
#include <q3dscene.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dsurface.sip"
#include <q3dsurface.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
#include <q3dtheme.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3daxis.sip"
#include <qabstract3daxis.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dgraph.sip"
#include <qabstract3dgraph.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dinputhandler.sip"
#include <qabstract3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstract3dseries.sip"
#include <qabstract3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qabstractdataproxy.sip"
#include <qabstractdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbar3dseries.sip"
#include <qbar3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataitem.sip"
#include <qbardataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qbardataproxy.sip"
#include <qbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcategory3daxis.sip"
#include <qcategory3daxis.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3ditem.sip"
#include <qcustom3ditem.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dlabel.sip"
#include <qcustom3dlabel.h>
#line 202 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qcustom3dvolume.sip"
#include <qcustom3dvolume.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qheightmapsurfacedataproxy.sip"
#include <qheightmapsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelbardataproxy.sip"
#include <qitemmodelbardataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelscatterdataproxy.sip"
#include <qitemmodelscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qitemmodelsurfacedataproxy.sip"
#include <qitemmodelsurfacedataproxy.h>
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qlogvalue3daxisformatter.sip"
#include <qlogvalue3daxisformatter.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatter3dseries.sip"
#include <qscatter3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataitem.sip"
#include <qscatterdataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qscatterdataproxy.sip"
#include <qscatterdataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurface3dseries.sip"
#include <qsurface3dseries.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataitem.sip"
#include <qsurfacedataitem.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qsurfacedataproxy.sip"
#include <qsurfacedataproxy.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtouch3dinputhandler.sip"
#include <qtouch3dinputhandler.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qutils.sip"
#include <qutils.h>
#line 26 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 32 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qvalue3daxis.sip"
#include <qvalue3daxis.h>
#line 1488 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"

/* Define the strings used by this module. */
const char sipStrings_QtDataVisualization[] = {
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', ':', ':', 'M', 'u', 'l', 't', 'i', 'M', 'a', 't', 'c', 'h', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', ':', ':', 'M', 'u', 'l', 't', 'i', 'M', 'a', 't', 'c', 'h', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'i', 'n', 't', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'i', 'n', 't', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', ':', ':', 'I', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', '>', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'A', 'x', 'i', 's', ':', ':', 'A', 'x', 'i', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'F', 'l', 'a', 'g', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', '>', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', ':', ':', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', ':', ':', 'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'D', 'r', 'a', 'w', 'F', 'l', 'a', 'g', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'H', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'S', 'c', 'a', 't', 't', 'e', 'r', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'D', 'r', 'a', 'w', 'F', 'l', 'a', 'g', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'A', 'x', 'i', 's', ':', ':', 'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'L', 'o', 'g', 'V', 'a', 'l', 'u', 'e', '3', 'D', 'A', 'x', 'i', 's', 'F', 'o', 'r', 'm', 'a', 't', 't', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'A', 'x', 'i', 's', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'C', 'a', 'm', 'e', 'r', 'a', ':', ':', 'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', ':', ':', 'M', 'e', 's', 'h', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'u', 's', 't', 'o', 'm', '3', 'D', 'I', 't', 'e', 'm', '*', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'V', 'a', 'l', 'u', 'e', '3', 'D', 'A', 'x', 'i', 's', 'F', 'o', 'r', 'm', 'a', 't', 't', 'e', 'r', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', '*', '>', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'V', 'a', 'l', 'u', 'e', '3', 'D', 'A', 'x', 'i', 's', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'T', 'h', 'e', 'm', 'e', ':', ':', 'C', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'T', 'o', 'u', 'c', 'h', '3', 'D', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'T', 'h', 'e', 'm', 'e', '*', '>', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'G', 'r', 'a', 'p', 'h', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'c', 'a', 't', 't', 'e', 'r', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'T', 'h', 'e', 'm', 'e', ':', ':', 'T', 'h', 'e', 'm', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'A', 'b', 's', 't', 'r', 'a', 'c', 't', '3', 'D', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', '3', 'D', 'A', 'x', 'i', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'u', 's', 't', 'o', 'm', '3', 'D', 'V', 'o', 'l', 'u', 'm', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'u', 's', 't', 'o', 'm', '3', 'D', 'L', 'a', 'b', 'e', 'l', 0,
    'P', 'Y', 'Q', 'T', '_', 'D', 'A', 'T', 'A', 'V', 'I', 'S', 'U', 'A', 'L', 'I', 'Z', 'A', 'T', 'I', 'O', 'N', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', '_', 'S', 'T', 'R', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'C', 'u', 's', 't', 'o', 'm', '3', 'D', 'I', 't', 'e', 'm', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', '3', 'D', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'B', 'a', 'r', 'D', 'a', 't', 'a', 'I', 't', 'e', 'm', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', 'V', 'a', 'l', 'u', 'e', '3', 'D', 'A', 'x', 'i', 's', 0,
    'Q', 'T', 'D', 'A', 'T', 'A', 'V', 'I', 'S', 'U', 'A', 'L', 'I', 'Z', 'A', 'T', 'I', 'O', 'N', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', '_', 'S', 'T', 'R', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'S', 'c', 'a', 't', 't', 'e', 'r', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'l', 'y', 'A', 'b', 'o', 'v', 'e', 'C', 'C', 'W', '4', '5', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'I', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'R', 'i', 'g', 'h', 't', 'H', 'i', 'g', 'h', 0,
    'P', 'Y', 'Q', 'T', '_', 'D', 'A', 'T', 'A', 'V', 'I', 'S', 'U', 'A', 'L', 'I', 'Z', 'A', 'T', 'I', 'O', 'N', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'O', 'b', 'j', 'e', 'c', 't', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'l', 'y', 'A', 'b', 'o', 'v', 'e', 'C', 'W', '4', '5', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'I', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'L', 'e', 'f', 't', 'H', 'i', 'g', 'h', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'L', 'i', 'g', 'h', 't', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'S', 'c', 'e', 'n', 'e', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'T', 'h', 'e', 'm', 'e', 0,
    'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', ':', ':', 'Q', '3', 'D', 'B', 'a', 'r', 's', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'v', 'i', 'e', 'w', 'O', 'n', 'T', 'o', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'Q', 'T', 'D', 'A', 'T', 'A', 'V', 'I', 'S', 'U', 'A', 'L', 'I', 'Z', 'A', 'T', 'I', 'O', 'N', '_', 'V', 'E', 'R', 'S', 'I', 'O', 'N', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 't', 'o', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'l', 'a', 't', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'u', 'e', 'r', 'i', 'e', 'd', 'G', 'r', 'a', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'I', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'R', 'i', 'g', 'h', 't', 0,
    'i', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'S', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'z', 'o', 'o', 'm', 'A', 't', 'T', 'a', 'r', 'g', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'l', 'y', 'A', 'b', 'o', 'v', 'e', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'D', 'i', 'r', 'e', 'c', 't', 'l', 'y', 'B', 'e', 'l', 'o', 'w', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'I', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'L', 'e', 'f', 't', 0,
    'P', 'y', 'Q', 't', '5', '.', 'Q', 't', 'D', 'a', 't', 'a', 'V', 'i', 's', 'u', 'a', 'l', 'i', 'z', 'a', 't', 'i', 'o', 'n', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 't', 'e', 'm', 'R', 'o', 'w', 'A', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'l', 'a', 't', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'l', 'i', 'p', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'G', 'r', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'a', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'P', 'o', 'i', 'n', 't', 'I', 'n', 'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'M', 'a', 't', 'c', 'h', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'S', 'e', 'r', 'i', 'e', 's', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'M', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'u', 's', 'e', 'M', 'o', 'd', 'e', 'l', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 'O', 'b', 'j', 'e', 'c', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'a', 'u', 't', 'o', 'R', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'i', 's', 'L', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'A', 'u', 't', 'o', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'i', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'a', 'd', 'i', 'a', 'l', 'L', 'a', 'b', 'e', 'l', 'O', 'f', 'f', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'v', 'i', 'e', 'w', 'O', 'n', 'T', 'o', 'p', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 'e', 's', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'B', 'e', 'h', 'i', 'n', 'd', 'B', 'e', 'l', 'o', 'w', 0,
    'C', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 'R', 'a', 'n', 'g', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'D', 'r', 'a', 'w', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'A', 'n', 'd', 'W', 'i', 'r', 'e', 'f', 'r', 'a', 'm', 'e', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'S', 'o', 'f', 't', 'M', 'e', 'd', 'i', 'u', 'm', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'P', 'o', 'i', 'n', 't', 'I', 'n', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 0,
    'i', 's', 'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'v', 'i', 'e', 'w', 'O', 'n', 'T', 'o', 'p', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'e', 't', 'S', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 's', 'e', 'H', 'i', 'g', 'h', 'D', 'e', 'f', 'S', 'h', 'a', 'd', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'B', 'e', 'h', 'i', 'n', 'd', 'H', 'i', 'g', 'h', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'F', 'r', 'o', 'n', 't', 'B', 'e', 'l', 'o', 'w', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'B', 'e', 'l', 'o', 'w', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'L', 'i', 'n', 'e', 'a', 'r', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', '>', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'u', 'n', 's', 'i', 'g', 'n', 'e', 'd', ' ', 'c', 'h', 'a', 'r', '>', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 't', 'e', 'm', 'A', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'a', 'l', 'p', 'h', 'a', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 't', 'o', 'A', 'd', 'j', 'u', 's', 't', 'R', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    'i', 's', 'F', 'l', 'a', 't', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'o', 'r', 't', 'h', 'o', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'O', 'p', 'a', 'c', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'c', 'a', 'l', 'i', 'n', 'g', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'E', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'A', 't', 'T', 'a', 'r', 'g', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'u', 'b', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 's', 'e', 'r', 'D', 'e', 'f', 'i', 'n', 'e', 'd', 'M', 'e', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'B', 'e', 'h', 'i', 'n', 'd', 'L', 'o', 'w', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'F', 'r', 'o', 'n', 't', 'H', 'i', 'g', 'h', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'L', 'e', 'f', 't', 'B', 'e', 'l', 'o', 'w', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'H', 'i', 'g', 'h', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'o', 'w', 'A', 'n', 'd', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'S', 'o', 'f', 't', 'H', 'i', 'g', 'h', 0,
    'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    'i', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 'n', 'd', 'e', 'x', 0,
    'i', 'n', 'v', 'a', 'l', 'i', 'd', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'P', 'o', 'i', 'n', 't', 0,
    'i', 's', 'Z', 'o', 'o', 'm', 'A', 't', 'T', 'a', 'r', 'g', 'e', 't', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'T', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'D', 'o', 'u', 'b', 'l', 'e', 'C', 'l', 'i', 'c', 'k', 'E', 'v', 'e', 'n', 't', 0,
    'q', 'D', 'e', 'f', 'a', 'u', 'l', 't', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'S', 'e', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    's', 'e', 't', 'B', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 0,
    's', 'e', 't', 'F', 'l', 'a', 't', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'F', 'l', 'i', 'p', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'G', 'r', 'i', 'd', 0,
    's', 'e', 't', 'G', 'r', 'a', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'B', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'M', 'u', 'l', 't', 'i', 'M', 'a', 't', 'c', 'h', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    's', 'e', 't', 'M', 'u', 'l', 't', 'i', 'S', 'e', 'r', 'i', 'e', 's', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'M', 'o', 'd', 'e', 'l', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'h', 'o', 'w', 'E', 'd', 'g', 'e', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'a', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 'e', 's', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'F', 'r', 'o', 'n', 't', 'L', 'o', 'w', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'L', 'e', 'f', 't', 'H', 'i', 'g', 'h', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'R', 'i', 'g', 'h', 't', 'L', 'o', 'w', 0,
    'I', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 'O', 'n', 'S', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'u', 'l', 't', 'i', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'S', 'o', 'f', 't', 'L', 'o', 'w', 0,
    'a', 'm', 'b', 'i', 'e', 'n', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    'a', 'u', 't', 'o', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'b', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 'F', 'i', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'B', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'R', 'e', 'l', 'a', 't', 'i', 'v', 'e', 0,
    'i', 's', 'F', 'l', 'a', 't', 'S', 'h', 'a', 'd', 'i', 'n', 'g', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'L', 'a', 'b', 'e', 'l', 'B', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'M', 'u', 'l', 't', 'i', 'S', 'e', 'r', 'i', 'e', 's', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 0,
    'l', 'a', 'b', 'e', 'l', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'l', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'e', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'q', 'u', 'e', 'r', 'i', 'e', 'd', 'G', 'r', 'a', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'P', 'o', 'i', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'R', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'A', 'u', 't', 'o', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'i', 'n', 't', 's', 0,
    's', 'e', 't', 'R', 'a', 'd', 'i', 'a', 'l', 'L', 'a', 'b', 'e', 'l', 'O', 'f', 'f', 's', 'e', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 's', 0,
    's', 'h', 'a', 'd', 'o', 'w', 'C', 'a', 's', 't', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'i', 'n', 'g', 'l', 'e', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'l', 'i', 'c', 'i', 'n', 'g', 'A', 'c', 't', 'i', 'v', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'e', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'r', 'a', 'p', 'X', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'r', 'a', 'p', 'Y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'x', 'i', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'N', 'o', 'n', 'e', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'L', 'e', 'f', 't', 'L', 'o', 'w', 0,
    'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'D', 'e', 'f', 'a', 'u', 'l', 't', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 't', 'e', 'm', 'A', 'n', 'd', 'R', 'o', 'w', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'M', 'e', 'd', 'i', 'u', 'm', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 't', 'o', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'r', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'n', 'd', 'e', 'x', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'a', 'c', 'i', 'n', 'g', 'C', 'a', 'm', 'e', 'r', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'm', 'a', 'x', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 's', 'h', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'H', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'I', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'D', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'A', 'x', 'i', 's', 'A', 'n', 'd', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 0,
    's', 'e', 't', 'P', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'I', 'n', 'p', 'u', 't', 'P', 'o', 's', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 's', 0,
    's', 'e', 't', 'U', 's', 'e', 'H', 'i', 'g', 'h', 'D', 'e', 'f', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'e', 'p', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'W', 'i', 'd', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'B', 'e', 'h', 'i', 'n', 'd', 0,
    'I', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 'O', 'n', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 0,
    'O', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'S', 't', 'a', 't', 'i', 'c', 0,
    'T', 'h', 'e', 'm', 'e', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'C', 'o', 'l', 'o', 'r', 's', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'L', 'i', 'g', 'h', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'T', 'h', 'e', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'u', 't', 'o', 'S', 'u', 'b', 'G', 'r', 'i', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'l', 'i', 'p', 'H', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'G', 'r', 'i', 'd', 0,
    'g', 'r', 'a', 'p', 'h', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'Q', 'u', 'e', 'r', 'y', 0,
    'g', 'r', 'i', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'I', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 's', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 0,
    'i', 's', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'u', 'l', 't', 'i', 'M', 'a', 't', 'c', 'h', 'B', 'e', 'h', 'a', 'v', 'i', 'o', 'r', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'u', 'b', 'V', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 'A', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'B', 'a', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'L', 'a', 'b', 'e', 'l', 'I', 'n', 'd', 'e', 'x', 0,
    's', 'e', 't', 'A', 'l', 'p', 'h', 'a', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'A', 'd', 'j', 'u', 's', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'B', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'D', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 's', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'O', 'r', 't', 'h', 'o', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'P', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'i', 'n', 'g', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'S', 'u', 'b', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'U', 's', 'e', 'r', 'D', 'e', 'f', 'i', 'n', 'e', 'd', 'M', 'e', 's', 'h', 0,
    's', 'e', 't', 'X', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'X', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'Y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'Y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'Z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'Z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'X', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'i', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'u', 's', 'e', 'M', 'o', 'd', 'e', 'l', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'o', 'o', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'F', 'r', 'o', 'n', 't', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'R', 'i', 'g', 'h', 't', 0,
    'C', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 'U', 'n', 'i', 'f', 'o', 'r', 'm', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'A', 'x', 'i', 's', 'X', 'L', 'a', 'b', 'e', 'l', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'A', 'x', 'i', 's', 'Y', 'L', 'a', 'b', 'e', 'l', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'A', 'x', 'i', 's', 'Z', 'L', 'a', 'b', 'e', 'l', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'S', 'c', 'a', 't', 't', 'e', 'r', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'H', 'i', 'g', 'h', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'N', 'o', 'n', 'e', 0,
    'a', 'u', 't', 'o', 'R', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'b', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'A', 'x', 'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'N', 'e', 'w', 'I', 'n', 's', 't', 'a', 'n', 'c', 'e', 0,
    'c', 'r', 'e', 'a', 't', 'e', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'f', 'l', 'o', 'o', 'r', 'L', 'e', 'v', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 's', 'A', 'u', 't', 'o', 'A', 'd', 'j', 'u', 's', 't', 'R', 'a', 'n', 'g', 'e', 0,
    'i', 's', 'O', 'r', 't', 'h', 'o', 'P', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'S', 'c', 'a', 'l', 'i', 'n', 'g', 'A', 'b', 's', 'o', 'l', 'u', 't', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 'A', 'u', 't', 'o', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'e', 'a', 's', 'u', 'r', 'e', 'F', 'p', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 's', 'h', 'S', 'm', 'o', 'o', 't', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'o', 'p', 't', 'i', 'm', 'i', 'z', 'a', 't', 'i', 'o', 'n', 'H', 'i', 'n', 't', 's', 0,
    'r', 'a', 'd', 'i', 'a', 'l', 'L', 'a', 'b', 'e', 'l', 'O', 'f', 'f', 's', 'e', 't', 0,
    'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 's', 0,
    's', 'e', 't', 'A', 'l', 'l', 'o', 'w', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 's', 0,
    's', 'e', 't', 'C', 'a', 'm', 'e', 'r', 'a', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'T', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'R', 'o', 'w', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    's', 'e', 't', 'R', 'o', 'w', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'e', 't', 'S', 'h', 'o', 'w', 'E', 'd', 'g', 'e', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'a', 'p', 's', 0,
    's', 'e', 't', 'S', 'u', 'b', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 0,
    's', 'i', 'p', '.', 's', 'i', 'm', 'p', 'l', 'e', 'w', 'r', 'a', 'p', 'p', 'e', 'r', 0,
    't', 'i', 't', 'l', 'e', 'F', 'i', 'x', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'x', 'i', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'X', 0,
    'A', 'x', 'i', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'Y', 0,
    'A', 'x', 'i', 's', 'O', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'Z', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'L', 'e', 'f', 't', 0,
    'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 'N', 'o', 'n', 'e', 0,
    'Q', 'V', 'e', 'c', 't', 'o', 'r', '<', 'Q', 'I', 'm', 'a', 'g', 'e', '*', '>', 0,
    'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 'L', 'o', 'w', 0,
    'T', 'h', 'e', 'm', 'e', 'U', 's', 'e', 'r', 'D', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    'd', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'e', 'v', 'i', 'c', 'e', 'P', 'i', 'x', 'e', 'l', 'R', 'a', 't', 'i', 'o', 0,
    'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'N', 'o', 't', 'i', 'f', 'y', 0,
    'f', 'o', 'r', 'm', 'a', 't', 't', 'e', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'X', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'x', 'Z', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 's', 'h', 'A', 'n', 'g', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'X', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'i', 'n', 'Z', 'V', 'a', 'l', 'u', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'I', 'n', 'p', 'u', 't', 'P', 'o', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'r', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'y', 'I', 'n', 'd', 'e', 'x', 0,
    'r', 'o', 'w', 'L', 'a', 'b', 'e', 'l', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', 0,
    's', 'e', 't', 'B', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'L', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    's', 'e', 't', 'P', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'e', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'R', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'o', 'w', 'C', 'a', 's', 't', 'i', 'n', 'g', 0,
    's', 'e', 't', 'S', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'i', 'n', 'g', 'A', 'c', 't', 'i', 'v', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'X', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'W', 'r', 'a', 'p', 'Y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'h', 'a', 'd', 'o', 'w', 's', 'S', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'W', 'i', 'd', 't', 'h', 's', 0,
    's', 'u', 'b', 'G', 'r', 'i', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    't', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 'W', 'i', 'd', 't', 'h', 0,
    'u', 's', 'e', 'H', 'i', 'g', 'h', 'D', 'e', 'f', 'S', 'h', 'a', 'd', 'e', 'r', 0,
    'v', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'x', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 'S', 'c', 'a', 't', 't', 'e', 'r', 0,
    'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'M', 'e', 's', 'h', 'U', 's', 'e', 'r', 'D', 'e', 'f', 'i', 'n', 'e', 'd', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'C', 'o', 'l', 'u', 'm', 'n', 0,
    'a', 'd', 'd', 'I', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 0,
    'a', 'l', 'p', 'h', 'a', 'M', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', 0,
    'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'r', 'a', 'w', 'M', 'o', 'd', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'd', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 's', 0,
    'i', 's', 'B', 'o', 'r', 'd', 'e', 'r', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'S', 'h', 'a', 'd', 'o', 'w', 'C', 'a', 's', 't', 'i', 'n', 'g', 0,
    'i', 's', 'S', 'l', 'i', 'c', 'i', 'n', 'g', 'A', 'c', 't', 'i', 'v', 'e', 0,
    'i', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'i', 't', 'e', 'm', 'S', 'i', 'z', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'k', 'e', 'y', 'R', 'e', 'l', 'e', 'a', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'm', 'e', 's', 'h', 'F', 'i', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'o', 'u', 's', 'e', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'O', 'p', 'a', 'c', 'i', 't', 'y', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'd', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'E', 'l', 'e', 'm', 'e', 'n', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'B', 'a', 'r', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    's', 'e', 't', 'C', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'F', 'a', 'c', 'i', 'n', 'g', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    's', 'e', 't', 'M', 'a', 'x', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'M', 'i', 'n', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'P', 'r', 'e', 'v', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    's', 'e', 't', 'R', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'i', 'c', 'e', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'e', 'p', 't', 'h', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'I', 'm', 'a', 'g', 'e', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'W', 'i', 'd', 't', 'h', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'u', 'b', 'S', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    'u', 's', 'e', 'r', 'D', 'e', 'f', 'i', 'n', 'e', 'd', 'M', 'e', 's', 'h', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    'M', 'M', 'B', 'C', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'v', 'e', 'Y', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'S', 'l', 'i', 'c', 'e', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'N', 'o', 'n', 'e', 0,
    'T', 'h', 'e', 'm', 'e', 'S', 't', 'o', 'n', 'e', 'M', 'o', 's', 's', 0,
    'a', 'l', 'l', 'o', 'w', 'N', 'e', 'g', 'a', 't', 'i', 'v', 'e', 's', 0,
    'c', 'l', 'e', 'a', 'r', 'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'c', 'o', 'p', 'y', 'V', 'a', 'l', 'u', 'e', 's', 'F', 'r', 'o', 'm', 0,
    'i', 's', 'A', 'u', 't', 'o', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'i', 's', 'F', 'a', 'c', 'i', 'n', 'g', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'i', 's', 'T', 'i', 't', 'l', 'e', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'l', 'a', 'b', 'e', 'l', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'l', 'a', 'b', 'e', 'l', 'T', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'm', 'o', 'u', 's', 'e', 'M', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'o', 'w', 'A', 'x', 'i', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 'P', 'a', 't', 't', 'e', 'r', 'n', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 'R', 'e', 'p', 'l', 'a', 'c', 'e', 0,
    's', 'c', 'a', 'l', 'i', 'n', 'g', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'S', 'e', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'L', 'i', 'g', 'h', 't', 0,
    's', 'e', 't', 'A', 'c', 't', 'i', 'v', 'e', 'T', 'h', 'e', 'm', 'e', 0,
    's', 'e', 't', 'A', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    's', 'e', 't', 'A', 'u', 't', 'o', 'S', 'u', 'b', 'G', 'r', 'i', 'd', 0,
    's', 'e', 't', 'G', 'r', 'i', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    's', 'e', 't', 'S', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'B', 'a', 'r', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'X', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Y', 0,
    's', 'e', 't', 'S', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Z', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 'R', 'a', 'n', 'g', 'e', 's', 0,
    's', 'e', 't', 'W', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    's', 'h', 'o', 'w', 'E', 'd', 'g', 'e', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'l', 'i', 'c', 'e', 'F', 'r', 'a', 'm', 'e', 'G', 'a', 'p', 's', 0,
    's', 't', 'r', 'i', 'n', 'g', 'F', 'o', 'r', 'V', 'a', 'l', 'u', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'v', 'i', 's', 'i', 'b', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'V', 'a', 'l', 'u', 'e', 0,
    'D', 'r', 'a', 'w', 'W', 'i', 'r', 'e', 'f', 'r', 'a', 'm', 'e', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'I', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 'N', 'o', 'n', 'e', 0,
    'M', 'M', 'B', 'C', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'v', 'e', 0,
    'M', 'e', 's', 'h', 'B', 'e', 'v', 'e', 'l', 'C', 'u', 'b', 'e', 0,
    'Q', 'L', 'i', 's', 't', '<', 'Q', 'C', 'o', 'l', 'o', 'r', '>', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'I', 't', 'e', 'm', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'N', 'o', 'n', 'e', 0,
    'S', 'e', 'r', 'i', 'e', 's', 'T', 'y', 'p', 'e', 'B', 'a', 'r', 0,
    'T', 'h', 'e', 'm', 'e', 'A', 'r', 'm', 'y', 'B', 'l', 'u', 'e', 0,
    'T', 'h', 'e', 'm', 'e', 'I', 's', 'a', 'b', 'e', 'l', 'l', 'e', 0,
    'a', 'd', 'd', 'C', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 0,
    'b', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'u', 't', 'E', 'v', 'e', 'n', 't', 0,
    'g', 'r', 'i', 'd', 'L', 'i', 'n', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'g', 'r', 'i', 'd', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 'F', 'i', 'l', 'e', 0,
    'i', 'n', 'p', 'u', 't', 'H', 'a', 'n', 'd', 'l', 'e', 'r', 's', 0,
    'i', 'n', 'p', 'u', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'i', 's', 'G', 'r', 'i', 'd', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 's', 'Z', 'o', 'o', 'm', 'E', 'n', 'a', 'b', 'l', 'e', 'd', 0,
    'i', 't', 'e', 'm', 's', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    'k', 'e', 'y', 'P', 'r', 'e', 's', 's', 'E', 'v', 'e', 'n', 't', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'i', 'g', 'h', 't', 'S', 't', 'r', 'e', 'n', 'g', 't', 'h', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'r', 'i', 'm', 'a', 'r', 'y', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'T', 'o', 'I', 'm', 'a', 'g', 'e', 0,
    'r', 'o', 'w', 'C', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'P', 'o', 'i', 'n', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'M', 'o', 'd', 'e', 0,
    's', 'e', 'r', 'i', 'e', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 't', 'B', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 's', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'A', 'x', 'i', 's', 0,
    's', 'e', 't', 'C', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'D', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 's', 0,
    's', 'e', 't', 'F', 'l', 'o', 'o', 'r', 'L', 'e', 'v', 'e', 'l', 0,
    's', 'e', 't', 'L', 'i', 'g', 'h', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'M', 'e', 'a', 's', 'u', 'r', 'e', 'F', 'p', 's', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'S', 'm', 'o', 'o', 't', 'h', 0,
    's', 'e', 't', 'R', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 'F', 'i', 'x', 'e', 'd', 0,
    's', 'h', 'a', 'd', 'o', 'w', 'Q', 'u', 'a', 'l', 'i', 't', 'y', 0,
    't', 'a', 'r', 'g', 'e', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'o', 'r', 'm', 'a', 't', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'H', 'e', 'i', 'g', 'h', 't', 0,
    'w', 'r', 'a', 'p', 'X', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'w', 'r', 'a', 'p', 'Y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'A', 'x', 'i', 's', 'T', 'y', 'p', 'e', 'N', 'o', 'n', 'e', 0,
    'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 'N', 'o', 'n', 'e', 0,
    'M', 'e', 's', 'h', 'B', 'e', 'v', 'e', 'l', 'B', 'a', 'r', 0,
    'M', 'e', 's', 'h', 'C', 'y', 'l', 'i', 'n', 'd', 'e', 'r', 0,
    'S', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'R', 'o', 'w', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'C', 'a', 'm', 'e', 'r', 'a', 0,
    'a', 'x', 'i', 's', 'X', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'x', 'i', 's', 'Y', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'a', 'x', 'i', 's', 'Z', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'b', 'a', 'r', 'T', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 0,
    'b', 'a', 's', 'e', 'G', 'r', 'a', 'd', 'i', 'e', 'n', 't', 0,
    'c', 'a', 'm', 'e', 'r', 'a', 'P', 'r', 'e', 's', 'e', 't', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'L', 'a', 'b', 'e', 'l', 's', 0,
    'f', 'o', 'c', 'u', 's', 'I', 'n', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'i', 's', 'M', 'e', 's', 'h', 'S', 'm', 'o', 'o', 't', 'h', 0,
    'i', 's', 'R', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 0,
    'i', 's', 'T', 'i', 't', 'l', 'e', 'F', 'i', 'x', 'e', 'd', 0,
    'i', 't', 'e', 'm', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 't', 'e', 'm', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'S', 't', 'r', 'i', 'n', 'g', 's', 0,
    'l', 'a', 'b', 'e', 'l', 's', 'C', 'h', 'a', 'n', 'g', 'e', 0,
    'm', 'a', 'x', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    'm', 'e', 's', 'h', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'm', 'i', 'n', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    'p', 'o', 'l', 'a', 'r', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'C', 'o', 'p', 'y', 0,
    'p', 'r', 'e', 'v', 'D', 'i', 's', 't', 'a', 'n', 'c', 'e', 0,
    'r', 'a', 'n', 'g', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'T', 'h', 'e', 'm', 'e', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'L', 'a', 'b', 'e', 'l', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'R', 'o', 'l', 'e', 0,
    'r', 'o', 'w', 's', 'I', 'n', 's', 'e', 'r', 't', 'e', 'd', 0,
    's', 'c', 'e', 'n', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    's', 'e', 'g', 'm', 'e', 'n', 't', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'A', 'x', 'i', 's', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'A', 'l', 'l', 'o', 'w', 'Z', 'e', 'r', 'o', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'D', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    's', 'e', 't', 'F', 'o', 'r', 'm', 'a', 't', 't', 'e', 'r', 0,
    's', 'e', 't', 'H', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 0,
    's', 'e', 't', 'I', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    's', 'e', 't', 'M', 'a', 'x', 'X', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'a', 'x', 'Z', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'A', 'n', 'g', 'l', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'X', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'M', 'i', 'n', 'Z', 'V', 'a', 'l', 'u', 'e', 0,
    's', 'e', 't', 'R', 'o', 'w', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'X', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'Y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'Z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'e', 'p', 't', 'h', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'W', 'i', 'd', 't', 'h', 0,
    't', 'i', 't', 'l', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'D', 'a', 't', 'a', 'T', 'y', 'p', 'e', 'B', 'a', 'r', 0,
    'D', 'r', 'a', 'w', 'S', 'u', 'r', 'f', 'a', 'c', 'e', 0,
    'E', 'l', 'e', 'm', 'e', 'n', 't', 'N', 'o', 'n', 'e', 0,
    'M', 'e', 's', 'h', 'M', 'i', 'n', 'i', 'm', 'a', 'l', 0,
    'M', 'e', 's', 'h', 'P', 'y', 'r', 'a', 'm', 'i', 'd', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'L', 'i', 'g', 'h', 't', 0,
    'a', 'c', 't', 'i', 'v', 'e', 'T', 'h', 'e', 'm', 'e', 0,
    'a', 's', 'p', 'e', 'c', 't', 'R', 'a', 't', 'i', 'o', 0,
    'a', 'u', 't', 'o', 'S', 'u', 'b', 'G', 'r', 'i', 'd', 0,
    'b', 'a', 's', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'C', 'o', 'u', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'u', 's', 't', 'o', 'm', 'I', 't', 'e', 'm', 's', 0,
    'e', 'v', 'e', 'n', 't', 'F', 'i', 'l', 't', 'e', 'r', 0,
    'e', 'x', 'p', 'o', 's', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'f', 'o', 'c', 'u', 's', 'O', 'b', 'j', 'e', 'c', 't', 0,
    'f', 'o', 'n', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'i', 'n', 's', 'e', 'r', 't', 'I', 't', 'e', 'm', 's', 0,
    'i', 't', 'e', 'm', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'l', 'a', 'b', 'e', 'l', 'F', 'o', 'r', 'm', 'a', 't', 0,
    'm', 'e', 's', 'h', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 's', 'a', 'a', 'S', 'a', 'm', 'p', 'l', 'e', 's', 0,
    'n', 'a', 'm', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 0,
    'p', 'a', 'r', 'e', 'n', 't', 'S', 'c', 'e', 'n', 'e', 0,
    'r', 'e', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 0,
    'r', 'e', 'l', 'e', 'a', 's', 'e', 'A', 'x', 'i', 's', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'I', 't', 'e', 'm', 's', 0,
    'r', 'e', 'n', 'd', 'e', 'r', 'S', 'l', 'i', 'c', 'e', 0,
    'r', 'e', 's', 'i', 'z', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'o', 'w', 's', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'r', 'o', 'w', 's', 'R', 'e', 'm', 'o', 'v', 'e', 'd', 0,
    's', 'e', 'l', 'e', 'c', 't', 'e', 'd', 'B', 'a', 'r', 0,
    's', 'e', 't', 'D', 'r', 'a', 'w', 'M', 'o', 'd', 'e', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 'F', 'i', 'l', 'e', 0,
    's', 'e', 't', 'P', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'R', 'e', 'v', 'e', 'r', 's', 'e', 'd', 0,
    's', 'e', 't', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    's', 'e', 't', 'X', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'Y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'Z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'X', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Y', 0,
    's', 'l', 'i', 'c', 'e', 'I', 'n', 'd', 'e', 'x', 'Z', 0,
    's', 'u', 'r', 'f', 'a', 'c', 'e', 'T', 'y', 'p', 'e', 0,
    't', 'a', 'b', 'l', 'e', 't', 'E', 'v', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'D', 'a', 't', 'a', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 'F', 'i', 'l', 'e', 0,
    't', 'y', 'p', 'e', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'w', 'i', 'n', 'd', 'o', 'w', 'C', 'o', 'l', 'o', 'r', 0,
    'M', 'M', 'B', 'A', 'v', 'e', 'r', 'a', 'g', 'e', 0,
    'M', 'e', 's', 'h', 'S', 'p', 'h', 'e', 'r', 'e', 0,
    'T', 'h', 'e', 'm', 'e', 'D', 'i', 'g', 'i', 'a', 0,
    'T', 'h', 'e', 'm', 'e', 'E', 'b', 'o', 'n', 'y', 0,
    'T', 'h', 'e', 'm', 'e', 'R', 'e', 't', 'r', 'o', 0,
    '_', '_', 'i', 'n', 'v', 'e', 'r', 't', '_', '_', 0,
    'a', 'r', 'r', 'a', 'y', 'R', 'e', 's', 'e', 't', 0,
    'b', 'a', 'r', 'S', 'p', 'a', 'c', 'i', 'n', 'g', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 's', 0,
    'c', 'h', 'i', 'l', 'd', 'E', 'v', 'e', 'n', 't', 0,
    'c', 'o', 'l', 'o', 'r', 'S', 't', 'y', 'l', 'e', 0,
    'c', 'o', 'l', 'o', 'r', 'T', 'a', 'b', 'l', 'e', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'A', 'x', 'i', 's', 0,
    'c', 'o', 'l', 'u', 'm', 'n', 'R', 'o', 'l', 'e', 0,
    'c', 'u', 'r', 'r', 'e', 'n', 't', 'F', 'p', 's', 0,
    'd', 'r', 'a', 'w', 'S', 'l', 'i', 'c', 'e', 's', 0,
    'f', 'l', 'o', 'o', 'r', 'L', 'e', 'v', 'e', 'l', 0,
    'h', 'a', 's', 'C', 'o', 'n', 't', 'e', 'x', 't', 0,
    'i', 'n', 's', 'e', 'r', 't', 'I', 't', 'e', 'm', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 's', 0,
    'i', 't', 'e', 'm', 's', 'A', 'd', 'd', 'e', 'd', 0,
    'm', 'a', 'x', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'm', 'e', 'a', 's', 'u', 'r', 'e', 'F', 'p', 's', 0,
    'm', 'i', 'n', 'C', 'h', 'a', 'n', 'g', 'e', 'd', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'A', 't', 0,
    'r', 'e', 'm', 'o', 'v', 'e', 'R', 'o', 'w', 's', 0,
    'r', 'e', 's', 'e', 't', 'A', 'r', 'r', 'a', 'y', 0,
    's', 'e', 'r', 'i', 'e', 's', 'L', 'i', 's', 't', 0,
    's', 'e', 't', 'R', 'o', 'w', 'A', 'x', 'i', 's', 0,
    's', 'e', 't', 'R', 'o', 'w', 'R', 'o', 'l', 'e', 0,
    's', 'e', 't', 'S', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 'u', 'r', 'e', 0,
    's', 'e', 't', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    't', 'i', 'm', 'e', 'r', 'E', 'v', 'e', 'n', 't', 0,
    't', 'o', 'u', 'c', 'h', 'E', 'v', 'e', 'n', 't', 0,
    'w', 'h', 'e', 'e', 'l', 'E', 'v', 'e', 'n', 't', 0,
    'M', 'e', 's', 'h', 'A', 'r', 'r', 'o', 'w', 0,
    'M', 'e', 's', 'h', 'P', 'o', 'i', 'n', 't', 0,
    '_', '_', 'i', 'n', 'd', 'e', 'x', '_', '_', 0,
    'a', 'd', 'd', 'S', 'e', 'r', 'i', 'e', 's', 0,
    'a', 'l', 'l', 'o', 'w', 'Z', 'e', 'r', 'o', 0,
    'a', 'n', 't', 'i', 'a', 'l', 'i', 'a', 's', 0,
    'b', 'a', 's', 'e', 'C', 'o', 'l', 'o', 'r', 0,
    'd', 'a', 't', 'a', 'P', 'r', 'o', 'x', 'y', 0,
    'f', 'o', 'r', 'm', 'a', 't', 't', 'e', 'r', 0,
    'h', 'e', 'i', 'g', 'h', 't', 'M', 'a', 'p', 0,
    'h', 'i', 'd', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'i', 'm', 'a', 'g', 'e', 'S', 'i', 'z', 'e', 0,
    'i', 'n', 'p', 'u', 't', 'V', 'i', 'e', 'w', 0,
    'i', 'n', 's', 'e', 'r', 't', 'R', 'o', 'w', 0,
    'i', 's', 'V', 'i', 's', 'i', 'b', 'l', 'e', 0,
    'i', 't', 'e', 'm', 'C', 'o', 'u', 'n', 't', 0,
    'i', 't', 'e', 'm', 'L', 'a', 'b', 'e', 'l', 0,
    'i', 't', 'e', 'm', 'M', 'o', 'd', 'e', 'l', 0,
    'm', 'a', 'r', 'k', 'D', 'i', 'r', 't', 'y', 0,
    'm', 'a', 'x', 'X', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'a', 'x', 'Z', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'e', 's', 'h', 'A', 'n', 'g', 'l', 'e', 0,
    'm', 'i', 'n', 'X', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'i', 'n', 'Z', 'V', 'a', 'l', 'u', 'e', 0,
    'm', 'o', 'v', 'e', 'E', 'v', 'e', 'n', 't', 0,
    'r', 'o', 'w', 'L', 'a', 'b', 'e', 'l', 's', 0,
    'r', 'o', 'w', 's', 'A', 'd', 'd', 'e', 'd', 0,
    's', 'e', 't', 'L', 'a', 'b', 'e', 'l', 's', 0,
    's', 'e', 't', 'L', 'o', 'c', 'a', 'l', 'e', 0,
    's', 'e', 't', 'M', 'a', 'r', 'g', 'i', 'n', 0,
    's', 'e', 't', 'T', 'a', 'r', 'g', 'e', 't', 0,
    's', 'h', 'o', 'w', 'E', 'v', 'e', 'n', 't', 0,
    't', 'e', 'x', 't', 'C', 'o', 'l', 'o', 'r', 0,
    'v', 'a', 'l', 'u', 'e', 'A', 'x', 'i', 's', 0,
    'v', 'a', 'l', 'u', 'e', 'R', 'o', 'l', 'e', 0,
    'x', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'y', 'R', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'z', 'o', 'o', 'm', 'L', 'e', 'v', 'e', 'l', 0,
    'M', 'M', 'B', 'F', 'i', 'r', 's', 't', 0,
    'M', 'e', 's', 'h', 'C', 'o', 'n', 'e', 0,
    'M', 'e', 's', 'h', 'C', 'u', 'b', 'e', 0,
    '_', '_', 'b', 'o', 'o', 'l', '_', '_', 0,
    '_', '_', 'h', 'a', 's', 'h', '_', '_', 0,
    '_', '_', 'i', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 's', 0,
    'a', 'd', 'd', 'T', 'h', 'e', 'm', 'e', 0,
    'd', 'r', 'a', 'w', 'M', 'o', 'd', 'e', 0,
    'i', 't', 'e', 'm', 'S', 'i', 'z', 'e', 0,
    'm', 'e', 's', 'h', 'F', 'i', 'l', 'e', 0,
    'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 0,
    'r', 'e', 'v', 'e', 'r', 's', 'e', 'd', 0,
    'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 0,
    'r', 'o', 'w', 'C', 'o', 'u', 'n', 't', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 'X', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 'Y', 0,
    's', 'e', 't', 'A', 'x', 'i', 's', 'Z', 0,
    's', 'e', 't', 'D', 'i', 'r', 't', 'y', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 's', 0,
    's', 'e', 't', 'P', 'o', 'l', 'a', 'r', 0,
    's', 'e', 't', 'R', 'a', 'n', 'g', 'e', 0,
    's', 'e', 't', 'S', 'c', 'e', 'n', 'e', 0,
    's', 'e', 't', 'T', 'i', 't', 'l', 'e', 0,
    's', 'e', 't', 'V', 'a', 'l', 'u', 'e', 0,
    'v', 'i', 'e', 'w', 'p', 'o', 'r', 't', 0,
    'x', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    'y', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    'z', 'P', 'o', 's', 'R', 'o', 'l', 'e', 0,
    'M', 'M', 'B', 'L', 'a', 's', 't', 0,
    'M', 'e', 's', 'h', 'B', 'a', 'r', 0,
    'T', 'h', 'e', 'm', 'e', 'Q', 't', 0,
    '_', '_', 'a', 'n', 'd', '_', '_', 0,
    '_', '_', 'i', 'n', 't', '_', '_', 0,
    '_', '_', 'i', 'o', 'r', '_', '_', 0,
    '_', '_', 'x', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'A', 'x', 'i', 's', 0,
    'a', 'd', 'd', 'I', 't', 'e', 'm', 0,
    'a', 'd', 'd', 'R', 'o', 'w', 's', 0,
    'i', 's', 'D', 'i', 'r', 't', 'y', 0,
    'i', 's', 'P', 'o', 'l', 'a', 'r', 0,
    'r', 'o', 'w', 'A', 'x', 'i', 's', 0,
    'r', 'o', 'w', 'R', 'o', 'l', 'e', 0,
    's', 'c', 'a', 'l', 'i', 'n', 'g', 0,
    's', 'e', 't', 'B', 'a', 's', 'e', 0,
    's', 'e', 't', 'F', 'o', 'n', 't', 0,
    's', 'e', 't', 'I', 't', 'e', 'm', 0,
    's', 'e', 't', 'M', 'e', 's', 'h', 0,
    's', 'e', 't', 'N', 'a', 'm', 'e', 0,
    's', 'e', 't', 'R', 'o', 'w', 's', 0,
    's', 'e', 't', 'T', 'e', 'x', 't', 0,
    's', 'e', 't', 'T', 'y', 'p', 'e', 0,
    't', 'e', 'x', 't', 'u', 'r', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 'A', 't', 0,
    '_', '_', 'e', 'q', '_', '_', 0,
    '_', '_', 'n', 'e', '_', '_', 0,
    '_', '_', 'o', 'r', '_', '_', 0,
    'a', 'd', 'd', 'R', 'o', 'w', 0,
    'f', 'o', 'r', 'm', 'a', 't', 0,
    'i', 't', 'e', 'm', 'A', 't', 0,
    'l', 'a', 'b', 'e', 'l', 's', 0,
    'l', 'o', 'c', 'a', 'l', 'e', 0,
    'm', 'a', 'r', 'g', 'i', 'n', 0,
    'p', 'a', 'r', 'e', 'n', 't', 0,
    's', 'e', 'r', 'i', 'e', 's', 0,
    's', 'e', 't', 'M', 'a', 'x', 0,
    's', 'e', 't', 'M', 'i', 'n', 0,
    's', 'e', 't', 'R', 'o', 'w', 0,
    't', 'a', 'r', 'g', 'e', 't', 0,
    't', 'h', 'e', 'm', 'e', 's', 0,
    'a', 'r', 'r', 'a', 'y', 0,
    'a', 'x', 'i', 's', 'X', 0,
    'a', 'x', 'i', 's', 'Y', 0,
    'a', 'x', 'i', 's', 'Z', 0,
    'e', 'v', 'e', 'n', 't', 0,
    'r', 'e', 'm', 'a', 'p', 0,
    'r', 'o', 'w', 'A', 't', 0,
    's', 'c', 'e', 'n', 'e', 0,
    't', 'i', 't', 'l', 'e', 0,
    'v', 'a', 'l', 'u', 'e', 0,
    'a', 'x', 'e', 's', 0,
    'a', 'x', 'i', 's', 0,
    'b', 'a', 's', 'e', 0,
    'f', 'o', 'n', 't', 0,
    'm', 'e', 's', 'h', 0,
    'n', 'a', 'm', 'e', 0,
    's', 'e', 't', 'X', 0,
    's', 'e', 't', 'Y', 0,
    's', 'e', 't', 'Z', 0,
    's', 'i', 'z', 'e', 0,
    't', 'y', 'p', 'e', 0,
    'z', 'o', 'o', 'm', 0,
    'm', 'a', 'x', 0,
    'm', 'i', 'n', 0,
    'z', 0,
};
#line 28 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qdatavisualizationglobal.sip"
static int PYQT_DATAVISUALIZATION_VERSION = 0x050f06;
static const char *PYQT_DATAVISUALIZATION_VERSION_STR = "5.15.6";
#line 27 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/qtdatavisualizationversion.sip"
#include <qtdatavisualizationversion.h>
#line 2380 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"

void sipVH_QtDataVisualization_28(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QtDataVisualization::QValue3DAxisFormatter& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", &a0, sipType_QtDataVisualization_QValue3DAxisFormatter, SIP_NULLPTR);
}

float sipVH_QtDataVisualization_27(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, float a0)
{
    float sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "f", a0);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "f", &sipRes);

    return sipRes;
}

::QString sipVH_QtDataVisualization_26(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::qreal a0, const ::QString& a1)
{
    ::QString sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "dN", a0, new ::QString(a1), sipType_QString, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QString, &sipRes);

    return sipRes;
}

void sipVH_QtDataVisualization_25(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "");
}

::QtDataVisualization::QValue3DAxisFormatter* sipVH_QtDataVisualization_24(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QtDataVisualization::QValue3DAxisFormatter* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H2", sipType_QtDataVisualization_QValue3DAxisFormatter, &sipRes);

    return sipRes;
}

void sipVH_QtDataVisualization_23(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0, const ::QPoint& a1)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "DN", a0, sipType_QMouseEvent, SIP_NULLPTR, new ::QPoint(a1), sipType_QPoint, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_22(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QtDataVisualization::Q3DObject& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", const_cast< ::QtDataVisualization::Q3DObject *>(&a0), sipType_QtDataVisualization_Q3DObject, SIP_NULLPTR);
}

bool sipVH_QtDataVisualization_21(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

void sipVH_QtDataVisualization_20(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, const ::QMetaMethod& a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "N", new ::QMetaMethod(a0), sipType_QMetaMethod, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_19(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_18(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QChildEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QChildEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_17(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTimerEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTimerEvent, SIP_NULLPTR);
}

bool sipVH_QtDataVisualization_16(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QObject*a0, ::QEvent*a1)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "DD", a0, sipType_QObject, SIP_NULLPTR, a1, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

bool sipVH_QtDataVisualization_15(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QEvent*a0)
{
    bool sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "D", a0, sipType_QEvent, SIP_NULLPTR);

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "b", &sipRes);

    return sipRes;
}

::QSize sipVH_QtDataVisualization_14(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSize sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSize, &sipRes);

    return sipRes;
}

::QSurface::SurfaceType sipVH_QtDataVisualization_13(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurface::SurfaceType sipRes = ::QSurface::RasterSurface;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "F", sipType_QSurface_SurfaceType, &sipRes);

    return sipRes;
}

::QSurfaceFormat sipVH_QtDataVisualization_12(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QSurfaceFormat sipRes;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H5", sipType_QSurfaceFormat, &sipRes);

    return sipRes;
}

::QObject* sipVH_QtDataVisualization_11(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod)
{
    ::QObject* sipRes = 0;
    PyObject *sipResObj = sipCallMethod(SIP_NULLPTR, sipMethod, "");

    sipParseResultEx(sipGILState, sipErrorHandler, sipPySelf, sipMethod, sipResObj, "H0", sipType_QObject, &sipRes);

    return sipRes;
}

void sipVH_QtDataVisualization_10(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QExposeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QExposeEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_9(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QResizeEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QResizeEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_8(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMoveEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMoveEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_7(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QFocusEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QFocusEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_6(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QShowEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QShowEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_5(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QHideEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QHideEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_4(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QKeyEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QKeyEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_3(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QMouseEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QMouseEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_2(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QWheelEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QWheelEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_1(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTouchEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTouchEvent, SIP_NULLPTR);
}

void sipVH_QtDataVisualization_0(sip_gilstate_t sipGILState, sipVirtErrorHandlerFunc sipErrorHandler, sipSimpleWrapper *sipPySelf, PyObject *sipMethod, ::QTabletEvent*a0)
{
    sipCallProcedureMethod(sipGILState, sipErrorHandler, sipPySelf, sipMethod, "D", a0, sipType_QTabletEvent, SIP_NULLPTR);
}


PyDoc_STRVAR(doc_qDefaultSurfaceFormat, "qDefaultSurfaceFormat(antialias: bool = True) -> QSurfaceFormat");

extern "C" {static PyObject *func_qDefaultSurfaceFormat(PyObject *, PyObject *, PyObject *);}
static PyObject *func_qDefaultSurfaceFormat(PyObject *, PyObject *sipArgs, PyObject *sipKwds)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        bool a0 = 1;

        static const char *sipKwdList[] = {
            sipName_antialias,
        };

        if (sipParseKwdArgs(&sipParseErr, sipArgs, sipKwds, sipKwdList, SIP_NULLPTR, "|b", &a0))
        {
            ::QSurfaceFormat*sipRes;

            sipRes = new ::QSurfaceFormat(::QtDataVisualization::qDefaultSurfaceFormat(a0));

            return sipConvertFromNewType(sipRes, sipType_QSurfaceFormat, SIP_NULLPTR);
        }
    }

    /* Raise an exception if the arguments couldn't be parsed. */
    sipNoFunction(sipParseErr, sipName_qDefaultSurfaceFormat, doc_qDefaultSurfaceFormat);

    return SIP_NULLPTR;
}


/* Convert to a sub-class if possible. */
extern "C" {static const sipTypeDef *sipSubClass_QtDataVisualization_Q3DTheme(void **);}
static const sipTypeDef *sipSubClass_QtDataVisualization_Q3DTheme(void **sipCppRet)
{
    ::QObject *sipCpp = reinterpret_cast< ::QObject *>(*sipCppRet);
    const sipTypeDef *sipType;

#line 36 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/sip/QtDataVisualization/q3dtheme.sip"
        static struct class_graph {
            const char *name;
            sipTypeDef **type;
            int yes, no;
        } graph[] = {
            {sipName_QtDataVisualization__QAbstract3DInputHandler, &sipType_QtDataVisualization_QAbstract3DInputHandler, 10, 1},
        #if QTDATAVISUALIZATION_VERSION >= 0x010100
            {sipName_QtDataVisualization__QValue3DAxisFormatter, &sipType_QtDataVisualization_QValue3DAxisFormatter, 12, 2},
        #else
            {0, 0, 12, 2},
        #endif
            {sipName_QtDataVisualization__QAbstractDataProxy, &sipType_QtDataVisualization_QAbstractDataProxy, 13, 3},
            {sipName_QtDataVisualization__QAbstract3DAxis, &sipType_QtDataVisualization_QAbstract3DAxis, 20, 4},
        #if QTDATAVISUALIZATION_VERSION >= 0x010100
            {sipName_QtDataVisualization__QCustom3DItem, &sipType_QtDataVisualization_QCustom3DItem, 22, 5},
        #else
            {0, 0, 22, 5},
        #endif
            {sipName_QtDataVisualization__QAbstract3DSeries, &sipType_QtDataVisualization_QAbstract3DSeries, 24, 6},
            {sipName_QtDataVisualization__Q3DTheme, &sipType_QtDataVisualization_Q3DTheme, -1, 7},
            {sipName_QtDataVisualization__QAbstract3DGraph, &sipType_QtDataVisualization_QAbstract3DGraph, 27, 8},
            {sipName_QtDataVisualization__Q3DScene, &sipType_QtDataVisualization_Q3DScene, -1, 9},
            {sipName_QtDataVisualization__Q3DObject, &sipType_QtDataVisualization_Q3DObject, 30, -1},
            {sipName_QtDataVisualization__Q3DInputHandler, &sipType_QtDataVisualization_Q3DInputHandler, 11, -1},
            {sipName_QtDataVisualization__QTouch3DInputHandler, &sipType_QtDataVisualization_QTouch3DInputHandler, -1, -1},
        #if QTDATAVISUALIZATION_VERSION >= 0x010100
            {sipName_QtDataVisualization__QLogValue3DAxisFormatter, &sipType_QtDataVisualization_QLogValue3DAxisFormatter, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
            {sipName_QtDataVisualization__QSurfaceDataProxy, &sipType_QtDataVisualization_QSurfaceDataProxy, 16, 14},
            {sipName_QtDataVisualization__QScatterDataProxy, &sipType_QtDataVisualization_QScatterDataProxy, 18, 15},
            {sipName_QtDataVisualization__QBarDataProxy, &sipType_QtDataVisualization_QBarDataProxy, 19, -1},
            {sipName_QtDataVisualization__QItemModelSurfaceDataProxy, &sipType_QtDataVisualization_QItemModelSurfaceDataProxy, -1, 17},
            {sipName_QtDataVisualization__QHeightMapSurfaceDataProxy, &sipType_QtDataVisualization_QHeightMapSurfaceDataProxy, -1, -1},
            {sipName_QtDataVisualization__QItemModelScatterDataProxy, &sipType_QtDataVisualization_QItemModelScatterDataProxy, -1, -1},
            {sipName_QtDataVisualization__QItemModelBarDataProxy, &sipType_QtDataVisualization_QItemModelBarDataProxy, -1, -1},
            {sipName_QtDataVisualization__QValue3DAxis, &sipType_QtDataVisualization_QValue3DAxis, -1, 21},
            {sipName_QtDataVisualization__QCategory3DAxis, &sipType_QtDataVisualization_QCategory3DAxis, -1, -1},
        #if QTDATAVISUALIZATION_VERSION >= 0x010100
            {sipName_QtDataVisualization__QCustom3DLabel, &sipType_QtDataVisualization_QCustom3DLabel, -1, 23},
        #else
            {0, 0, -1, 23},
        #endif
        #if QTDATAVISUALIZATION_VERSION >= 0x010200
            {sipName_QtDataVisualization__QCustom3DVolume, &sipType_QtDataVisualization_QCustom3DVolume, -1, -1},
        #else
            {0, 0, -1, -1},
        #endif
            {sipName_QtDataVisualization__QScatter3DSeries, &sipType_QtDataVisualization_QScatter3DSeries, -1, 25},
            {sipName_QtDataVisualization__QSurface3DSeries, &sipType_QtDataVisualization_QSurface3DSeries, -1, 26},
            {sipName_QtDataVisualization__QBar3DSeries, &sipType_QtDataVisualization_QBar3DSeries, -1, -1},
            {sipName_QtDataVisualization__Q3DSurface, &sipType_QtDataVisualization_Q3DSurface, -1, 28},
            {sipName_QtDataVisualization__Q3DScatter, &sipType_QtDataVisualization_Q3DScatter, -1, 29},
            {sipName_QtDataVisualization__Q3DBars, &sipType_QtDataVisualization_Q3DBars, -1, -1},
            {sipName_QtDataVisualization__Q3DCamera, &sipType_QtDataVisualization_Q3DCamera, -1, 31},
            {sipName_QtDataVisualization__Q3DLight, &sipType_QtDataVisualization_Q3DLight, -1, -1},
        };
        
        int i = 0;
        
        sipType = NULL;
        
        do
        {
            struct class_graph *cg = &graph[i];
        
            if (cg->name != NULL && sipCpp->inherits(cg->name))
            {
                sipType = *cg->type;
                i = cg->yes;
            }
            else
                i = cg->no;
        }
        while (i >= 0);
#line 2693 "/build/python-pyqt5-datavisualization/src/PyQtDataVisualization-5.15.6/build/QtDataVisualization/sipQtDataVisualizationcmodule.cpp"

    return sipType;
}


extern "C" {static PyObject *slot_QtDataVisualization_QAbstract3DGraph_OptimizationHint___or__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QAbstract3DGraph_OptimizationHint___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph::OptimizationHint a0;
        ::QtDataVisualization::QAbstract3DGraph::OptimizationHints* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHint, &a0, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, &a1, &a1State))
        {
            ::QtDataVisualization::QAbstract3DGraph::OptimizationHints*sipRes;

            sipRes = new ::QtDataVisualization::QAbstract3DGraph::OptimizationHints((a0 | *a1));
            sipReleaseType(a1, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, a1State);

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QAbstract3DGraph_OptimizationHints, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QtDataVisualization_QAbstract3DGraph_OptimizationHint[] = {
    {(void *)slot_QtDataVisualization_QAbstract3DGraph_OptimizationHint___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};



extern "C" {static PyObject *slot_QtDataVisualization_QAbstract3DGraph_SelectionFlag___or__(PyObject *, PyObject *);}
static PyObject *slot_QtDataVisualization_QAbstract3DGraph_SelectionFlag___or__(PyObject *sipArg0, PyObject *sipArg1)
{
    PyObject *sipParseErr = SIP_NULLPTR;

    {
        ::QtDataVisualization::QAbstract3DGraph::SelectionFlag a0;
        ::QtDataVisualization::QAbstract3DGraph::SelectionFlags* a1;
        int a1State = 0;

        if (sipParsePair(&sipParseErr, sipArg0, sipArg1, "EJ1", sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlag, &a0, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, &a1, &a1State))
        {
            ::QtDataVisualization::QAbstract3DGraph::SelectionFlags*sipRes;

            sipRes = new ::QtDataVisualization::QAbstract3DGraph::SelectionFlags((a0 | *a1));
            sipReleaseType(a1, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, a1State);

            return sipConvertFromNewType(sipRes, sipType_QtDataVisualization_QAbstract3DGraph_SelectionFlags, SIP_NULLPTR);
        }
    }

    Py_XDECREF(sipParseErr);

    if (sipParseErr == Py_None)
        return SIP_NULLPTR;

    PyErr_Clear();

    Py_INCREF(Py_NotImplemented);
    return Py_NotImplemented;
}

static sipPySlotDef slots_QtDataVisualization_QAbstract3DGraph_SelectionFlag[] = {
    {(void *)slot_QtDataVisualization_QAbstract3DGraph_SelectionFlag___or__, or_slot},
    {SIP_NULLPTR, (sipPySlotType)0}
};

static sipEnumTypeDef enumTypes[] = {
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__Q3DCamera__CameraPreset, SIP_NULLPTR, 0}, sipNameNr_CameraPreset, 18, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__Q3DTheme__ColorStyle, SIP_NULLPTR, 0}, sipNameNr_ColorStyle, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__Q3DTheme__Theme, SIP_NULLPTR, 0}, sipNameNr_Theme, 26, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DAxis__AxisOrientation, SIP_NULLPTR, 0}, sipNameNr_AxisOrientation, 29, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DAxis__AxisType, SIP_NULLPTR, 0}, sipNameNr_AxisType, 29, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DGraph__ElementType, SIP_NULLPTR, 0}, sipNameNr_ElementType, 32, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DGraph__OptimizationHint, SIP_NULLPTR, 0}, sipNameNr_OptimizationHint, 32, slots_QtDataVisualization_QAbstract3DGraph_OptimizationHint},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DGraph__SelectionFlag, SIP_NULLPTR, 0}, sipNameNr_SelectionFlag, 32, slots_QtDataVisualization_QAbstract3DGraph_SelectionFlag},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DGraph__ShadowQuality, SIP_NULLPTR, 0}, sipNameNr_ShadowQuality, 32, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DInputHandler__InputView, SIP_NULLPTR, 0}, sipNameNr_InputView, 39, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DSeries__Mesh, SIP_NULLPTR, 0}, sipNameNr_Mesh, 41, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstract3DSeries__SeriesType, SIP_NULLPTR, 0}, sipNameNr_SeriesType, 41, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QAbstractDataProxy__DataType, SIP_NULLPTR, 0}, sipNameNr_DataType, 44, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QItemModelBarDataProxy__MultiMatchBehavior, SIP_NULLPTR, 0}, sipNameNr_MultiMatchBehavior, 54, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QItemModelSurfaceDataProxy__MultiMatchBehavior, SIP_NULLPTR, 0}, sipNameNr_MultiMatchBehavior, 57, SIP_NULLPTR},
    {{-1, SIP_NULLPTR, SIP_NULLPTR, SIP_TYPE_ENUM, sipNameNr_QtDataVisualization__QSurface3DSeries__DrawFlag, SIP_NULLPTR, 0}, sipNameNr_DrawFlag, 63, SIP_NULLPTR},
};


/*
 * This defines each type in this module.
 */
sipTypeDef *sipExportedTypes_QtDataVisualization[] = {
    &sipTypeDef_QtDataVisualization_QList_0100QColor.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0100QLinearGradient.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0601QVector_0100QtDataVisualization_QBarDataItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0601QVector_0100QtDataVisualization_QSurfaceDataItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_Q3DTheme.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QAbstract3DAxis.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QAbstract3DInputHandler.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QBar3DSeries.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QCustom3DItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QScatter3DSeries.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QSurface3DSeries.mtd_base,
    &sipTypeDef_QtDataVisualization_QList_0101QtDataVisualization_QValue3DAxis.mtd_base,
    &sipTypeDef_QtDataVisualization_QVector_0101QImage.mtd_base,
    &sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QBarDataItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QScatterDataItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QVector_0100QtDataVisualization_QSurfaceDataItem.mtd_base,
    &sipTypeDef_QtDataVisualization_QVector_1300.mtd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DBars.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DCamera.ctd_base,
    &enumTypes[0].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DInputHandler.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DLight.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DObject.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DScatter.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DScene.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DSurface.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_Q3DTheme.ctd_base,
    &enumTypes[1].etd_base,
    &enumTypes[2].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DAxis.ctd_base,
    &enumTypes[3].etd_base,
    &enumTypes[4].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph.ctd_base,
    &enumTypes[5].etd_base,
    &enumTypes[6].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph_OptimizationHints.ctd_base,
    &enumTypes[7].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DGraph_SelectionFlags.ctd_base,
    &enumTypes[8].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DInputHandler.ctd_base,
    &enumTypes[9].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstract3DSeries.ctd_base,
    &enumTypes[10].etd_base,
    &enumTypes[11].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QAbstractDataProxy.ctd_base,
    &enumTypes[12].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QBar3DSeries.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataItem.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QBarDataProxy.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QCategory3DAxis.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DItem.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DLabel.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QCustom3DVolume.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QHeightMapSurfaceDataProxy.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelBarDataProxy.ctd_base,
    &enumTypes[13].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelScatterDataProxy.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QItemModelSurfaceDataProxy.ctd_base,
    &enumTypes[14].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QLogValue3DAxisFormatter.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QScatter3DSeries.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QScatterDataItem.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QScatterDataProxy.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries.ctd_base,
    &enumTypes[15].etd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QSurface3DSeries_DrawFlags.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QSurfaceDataItem.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QSurfaceDataProxy.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QTouch3DInputHandler.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QValue3DAxis.ctd_base,
    &sipTypeDef_QtDataVisualization_QtDataVisualization_QValue3DAxisFormatter.ctd_base,
};


/*
 * These define each typedef in this module.
 */
static sipTypedefDef typedefsTable[] = {
    {"QtDataVisualization::QBarDataArray", "QList<QVector<QtDataVisualization::QBarDataItem>*>"},
    {"QtDataVisualization::QBarDataRow", "QVector<QtDataVisualization::QBarDataItem>"},
    {"QtDataVisualization::QScatterDataArray", "QVector<QtDataVisualization::QScatterDataItem>"},
    {"QtDataVisualization::QSurfaceDataArray", "QList<QVector<QtDataVisualization::QSurfaceDataItem>*>"},
    {"QtDataVisualization::QSurfaceDataRow", "QVector<QtDataVisualization::QSurfaceDataItem>"},
};


/* This defines the types that this module needs to import from QtCore. */
sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtCore[] = {
    {"QAbstractItemModel"},
    {"QChildEvent"},
    {"QEvent"},
    {"QLocale"},
    {"QMetaMethod"},
    {"QObject"},
    {"QPoint"},
    {"QRect"},
    {"QRegExp"},
    {"QSize"},
    {"QSizeF"},
    {"QString"},
    {"QStringList"},
    {"QTimerEvent"},
    {"Qt::Axis"},
    {SIP_NULLPTR}
};


/*
 * This defines the virtual error handlers that this module needs to import
 * from QtCore.
 */
sipImportedVirtErrorHandlerDef sipImportedVirtErrorHandlers_QtDataVisualization_QtCore[] = {
    {"PyQt5"},
    {SIP_NULLPTR}
};


/* This defines the types that this module needs to import from QtGui. */
sipImportedTypeDef sipImportedTypes_QtDataVisualization_QtGui[] = {
    {"QColor"},
    {"QExposeEvent"},
    {"QFocusEvent"},
    {"QFont"},
    {"QHideEvent"},
    {"QImage"},
    {"QImage::Format"},
    {"QKeyEvent"},
    {"QLinearGradient"},
    {"QMouseEvent"},
    {"QMoveEvent"},
    {"QQuaternion"},
    {"QResizeEvent"},
    {"QShowEvent"},
    {"QSurface"},
    {"QSurface::SurfaceType"},
    {"QSurfaceFormat"},
    {"QTabletEvent"},
    {"QTouchEvent"},
    {"QVector3D"},
    {"QVector<float>"},
    {"QVector<uint>"},
    {"QWheelEvent"},
    {"QWindow"},
    {SIP_NULLPTR}
};


/* This defines the modules that this module needs to import. */
static sipImportedModuleDef importsTable[] = {
    {"PyQt5.QtCore", sipImportedTypes_QtDataVisualization_QtCore, sipImportedVirtErrorHandlers_QtDataVisualization_QtCore, SIP_NULLPTR},
    {"PyQt5.QtGui", sipImportedTypes_QtDataVisualization_QtGui, SIP_NULLPTR, SIP_NULLPTR},
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR}
};


/* This defines the class sub-convertors that this module defines. */
static sipSubClassConvertorDef convertorsTable[] = {
    {sipSubClass_QtDataVisualization_Q3DTheme, {5, 0, 0}, SIP_NULLPTR},
    {SIP_NULLPTR, {0, 0, 0}, SIP_NULLPTR}
};


/* Define the strings to be added to this module dictionary. */
static sipStringInstanceDef stringInstances[] = {
    {sipName_PYQT_DATAVISUALIZATION_VERSION_STR, PYQT_DATAVISUALIZATION_VERSION_STR, 'A'},
    {sipName_QTDATAVISUALIZATION_VERSION_STR, QTDATAVISUALIZATION_VERSION_STR, 'A'},
    {0, 0, 0}
};


/* Define the enum members and ints to be added to this module. */
static sipIntInstanceDef intInstances[] = {
    {sipName_PYQT_DATAVISUALIZATION_VERSION, PYQT_DATAVISUALIZATION_VERSION},
    {sipName_QTDATAVISUALIZATION_VERSION, QTDATAVISUALIZATION_VERSION},
    {0, 0}
};


/* This defines this module. */
sipExportedModuleDef sipModuleAPI_QtDataVisualization = {
    SIP_NULLPTR,
    15,
    sipNameNr_PyQt5_QtDataVisualization,
    0,
    sipStrings_QtDataVisualization,
    importsTable,
    SIP_NULLPTR,
    71,
    sipExportedTypes_QtDataVisualization,
    SIP_NULLPTR,
    0,
    SIP_NULLPTR,
    5,
    typedefsTable,
    SIP_NULLPTR,
    convertorsTable,
    {SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, stringInstances, intInstances, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR, SIP_NULLPTR},
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
    SIP_NULLPTR,
};


/* The SIP API and the APIs of any imported modules. */
const sipAPIDef *sipAPI_QtDataVisualization;

sip_qt_metaobject_func sip_QtDataVisualization_qt_metaobject;
sip_qt_metacall_func sip_QtDataVisualization_qt_metacall;
sip_qt_metacast_func sip_QtDataVisualization_qt_metacast;


/* The Python module initialisation function. */
#if defined(SIP_STATIC_MODULE)
extern "C" PyObject *PyInit_QtDataVisualization()
#else
PyMODINIT_FUNC PyInit_QtDataVisualization()
#endif
{
    static PyMethodDef sip_methods[] = {
        {sipName_qDefaultSurfaceFormat, SIP_MLMETH_CAST(func_qDefaultSurfaceFormat), METH_VARARGS|METH_KEYWORDS, SIP_NULLPTR},
        {SIP_NULLPTR, SIP_NULLPTR, 0, SIP_NULLPTR}
    };
    static PyModuleDef sip_module_def = {
        PyModuleDef_HEAD_INIT,
        "PyQt5.QtDataVisualization",
        SIP_NULLPTR,
        -1,
        sip_methods,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR,
        SIP_NULLPTR
    };

    PyObject *sipModule, *sipModuleDict;
    PyObject *sip_sipmod, *sip_capiobj;

    /* Initialise the module and get it's dictionary. */
    if ((sipModule = PyModule_Create(&sip_module_def)) == SIP_NULLPTR)
        return SIP_NULLPTR;

    sipModuleDict = PyModule_GetDict(sipModule);

    /* Get the SIP module's API. */
    if ((sip_sipmod = PyImport_ImportModule("PyQt5.sip")) == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sip_capiobj = PyDict_GetItemString(PyModule_GetDict(sip_sipmod), "_C_API");
    Py_DECREF(sip_sipmod);

    if (sip_capiobj == SIP_NULLPTR || !PyCapsule_CheckExact(sip_capiobj))
    {
        PyErr_SetString(PyExc_AttributeError, "PyQt5.sip._C_API is missing or has the wrong type");
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    sipAPI_QtDataVisualization = reinterpret_cast<const sipAPIDef *>(PyCapsule_GetPointer(sip_capiobj, "PyQt5.sip._C_API"));

    if (sipAPI_QtDataVisualization == SIP_NULLPTR)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    /* Export the module and publish it's API. */
    if (sipExportModule(&sipModuleAPI_QtDataVisualization, 12, 15, 0) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }


    sip_QtDataVisualization_qt_metaobject = (sip_qt_metaobject_func)sipImportSymbol("qtcore_qt_metaobject");
    sip_QtDataVisualization_qt_metacall = (sip_qt_metacall_func)sipImportSymbol("qtcore_qt_metacall");
    sip_QtDataVisualization_qt_metacast = (sip_qt_metacast_func)sipImportSymbol("qtcore_qt_metacast");

    if (!sip_QtDataVisualization_qt_metacast)
        Py_FatalError("Unable to import qtcore_qt_metacast");

    /* Initialise the module now all its dependencies have been set up. */
    if (sipInitModule(&sipModuleAPI_QtDataVisualization, sipModuleDict) < 0)
    {
        Py_DECREF(sipModule);
        return SIP_NULLPTR;
    }

    return sipModule;
}
